@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: css stylesheets
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: css stylesheets
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_Style
   require "#{SiSU_lib}/sysenv"
@@ -298,6 +306,15 @@ WOK
     margin-right: 5mm;
     text-align: right;
   }
+  p.tiny_center {
+    font-size: 10px;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    color: #777777;
+    margin-left: 0px;
+    margin-right: 0px;
+    text-align: center;
+  }
   p.pane {
     font-size: 80%;
     margin-top: 0px;
@@ -381,15 +398,15 @@ WOK
     margin-right: 5px;
     text-align: center;
   }
-  p.i1 {margin-left: 20mm;}
-  p.i2 {margin-left: 25mm;}
-  p.i3 {margin-left: 30mm;}
-  p.i4 {margin-left: 35mm;}
-  p.i5 {margin-left: 40mm;}
-  p.i6 {margin-left: 45mm;}
-  p.i7 {margin-left: 50mm;}
-  p.i8 {margin-left: 55mm;}
-  p.i9 {margin-left: 60mm;}
+  p.i1 {margin-left: 15mm;}
+  p.i2 {margin-left: 20mm;}
+  p.i3 {margin-left: 25mm;}
+  p.i4 {margin-left: 30mm;}
+  p.i5 {margin-left: 35mm;}
+  p.i6 {margin-left: 40mm;}
+  p.i7 {margin-left: 45mm;}
+  p.i8 {margin-left: 50mm;}
+  p.i9 {margin-left: 55mm;}
 
   table { }
   tr { }
@@ -397,11 +414,15 @@ WOK
   p.left, th.left, td.left {
     text-align: left;
   }
+  p.small_left, th.small_left, td.small_left {
+    text-align: left;
+    font-size: 80%;
+  }
   p.right, th.right, td.right {
     text-align: right;
   }
 
-  h1, h2, h3, h4, h5, h6 {
+  h0, h1, h2, h3, h4, h5, h6 {
     display: block;
     font-family: #{fonts};
     font-weight: bold;
@@ -425,82 +446,50 @@ WOK
     list-style: none;
   }
   li {
-    background: url(../image/bullet_red.png) no-repeat 0px 6px;
+    background: url(../image/bullet_09.png) no-repeat 0px 6px;
+    /* list-style-type: disc; */
     padding-left: 20px;
     display: block;
     font-family: #{fonts};
     /* font-size: 100%; */
     font-weight: normal;
-    line-height: 100%;
+    line-height: 150%;
     text-align: left;
     margin-left: 10mm;
     text-indent: 0mm;
-    margin-top: 0px;
-    margin-bottom: 0px;
-    margin-right: 5mm;
+    margin-top: 3px;
+    margin-bottom: 3px;
+    margin-right: 0mm;
   }
   li.bullet {
-    line-height: 150%;
-    margin-left: 0mm;
-    margin-right: 0mm;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 10mm;
   }
   li.i1 {
-    margin-left: 20mm;
-    line-height: 150%;
-    margin-left: 5mm;
-    margin-right: 5mm;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 15mm;
   }
   li.i2 {
-    margin-left: 25mm;
-    line-height: 150%;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 20mm;
   }
   li.i3 {
-    margin-left: 30mm;
-    line-height: 150%;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 25mm;
   }
   li.i4 {
-    margin-left: 35mm;
-    line-height: 150%;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 30mm;
   }
   li.i5 {
-    margin-left: 40mm;
-    line-height: 150%;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 35mm;
   }
   li.i6 {
-    margin-left: 45mm;
-    line-height: 150%;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 40mm;
   }
   li.i7 {
-    margin-left: 50mm;
-    line-height: 150%;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 45mm;
   }
   li.i8 {
-    margin-left: 55mm;
-    line-height: 150%;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 50mm;
   }
   li.i9 {
-    margin-left: 60mm;
-    line-height: 150%;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 55mm;
   }
   #horizontal_links {
     background: #eeeeee;
@@ -653,6 +642,9 @@ WOK
   h6 {
     font-size: 100%;
   }
+  h0 {
+    font-size: 80%;
+  }
   h1.norm, h2.norm, h3.norm {
     font-size: 110%;
     margin-left: 10mm;
@@ -723,6 +715,9 @@ WOK
   h4.i {margin-left: 25mm;}
   h5.i {margin-left: 30mm;}
   h6.i {margin-left: 35mm;}
+  h7.i {margin-left: 40mm;}
+  h8.i {margin-left: 45mm;}
+  h9.i {margin-left: 50mm;}
   h1.banner {
     font-weight: bold;
     text-align: center;
@@ -777,28 +772,28 @@ WOK
     font-weight: bold;
   }
   h1.toc {
-    margin-left: 0mm;
+    margin-left: 10mm;
     font-size: 115%;
     margin-top: 6px;
     margin-bottom: 6px;
     line-height: 150%;
   }
   h2.toc {
-    margin-left: 5mm;
+    margin-left: 15mm;
     font-size: 110%;
     margin-top: 6px;
     margin-bottom: 6px;
     line-height: 140%;
   }
   h3.toc {
-    margin-left: 10mm;
+    margin-left: 20mm;
     font-size: 105%;
     margin-top: 6px;
     margin-bottom: 6px;
     line-height: 120%;
   }
   h4.toc {
-    margin-left: 15mm;
+    margin-left: 25mm;
     font-weight: normal;
     font-size: 100%;
     margin-top: 6px;
@@ -806,7 +801,7 @@ WOK
     line-height: 120%;
   }
   h5.toc {
-    margin-left: 20mm;
+    margin-left: 30mm;
     font-weight: normal;
     font-size: 95%;
     margin-top: 6px;
@@ -814,7 +809,7 @@ WOK
     line-height: 110%;
   }
   h6.toc {
-    margin-left: 25mm;
+    margin-left: 35mm;
     font-weight: normal;
     font-size: 90%;
     margin-top: 6px;
@@ -1377,59 +1372,68 @@ WOK
       font-weight: bold;
       text-align: left;
     }
-    text[class|="indent1"] {
+    text[class|="indent0"] {
       margin-left: 10%;
     }
+    text[class|="indent1"] {
+      margin-left: 15%;
+    }
     text[class|="indent2"] {
-      margin-left: 15%;
+      margin-left: 20%;
     }
     text[class|="indent3"] {
-      margin-left: 20%;
+      margin-left: 25%;
     }
     text[class|="indent4"] {
-      margin-left: 25%;
+      margin-left: 30%;
     }
     text[class|="indent5"] {
-      margin-left: 30%;
+      margin-left: 35%;
     }
     text[class|="indent6"] {
-      margin-left: 35%;
+      margin-left: 40%;
     }
     text[class|="indent7"] {
-      margin-left: 40%;
+      margin-left: 45%;
     }
     text[class|="indent8"] {
-      margin-left: 45%;
+      margin-left: 50%;
     }
     text[class|="indent9"] {
-      margin-left: 50%;
+      margin-left: 55%;
+    }
+    text[class|="indent_bullet"] {
+      text-indent: 0%;
+    }
+    text[class|="indent_bullet0"] {
+      text-indent: 0%;
     }
     text[class|="indent_bullet1"] {
-      margin-left: 10%;
+      text-indent: 10%;
     }
     text[class|="indent_bullet2"] {
-      margin-left: 15%;
+      text-indent: 15%;
     }
     text[class|="indent_bullet3"] {
-      margin-left: 20%;
+      text-indent: 20%;
     }
     text[class|="indent_bullet4"] {
-      margin-left: 25%;
+      text-indent: 25%;
     }
     text[class|="indent_bullet5"] {
-      margin-left: 30%;
+      text-indent: 30%;
     }
     text[class|="indent_bullet6"] {
-      margin-left: 35%;
+      text-indent: 35%;
     }
     text[class|="indent_bullet7"] {
-      margin-left: 40%;
+      text-indent: 40%;
     }
     text[class|="indent_bullet8"] {
-      margin-left: 45%;
+      text-indent: 45%;
     }
     text[class|="indent_bullet9"] {
-      margin-left: 50%;
+      text-indent: 50%;
     }
     text[class|="verse"], text[class|="group"], text[class|="code"] {
       text-align: left;
