@@ -1,52 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: xml output (sax style) processing
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
+ ** Description: document abstraction tables
 
- * Notes: tidy -xml sax.xml >> index.tidy
 =end
 module SiSU_document_structure_tables
   class Instantiate < SiSU_Param::Parameters::Instructions
@@ -125,16 +131,18 @@ module SiSU_document_structure_tables
         if para =~/^\{(?:t|table)(?:~h)?(?:\sc\d+;)?[\d; ]*\}/
           @tuned_file << table_visual(para)
           @tuned_file=@tuned_file.flatten
-        elsif @@flag['table_to'] or para[/table\{(?:~h)?/]
+        elsif @@flag['table_to'] \
+        or para[/^table\{(?:~h)?/]
           if para[/table\{(?:~h)?\s+c(\d+;.+)/]
             instructions=$1
             @@column=instructions.split(/;\s*/)
             @@columns=@@column[0]
-            para.gsub!(/table\{~h\s+(c\d+?;.+?)$/,'<!Th¡ \1!>')
-            para.gsub!(/table\{\s+(c\d+?;.+?)$/,'<!T¡ \1!>')
+            para.gsub!(/^table\{~h\s+(c\d+?;.+?)$/,'<!Th¡ \1!>')
+            para.gsub!(/^table\{\s+(c\d+?;.+?)$/,'<!T¡ \1!>')
             @@flag['table_to']=true
           end
-          if @@flag['table_to'] and para =~/\}table/
+          if @@flag['table_to'] \
+          and para =~/\}table/
             para.gsub!(/^\}table\s*$/,"<!TZ!>\n")
             para.gsub!(/\n/,' ') #newlines taken out
             para.strip!
@@ -145,7 +153,8 @@ module SiSU_document_structure_tables
             @tuned_table=[]
             @@flag['table_to']=false
           end
-          if @@flag['table_to'] and para =~/\S/
+          if @@flag['table_to'] \
+          and para =~/\S/
             @@counter=1
             sub_array=para.dup
             @@line_mode=sub_array.scan(/.+/)
@@ -168,7 +177,8 @@ module SiSU_document_structure_tables
     def tr_td
       data=@data
       data.each do |line|
-        if @@counter <= @@columns.to_i and line !~/(\}T\s*$|<:table[-_](close|end)>|<!TZ!>)/
+        if @@counter <= @@columns.to_i \
+        and line !~/(\}T\s*$|<:table[-_](close|end)>|<!TZ!>)/
           line.gsub!(/(.+)/,"¡¡#{@@column[@@counter]}¡\\1") unless line =~/<!Th?¡/
           @@counter+=1
         end
