@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: Syntax for markup, input markup syntaxes, determined here
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: Syntax for markup, input markup syntaxes, determined here
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module Syntax
   class Words
@@ -57,12 +65,15 @@ module Syntax
       @data,@md=data,md
       @vz=SiSU_Env::Get_init.instance.skin
       @data_new=[]
-      @http_m='\{.+?\}http://\S+|http:\S+|\.\.\/\S+|\S+?\.png\b|[*]~\S+|^0~.+|<:(?:code|group|alt|verse)(?:-end)?>|<:br>'
+      url_and_stub=SiSU_Env::Info_env.new.url
+      @output_url="#{url_and_stub.remote}"
+      @http_m='\{.+?\}(?:https?|file)://\S+|(?:https?|file):\S+|\.\.\/\S+|\S+?\.png\b|[*]~\S+|^0~.+|<:(?:code|group|alt|verse)(?:-end)?>|<:br>'
       @manmkp_ital='[i/]\\{.+?\\}[i/]'
       tail_m_ital=%q{(?:\s|[.,;:?!'")]|~\^|~\\\{\s|$)}
       tail_m_bold=%q{(?:(?:<\/i>)?(?:\s|[.,;:?!'")]|~\^|~\\\{\s|$))?}
       bold_line=%q{^!_\s.+?(?:<br>|\n|$)}
-      @line_scan_ital=if defined? @md.make_italic[:str] and defined? @vz.markup_make_italic[:str]
+      @line_scan_ital=if defined? @md.make_italic[:str] \
+      and defined? @vz.markup_make_italic[:str]
         /#@http_m|#{bold_line}|#@manmkp_ital#{tail_m_ital}|(?:#{@md.make_italic[:str]}|#{@vz.markup_make_italic[:str]})#{tail_m_ital}|\S+|\n/
       elsif defined? @md.make_italic[:str]
         /#@http_m|#{bold_line}|#@manmkp_ital#{tail_m_ital}|#{@md.make_italic[:str]}#{tail_m_ital}|\S+|\n/
@@ -70,11 +81,16 @@ module Syntax
         /#@http_m|#{bold_line}|#@manmkp_ital#{tail_m_ital}|#{@vz.markup_make_italic[:str]}#{tail_m_ital}|\S+|\n/
       end
       @manmkp_bold='^!_\s.+?(?:\n|$)|[*!b]\\{.+?\\}[*!b]|[*!][a-zA-Z0-9\-_]+[*!]'
-      @line_scan_bold=if (defined? @md.make_bold[:str] and @md.make_bold[:str]) and (defined? @vz.markup_make_bold[:str] and @vz.markup_make_bold[:str])
+      @line_scan_bold=if (defined? @md.make_bold[:str] \
+      and @md.make_bold[:str]) \
+      and (defined? @vz.markup_make_bold[:str] \
+      and @vz.markup_make_bold[:str])
         /#@http_m|#{bold_line}|(?:#@manmkp_bold|#{@md.make_bold[:str]}|#{@vz.markup_make_bold[:str]})#{tail_m_bold}|\S+|\n/
-      elsif defined? @md.make_bold[:str] and @md.make_bold[:str]
+      elsif defined? @md.make_bold[:str] \
+      and @md.make_bold[:str]
         /#@http_m|#{bold_line}|(?:#@manmkp_bold|#{@md.make_bold[:str]})#{tail_m_bold}|\S+|\n/
-      elsif defined? @vz.markup_make_bold[:str] and @vz.markup_make_bold[:str]
+      elsif defined? @vz.markup_make_bold[:str] \
+      and @vz.markup_make_bold[:str]
         /#@http_m|#{bold_line}|(?:#@manmkp_bold|#{@vz.markup_make_bold[:str]})#{tail_m_bold}|\S+|\n/
       end
     end
@@ -96,18 +112,22 @@ module Syntax
     end
     def wordlist_italics(line)
       line=line.dup
-      if (defined? @md.make_italic[:str] and @md.make_italic[:str]) \
-      or (defined? @vz.markup_make_italic[:str] and @vz.markup_make_italic[:str])
-        line= if line !~/^(0~|%{1,4}\s)/  #!~/^(?:[0-6]~|!_|%+\s)/
+      if (defined? @md.make_italic[:str] \
+      and @md.make_italic[:str]) \
+      or (defined? @vz.markup_make_italic[:str] \
+      and @vz.markup_make_italic[:str])
+        line= if line !~/^(?:0~|%{1,4}\s|<:code)/  #!~/^(?:[0-6]~|!_|%+\s)/
           word=line.scan(@line_scan_ital)
           word.flatten!
           word.compact! #reinstated
           line_array=[]
           word.each do |w|
             unless /#@manmkp_ital|#@http_m/.match(w)
-              if defined? @md.make_italic[:regx] and @md.make_italic[:regx]
+              if defined? @md.make_italic[:regx] \
+              and @md.make_italic[:regx]
                 w.gsub!(@md.make_italic[:regx],'<i>\1</i>')
-              elsif defined? @vz.markup_make_italic and @vz.markup_make_italic
+              elsif defined? @vz.markup_make_italic \
+              and @vz.markup_make_italic
                 w.gsub!(@vz.markup_make_italic,'<i>\1</i>')
               end
             end
@@ -127,17 +147,22 @@ module Syntax
     end
     def wordlist_bold(line)
       line=line.dup
-      if (defined? @md.make_bold[:str] and @md.make_bold[:str]) or (defined? @vz.markup_make_bold[:str] and @vz.markup_make_bold[:str])
-        line=if line !~/^(?:[0-9]~|%+\s)/
+      if (defined? @md.make_bold[:str] \
+      and @md.make_bold[:str]) \
+      or (defined? @vz.markup_make_bold[:str] \
+      and @vz.markup_make_bold[:str])
+        line=if line !~/^(?:[0-9]~|%+\s|<:code)/
           line_array=[]
           word=line.scan(@line_scan_bold)
           word.flatten!
           word.compact!
           word.each do |w|
             unless /#@manmkp_bold|#@http_m/.match(w)
-              if defined? @md.make_bold[:regx] and @md.make_bold[:regx]   #document header: 0~bold [bold word list]
+              if defined? @md.make_bold[:regx] \
+              and @md.make_bold[:regx]   #document header: 0~bold [bold word list]
                 w.gsub!(@md.make_bold[:regx],'<b>\1</b>')
-              elsif defined? @vz.markup_make_bold and @vz.markup_make_bold               #defaults and skin adjusted bold word list
+              elsif defined? @vz.markup_make_bold \
+              and @vz.markup_make_bold               #defaults and skin adjusted bold word list
                 w.gsub!(@vz.markup_make_bold,'<b>\1</b>')
               end
             else
@@ -150,7 +175,9 @@ module Syntax
         else line
         end
       else
-        if line !~/^(?:[0-9]~|%+\s)/ and line =~ /(?:^!_|^[7-9]~)\s+/; embolden(line)
+        if line !~/^(?:[0-9]~|%+\s)/ \
+        and line =~ /(?:^!_|^[7-9]~)\s+/
+          embolden(line)
         end
       end
       line
@@ -177,13 +204,13 @@ module Syntax
       # _2                  <:i2>            #indent paragraph 2 steps
       # _3                  <:i3>            #indent paragraph 3 steps
       # _4                  <:i4>            #indent paragraph 4 steps
-      # _*                                    #bullet (list)
+      # _*                                    #bullet (list) ●
       # _1*                                   #bullet (list) indented
       # _1*                                   #bullet (list) indented
       # #                                     #numbered (list) level 1
       # _#                                    #numbered (list) level 2
       line=line.dup
-      unless line =~/^0~|<:codeline>|<:code-end>/
+      if line !~/^0~|<:codeline>|<:code-end>/
         #special characters: ~ { } < > - _ / also used : ^ ! #
         line_array=[]
         line.gsub!(/^%{1,4} .+/mi,'') #remove comments
@@ -201,7 +228,11 @@ module Syntax
           line=line_array.join(' ')
           line=line.strip
         end
-        line.gsub!(/<(https?:\/\/\S+?)>/,'< \1 >')                             #catch problem markup
+        line.gsub!(/^(1~\??) @title\s+(?:(by\s+)?(?:@creator|@author))\s*$/,"\\1 #{@md.title} - #{@md.subtitle},<br />\\2#{@md.dc_creator}")
+        line.gsub!(/^(1~\??) @title\s*$/,"\\1 #{@md.title} - #{@md.subtitle}")                    #
+        line.gsub!(/^([23]~\??) (?:(by\s+)?(?:@creator|@author))\s*$/,"\\1 \\2#{@md.dc_creator}")                    #
+        line.gsub!(/<((?:https?|file):\/\/\S+?)>/,'< \1 >')                             #catch problem markup
+        line.gsub!(/\}\.\.\/(\S+)/,"\}#@output_url/\\1")                             #means you are not supporting relative links (only relevant in html), converted to static here
         line.gsub!(/<:=(\S+?)>/,'{ c_\1.png 14x14 }http://www.jus.uio.no/sisu')                                                    #adjustment 2005w30
         line.gsub!(/<!(\S+)!>/,'<:\1>')                                        #escaped special character
         line.gsub!(/\\~/,'&#126;')                                             #escaped special character
@@ -228,8 +259,8 @@ module Syntax
         line.gsub!(/\\\!/,'&#033;')                                            #escaped special character
         line.gsub!(/(?:^| )\*~([a-z0-9._-]+)/i,' <:name#\1>')                  #html name marker <a name="\\1"></a>
         line.gsub!(/^([56]~)(\S+)(.+)/,'\1\2 \3 <:name#\2>')                   #html name marker <a name="\\1"></a>, however at present takes you to correct position within sub-toc, will nneed to clean from sub-toc leaving in main body only
-        line.gsub!(/(^| )\{~\^ (.+?)\s*\}((?:https?|ftp):\S+)\s+~\{(.+?)\}~/,'\1{ \2 }\3 ~{ \3 \4 }~') # watch
-        line.gsub!(/(^| )\{~\^ (.+?)\s*\}((?:https?|ftp):\S+?)(,?)?(?:\s|$)/,'\1{ \2 }\3\4 ~{ \3 }~ ') #text url endnote url shortcut {~^ [text] }http://url is { [text] }http://url ~{ http://url }~ [plus adjustment for commas]
+        line.gsub!(/(^| )\{~\^ (.+?)\s*\}((?:https?|file|ftp):\S+?)([;,.]?(?=\s[^~]|$))/,'\1{ \2 }\3\4 ~{ \3 }~ ') #text url endnote url shortcut {~^ [text] }http://url is { [text] }http://url ~{ http://url }~ [plus adjustment for commas] #means for this class, non-object, un-numbered ~# will not work # shortcut should not be used in conjunction with rebgular matches #reversed order, and addition of no-tilde..
+        line.gsub!(/(^| )\{~\^ (.+?)\s*\}((?:https?|file|ftp):\S+)\s+~\{(.+?)\}~/,'\1{ \2 }\3 ~{ \3 \4 }~') # watch
         line.gsub!(/<:?br>/,'<br />')                                              #xml requires
       # depreciated -->
         line.gsub!(/(^|\s+|['"]|&nbsp;|[\(\[\{]|\>)e\{(.+?)\}e/,'\1<b>\2</b>')     #emphasis
@@ -254,7 +285,7 @@ module Syntax
         line.gsub!(/(^|\s+|['"]|&nbsp;|\(|\>)\*(\S+?)\*/,'\1<b>\2</b>')            #bold single word, watch
         line.gsub!(/(^|\s+|['"]|&nbsp;|\(|\>)\!(\S+?)\!/,'\1<b>\2</b>')            #bold single word, watch
         line.gsub!(/(^|\s+|['"]|&nbsp;|\(|\>)\/([\(\)a-zA-Z0-9']+?)\/([^a-zA-Z0-9]|[ ,.;:'"~$]|$)/,'\1<i>\2</i>\3')     #italics single word, watch
-        line.gsub!(/(^|\s+|['"]|&nbsp;|\(|\>)_(\S+?)_/,'\1<u>\2</u>')              #underscore single word, watch
+        line.gsub!(/(^|\s+|['"]|&nbsp;|\(|\>)_(\S+?)_([.,!'")]?(?:\s|$))/,'\1<u>\2</u>\3')  #underscore single word, watch (made more complicated by url decoration escape tag (_url))
         line.gsub!(/(^|\s+)-([^{]\S+?)-( |$)/,'\1<del>\2</del>\3')                 #underscore single word, watch
         line.gsub!(/(^|\s+|['"]|&nbsp;|\(|\>|\d+)\^(\S+?)\^/,'\1<sup>\2</sup>')    #superscript single word, watch digit added
         line.gsub!(/<[:e]\s+(.+?)!?>/,'~{ \1 }~')                                  # not tested
@@ -274,8 +305,13 @@ module Syntax
         if line =~/(<:(?:verse|group)>)/; line.gsub!(/(<:(?:verse|group)>)/i,"\\1\n") #cosmetic
         else line.gsub!(/(<br \/>)/i,"\\1\n")
         end
-      else
-        line.gsub!(/<:codeline>/,"\n")
+      elsif line =~/^<:code(?:-end)?>|<:codeline>/ # /^<:code>/ #should be enough # underscore used as escape for angle brackets
+        line.gsub!(/([<>])/,'_\1')
+        line.gsub!(/_<:(\S+?)_>/,'<:\1>') #convert <:\S+> back, clumsy
+        line.gsub!(/_<(br(?: \/)?)_>/,'<\1>') #convert <br> <br /> back, clumsy
+        line.gsub!(/(^|\s)&lt;(br(?: \/)?)&gt;([\s,.]|$)/,'\1<\2>\3') #convert <br> <br /> back, clumsy
+        line.gsub!(/<:codeline>/,"\n&nbsp;&nbsp;") #temporary fix, prefer: #line.gsub!(/<:codeline>/,"\n")
+      else # 0~
       end
       line
     end
@@ -329,3 +365,5 @@ module Syntax
   end
 end
 __END__
+NOTE:
+downstream code blocks are not currently/yet honoured, e.g. stuff within angle brackets are removed
