@@ -1,50 +1,59 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: modules shared by the different db types, dbi, postgresql, sqlite
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: modules shared by the different db types, dbi, postgresql,
+    sqlite
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_DB_create
   require "#{SiSU_lib}/db_columns"
@@ -54,7 +63,7 @@ module SiSU_DB_create
     def initialize(opt,conn='',sql_type='pg')
       @opt,@conn,@sql_type=opt,conn,sql_type
       @cX=SiSU_Screen::Ansi.new(@opt.cmd).cX
-      @comment=comment
+      @comment=Comment.new(@sql_type)
       @@dl ||=SiSU_Env::Info_env.new.digest.length
     end
     def available
@@ -71,11 +80,222 @@ module SiSU_DB_create
       tell.colorize unless @opt.cmd =~/q/
       SiSU_Env::System_call.new.create_pg_db(@env.path.stub_pwd) #watch use of path.stub_pwd instead of stub
     end
-    def comment
-      @comment=Hash.new('')
-      case @sql_type
-      when /pg/
-        @comment['metadata'] =%{
+    def output_dir?
+      dir=SiSU_Env::Info_env.new('')
+      if @opt.cmd =~/d/; dir.path.webserv_stub_ensure
+      end
+    end
+    def create_table
+      def metadata
+        print %{
+          currently using sisu dbi module
+          to be populated from documents files
+          create tables metadata
+          data import through ruby transfer
+        } unless @opt.cmd =~/q/
+        @conn.execute(%{
+          CREATE TABLE metadata (
+            tid               INT4 PRIMARY KEY,
+            title             VARCHAR(#{lt_title}) NULL,
+            subtitle          VARCHAR(#{lt_subtitle}) NULL,
+            creator           VARCHAR(#{lt_creator}) NULL,
+            illustrator       VARCHAR(#{lt_illustrator}) NULL,
+            translator        VARCHAR(#{lt_translator}) NULL,
+            subject           VARCHAR(#{lt_subject}) NULL,
+            date              VARCHAR(#{lt_date}) NULL,
+            date_created      VARCHAR(#{lt_date_created}) NULL,
+            date_issued       VARCHAR(#{lt_date_issued}) NULL,
+            date_available    VARCHAR(#{lt_date_available}) NULL,
+            date_valid        VARCHAR(#{lt_date_valid}) NULL,
+            date_modified     VARCHAR(#{lt_date_modified}) NULL,
+/*          date              DATE, */
+/*          date_created      DATE, */
+/*          date_issued       DATE, */
+/*          date_available    DATE, */
+/*          date_valid        DATE, */
+/*          date_modified     DATE, */
+            type              VARCHAR(#{lt_type}) NULL,
+            description       VARCHAR(#{lt_description}) NULL,
+            publisher         VARCHAR(#{lt_publisher}) NULL,
+            contributor       VARCHAR(#{lt_contributor}) NULL,
+            prepared_by       VARCHAR(#{lt_prepared_by}) NULL,
+            digitized_by      VARCHAR(#{lt_digitized_by}) NULL,
+            format            VARCHAR(#{lt_format}) NULL,
+            identifier        VARCHAR(#{lt_identifier}) NULL,
+            source            VARCHAR(#{lt_source}) NULL,
+            language          VARCHAR(#{lt_language}) NULL,
+            language_original VARCHAR(#{lt_language_original}) NULL,
+            relation          VARCHAR(#{lt_relation}) NULL,
+            coverage          VARCHAR(#{lt_coverage}) NULL,
+            rights            VARCHAR(#{lt_rights}) NULL,
+            copyright         VARCHAR(#{lt_copyright}) NULL,
+            owner             VARCHAR(#{lt_owner}) NULL,
+            keywords          VARCHAR(#{lt_keywords}) NULL,
+            comment           VARCHAR(#{lt_comment}) NULL,
+            loc               VARCHAR(#{lt_loc}) NULL,
+            dewey             VARCHAR(#{lt_dewey}) NULL,
+            isbn              VARCHAR(#{lt_isbn}) NULL,
+            pg                VARCHAR(#{lt_pg}) NULL,
+            abstract          VARCHAR(#{lt_abstract}) NULL,
+            prefix_a          TEXT NULL,
+            prefix_b          TEXT NULL,
+            skin              VARCHAR(#{lt_skin}) NULL,
+            markup            VARCHAR(#{lt_markup}) NULL,
+            links             VARCHAR(#{lt_links}) NULL,
+            information       VARCHAR(#{lt_information}) NULL,
+            contact           VARCHAR(#{lt_contact}) NULL,
+            suffix            VARCHAR(#{lt_suffix}) NULL,
+            filename          VARCHAR(#{lt_filename}) NULL UNIQUE,
+            types             CHAR(#{lt_types}) NULL,
+            subj              VARCHAR(#{lt_subj}) NULL
+          );
+          #{@comment.metadata}
+        })
+      end
+      def documents                                                 # create documents base
+        print %{
+          to be populated from documents files
+          create tables documents document_trade document_env
+          data import through ruby transfer
+        } unless @opt.cmd =~/q/
+        @conn.execute(%{
+          CREATE TABLE documents (
+            lid             INT4 PRIMARY KEY,
+            metadata_tid    INT4 REFERENCES metadata,
+            ocn             SMALLINT,
+            ocnd            VARCHAR(6),
+            ocns            VARCHAR(6),
+            clean           TEXT NULL,
+            body            TEXT NULL,
+            seg             VARCHAR(#{document_seg}) NULL,
+            lev             SMALLINT NULL,
+            lev1            SMALLINT,
+            lev2            SMALLINT,
+            lev3            SMALLINT,
+            lev4            SMALLINT,
+            lev5            SMALLINT,
+            lev6            SMALLINT,
+            en_a            SMALLINT NULL,
+            en_z            SMALLINT NULL,
+            en_a_asterisk   SMALLINT NULL,
+            en_z_asterisk   SMALLINT NULL,
+            en_a_plus       SMALLINT NULL,
+            en_z_plus       SMALLINT NULL,
+            digest_clean    CHAR(#{@@dl}),
+            digest_all      CHAR(#{@@dl}),
+            types           CHAR(1) NULL
+          );
+          #{@comment.documents}
+        })
+      end
+      def endnotes
+        print %{
+          to be populated from documents files
+          create tables endnotes
+          data import through ruby transfer
+        } unless @opt.cmd =~/q/
+        @conn.execute(%{
+          CREATE TABLE endnotes (
+            nid             INT4 PRIMARY KEY,
+            document_lid    INT4 REFERENCES documents,
+            nr              SMALLINT,
+            clean           TEXT NULL,
+            body            TEXT NULL,
+            ocn             SMALLINT,
+            ocnd            VARCHAR(6),
+            ocns            VARCHAR(6),
+            digest_clean    CHAR(#{@@dl}),
+            metadata_tid    INT4 REFERENCES metadata
+          );
+          #{@comment.endnotes}
+        })
+      end
+      def endnotes_asterisk
+        print %{
+          to be populated from documents files
+          create tables endnotes_asterisk
+          data import through ruby transfer
+        } unless @opt.cmd =~/q/
+        @conn.execute(%{
+          CREATE TABLE endnotes_asterisk (
+            nid             INT4 PRIMARY KEY,
+            document_lid    INT4 REFERENCES documents,
+            nr              SMALLINT,
+            clean           TEXT NULL,
+            body            TEXT NULL,
+            ocn             SMALLINT,
+            ocnd            VARCHAR(6),
+            ocns            VARCHAR(6),
+            digest_clean    CHAR(#{@@dl}),
+            metadata_tid    INT4 REFERENCES metadata
+          );
+          #{@comment.endnotes_asterisk}
+        })
+      end
+      def endnotes_plus
+        print %{
+          to be populated from documents files
+          create tables endnotes_plus
+          data import through ruby transfer
+        } unless @opt.cmd =~/q/
+        @conn.execute(%{
+          CREATE TABLE endnotes_plus (
+            nid             INT4 PRIMARY KEY,
+            document_lid    INT4 REFERENCES documents,
+            nr              SMALLINT,
+            clean           TEXT NULL,
+            body            TEXT NULL,
+            ocn             SMALLINT,
+            ocnd            VARCHAR(6),
+            ocns            VARCHAR(6),
+            digest_clean    CHAR(#{@@dl}),
+            metadata_tid    INT4 REFERENCES metadata
+          );
+          #{@comment.endnotes_plus}
+        })
+      end
+      def urls                                                       # create documents file links mapping
+        print %{
+          currently using sisu dbi module
+          to be populated from documents files
+          create tables urls
+          data import through ruby transfer
+        } unless @opt.cmd =~/q/
+        @conn.execute(%{
+          CREATE TABLE urls (
+            metadata_tid    INT4 REFERENCES metadata,
+            plaintext       varchar(512),
+            html_toc        varchar(512),
+            html_doc        varchar(512),
+            xhtml           varchar(512),
+            xml_sax         varchar(512),
+            xml_dom         varchar(512),
+            odf             varchar(512),
+            pdf_p           varchar(512),
+            pdf_l           varchar(512),
+            concordance     varchar(512),
+            latex_p         varchar(512),
+            latex_l         varchar(512),
+            digest          varchar(512),
+            manifest        varchar(512),
+            markup          varchar(512),
+            sisupod         varchar(512)
+          );
+          #{@comment.urls}
+        })
+      end
+      self
+    end
+  end
+  class Comment
+    def initialize(sql_type='pg')
+      if sql_type =~ /pg/; psql
+      else none
+      end
+    end
+    def psql
+      def metadata
+        %{
         COMMENT ON Table metadata
           IS 'contains SiSU documents metadata with metadata';
         COMMENT ON COLUMN metadata.tid
@@ -187,7 +407,9 @@ module SiSU_DB_create
         PROCEDURE fileremoval();
 */
         }
-        @comment['documents'] =%{
+      end
+      def documents
+        %{
         COMMENT ON Table documents
           IS 'contains searchable text of SiSU documents';
         COMMENT ON COLUMN documents.lid
@@ -231,7 +453,9 @@ module SiSU_DB_create
         COMMENT ON COLUMN documents.lev6
           IS 'document structure, level 6';
         }
-        @comment['endnotes'] =%{
+      end
+      def endnotes
+        %{
         COMMENT ON Table endnotes
           IS 'contains searchable text of SiSU documents endnotes';
         COMMENT ON COLUMN endnotes.nid
@@ -249,7 +473,9 @@ module SiSU_DB_create
         COMMENT ON COLUMN documents.metadata_tid
           IS 'tie to title in metadata - unique for each document';
         }
-        @comment['endnotes_asterisk'] =%{
+      end
+      def endnotes_asterisk
+        %{
         COMMENT ON Table endnotes_asterisk
           IS 'contains searchable text of SiSU documents endnotes asterisk';
         COMMENT ON COLUMN endnotes_asterisk.nid
@@ -267,7 +493,9 @@ module SiSU_DB_create
         COMMENT ON COLUMN documents.metadata_tid
           IS 'tie to title in metadata - unique for each document';
         }
-        @comment['endnotes_plus'] =%{
+      end
+      def endnotes_plus
+        %{
         COMMENT ON Table endnotes_plus
           IS 'contains searchable text of SiSU documents endnotes';
         COMMENT ON COLUMN endnotes_plus.nid
@@ -285,7 +513,9 @@ module SiSU_DB_create
         COMMENT ON COLUMN documents.metadata_tid
           IS 'tie to title in metadata - unique for each document';
         }
-        @comment['urls'] =%{
+      end
+      def urls
+        %{
         COMMENT ON Table urls
           IS 'contains base url links to different SiSU output';
         COMMENT ON COLUMN documents.metadata_tid
@@ -320,210 +550,22 @@ module SiSU_DB_create
           IS 'SiSU document format .tgz (all SiSU information on document)';
         }
       end
-      @comment
+      self
     end
-    def output_dir?
-      dir=SiSU_Env::Info_env.new('')
-      if @opt.cmd =~/d/; dir.path.webserv_stub_ensure
+    def none
+      def metadata
       end
-    end
-    def create_table_metadata
-      print %{
-        currently using sisu dbi module
-        to be populated from documents files
-        create tables metadata
-        data import through ruby transfer
-      } unless @opt.cmd =~/q/
-      @conn.execute(%{
-        CREATE TABLE metadata (
-          tid               INT4 PRIMARY KEY,
-          title             VARCHAR(#{lt_title}) NULL,
-          subtitle          VARCHAR(#{lt_subtitle}) NULL,
-          creator           VARCHAR(#{lt_creator}) NULL,
-          illustrator       VARCHAR(#{lt_illustrator}) NULL,
-          translator        VARCHAR(#{lt_translator}) NULL,
-          subject           VARCHAR(#{lt_subject}) NULL,
-          date              VARCHAR(#{lt_date}) NULL,
-          date_created      VARCHAR(#{lt_date_created}) NULL,
-          date_issued       VARCHAR(#{lt_date_issued}) NULL,
-          date_available    VARCHAR(#{lt_date_available}) NULL,
-          date_valid        VARCHAR(#{lt_date_valid}) NULL,
-          date_modified     VARCHAR(#{lt_date_modified}) NULL,
-/*        date              DATE, */
-/*        date_created      DATE, */
-/*        date_issued       DATE, */
-/*        date_available    DATE, */
-/*        date_valid        DATE, */
-/*        date_modified     DATE, */
-          type              VARCHAR(#{lt_type}) NULL,
-          description       VARCHAR(#{lt_description}) NULL,
-          publisher         VARCHAR(#{lt_publisher}) NULL,
-          contributor       VARCHAR(#{lt_contributor}) NULL,
-          prepared_by       VARCHAR(#{lt_prepared_by}) NULL,
-          digitized_by      VARCHAR(#{lt_digitized_by}) NULL,
-          format            VARCHAR(#{lt_format}) NULL,
-          identifier        VARCHAR(#{lt_identifier}) NULL,
-          source            VARCHAR(#{lt_source}) NULL,
-          language          VARCHAR(#{lt_language}) NULL,
-          language_original VARCHAR(#{lt_language_original}) NULL,
-          relation          VARCHAR(#{lt_relation}) NULL,
-          coverage          VARCHAR(#{lt_coverage}) NULL,
-          rights            VARCHAR(#{lt_rights}) NULL,
-          copyright         VARCHAR(#{lt_copyright}) NULL,
-          owner             VARCHAR(#{lt_owner}) NULL,
-          keywords          VARCHAR(#{lt_keywords}) NULL,
-          comment           VARCHAR(#{lt_comment}) NULL,
-          loc               VARCHAR(#{lt_loc}) NULL,
-          dewey             VARCHAR(#{lt_dewey}) NULL,
-          isbn              VARCHAR(#{lt_isbn}) NULL,
-          pg                VARCHAR(#{lt_pg}) NULL,
-          abstract          VARCHAR(#{lt_abstract}) NULL,
-          prefix_a          TEXT NULL,
-          prefix_b          TEXT NULL,
-          skin              VARCHAR(#{lt_skin}) NULL,
-          markup            VARCHAR(#{lt_markup}) NULL,
-          links             VARCHAR(#{lt_links}) NULL,
-          information       VARCHAR(#{lt_information}) NULL,
-          contact           VARCHAR(#{lt_contact}) NULL,
-          suffix            VARCHAR(#{lt_suffix}) NULL,
-          filename          VARCHAR(#{lt_filename}) NULL UNIQUE,
-          types             CHAR(#{lt_types}) NULL,
-          subj              VARCHAR(#{lt_subj}) NULL
-        );
-        #{@comment['metadata']}
-      })
-    end
-    def create_table                                                             # create documents base
-      print %{
-        to be populated from documents files
-        create tables documents document_trade document_env
-        data import through ruby transfer
-      } unless @opt.cmd =~/q/
-      @conn.execute(%{
-        CREATE TABLE documents (
-          lid             INT4 PRIMARY KEY,
-          metadata_tid      INT4 REFERENCES metadata,
-          ocn             SMALLINT,
-          ocnd            VARCHAR(6),
-          ocns            VARCHAR(6),
-          clean           TEXT NULL,
-          body            TEXT NULL,
-          seg             VARCHAR(#{document_seg}) NULL,
-          lev             SMALLINT NULL,
-          lev1            SMALLINT,
-          lev2            SMALLINT,
-          lev3            SMALLINT,
-          lev4            SMALLINT,
-          lev5            SMALLINT,
-          lev6            SMALLINT,
-          en_a            SMALLINT NULL,
-          en_z            SMALLINT NULL,
-          en_a_asterisk   SMALLINT NULL,
-          en_z_asterisk   SMALLINT NULL,
-          en_a_plus       SMALLINT NULL,
-          en_z_plus       SMALLINT NULL,
-          digest_clean    CHAR(#{@@dl}),
-          digest_all      CHAR(#{@@dl}),
-          types           CHAR(1) NULL
-        );
-        #{@comment['documents']}
-      })
-    end
-    def create_table_endnotes
-      print %{
-        to be populated from documents files
-        create tables endnotes
-        data import through ruby transfer
-      } unless @opt.cmd =~/q/
-      @conn.execute(%{
-        CREATE TABLE endnotes (
-          nid             INT4 PRIMARY KEY,
-          document_lid    INT4 REFERENCES documents,
-          nr              SMALLINT,
-          clean           TEXT NULL,
-          body            TEXT NULL,
-          ocn             SMALLINT,
-          ocnd            VARCHAR(6),
-          ocns            VARCHAR(6),
-          digest_clean    CHAR(#{@@dl}),
-          metadata_tid    INT4 REFERENCES metadata
-        );
-        #{@comment['endnotes']}
-      })
-    end
-    def create_table_endnotes_asterisk
-      print %{
-        to be populated from documents files
-        create tables endnotes_asterisk
-        data import through ruby transfer
-      } unless @opt.cmd =~/q/
-      @conn.execute(%{
-        CREATE TABLE endnotes_asterisk (
-          nid             INT4 PRIMARY KEY,
-          document_lid    INT4 REFERENCES documents,
-          nr              SMALLINT,
-          clean           TEXT NULL,
-          body            TEXT NULL,
-          ocn             SMALLINT,
-          ocnd            VARCHAR(6),
-          ocns            VARCHAR(6),
-          digest_clean    CHAR(#{@@dl}),
-          metadata_tid    INT4 REFERENCES metadata
-        );
-        #{@comment['endnotes_asterisk']}
-      })
-    end
-    def create_table_endnotes_plus
-      print %{
-        to be populated from documents files
-        create tables endnotes_plus
-        data import through ruby transfer
-      } unless @opt.cmd =~/q/
-      @conn.execute(%{
-        CREATE TABLE endnotes_plus (
-          nid             INT4 PRIMARY KEY,
-          document_lid    INT4 REFERENCES documents,
-          nr              SMALLINT,
-          clean           TEXT NULL,
-          body            TEXT NULL,
-          ocn             SMALLINT,
-          ocnd            VARCHAR(6),
-          ocns            VARCHAR(6),
-          digest_clean    CHAR(#{@@dl}),
-          metadata_tid    INT4 REFERENCES metadata
-        );
-        #{@comment['endnotes_plus']}
-      })
-    end
-    def create_table_urls                                                       # create documents file links mapping
-      print %{
-        currently using sisu dbi module
-        to be populated from documents files
-        create tables urls
-        data import through ruby transfer
-      } unless @opt.cmd =~/q/
-      @conn.execute(%{
-        CREATE TABLE urls (
-          metadata_tid    INT4 REFERENCES metadata,
-          plaintext       varchar(512),
-          html_toc        varchar(512),
-          html_doc        varchar(512),
-          xhtml           varchar(512),
-          xml_sax         varchar(512),
-          xml_dom         varchar(512),
-          odf             varchar(512),
-          pdf_p           varchar(512),
-          pdf_l           varchar(512),
-          concordance     varchar(512),
-          latex_p         varchar(512),
-          latex_l         varchar(512),
-          digest          varchar(512),
-          manifest        varchar(512),
-          markup          varchar(512),
-          sisupod         varchar(512)
-        );
-        #{@comment['urls']}
-      })
+      def documents
+      end
+      def endnotes
+      end
+      def endnotes_asterisk
+      end
+      def endnotes_plus
+      end
+      def urls
+      end
+      self
     end
   end
 end
