@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: html generation, processing
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: html generation, processing
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_HTML
   require 'pstore'
@@ -85,22 +93,16 @@ module SiSU_HTML
         SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.path.output_tell}/#@fnb/#{@md.fn[:index]}").flow if @opt.cmd =~/[MV]/
         SiSU_Env::Info_skin.new(@md).select
         data=nil
-        unless @md.markup =~/url_png/
-          my_make=SiSU_Env::Create_file.new(@opt.cmd,@opt.fns,@md) #Beware #FIX opt and md, both not necessary
-          SiSU_Env::SiSU_file.new(@md).mkdir
-          @tuned_file_array=SiSU_HTML::Source::Html_environment.new(@md).tuned_file_instructions
-          data=@tuned_file_array
-        else
-          data=IO.readlines(@opt.fns,'') #wasteful, not really necessary?
-          SiSU_HTML_nav_tune::Tune.new(data,@md).songsheet
-          @tuned_file_array=data #watch may not be what you want
-        end
-        scr_endnotes=SiSU_HTML::Source::Endnotes.new(data,@md).scroll unless @md.markup =~/url_png/
+        my_make=SiSU_Env::Create_file.new(@opt.cmd,@opt.fns,@md) #Beware #FIX opt and md, both not necessary
+        SiSU_Env::SiSU_file.new(@md).mkdir
+        @tuned_file_array=SiSU_HTML::Source::Html_environment.new(@md).tuned_file_instructions
+        data=@tuned_file_array
+        scr_endnotes=SiSU_HTML::Source::Endnotes.new(data,@md).scroll
         toc=SiSU_HTML::Source::Toc.new(data,@md).songsheet
         links_guide=SiSU_HTML::Source::Links_guide.new(data,@md).toc
         data=@tuned_file_array
         scr_toc=SiSU_HTML::Source::Scroll_head_and_segtoc.new(data,@md,toc,links_guide).in_common #watch
-        SiSU_HTML::Source::Seg.new(data,@md).songsheet #if not_scroll_only
+        SiSU_HTML::Source::Seg.new(data,@md).songsheet
         data=@tuned_file_array
         scr=SiSU_HTML::Source::Scroll.new(data,@md).songsheet
         scroll=SiSU_HTML::Source::Scroll_output.new(scr_toc,scr[:body],scr_endnotes,scr[:metadata],scr[:owner_details],scr[:tails],@md).publish
@@ -118,8 +120,8 @@ module SiSU_HTML
         SiSU_Env::Create_file.new(@opt.cmd,@opt.fns).param_instantiate
         @@flag,@@scr,@@seg,@@seg_endnotes,@@seg_subtoc,@@seg_ad={},{},{},{},{},{}
         @@seg_total,@@tracker,@@loop_count,@@tablehead,@@number_of_cols=0,0,0,0,0
-        @@seg_name,@@seg_name_html,@@seg_name_php,@@seg_subtoc_array,@@seg_endnotes_array,@@segtocband,@@tablefoot=Array.new(7){[]}
-        @@filename_seg,@@seg_url,@@filename_segphp,@@fn,@@to_lev4,@@get_hash_to,@@get_hash_fn='','','','','','',''
+        @@seg_name,@@seg_name_html,@@seg_subtoc_array,@@seg_endnotes_array,@@segtocband,@@tablefoot=Array.new(7){[]}
+        @@filename_seg,@@seg_url,@@fn,@@to_lev4,@@get_hash_to,@@get_hash_fn='','','','','','',''
         @@is4=@@is3=@@is2=@@is1=@@header1=@@header2=@@header3=@@header4=0
       end
     end
@@ -149,17 +151,17 @@ module SiSU_HTML
         @tell=SiSU_Screen::Ansi.new(@md.cmd)
         if @md
           @md.sfx=''
-          @md.file_type='php' if @md.cmd =~/z/
           @md.sfx='' if @md.cmd =~/z/
-          if @md.cmd =~/h/ or @md.fns =~/\~[a-z]{2,3}\.s?/ #multilingual document protection is a bit arbitrary, (needed by existing server configuration), add configuration overide...
-            if @md.cmd =~/H/ and @md.fns =~/\~[a-z]{2,3}\.s?/
+          if @md.cmd =~/h/ \
+          or @md.fns =~/\~[a-z]{2,3}\.s?/ #multilingual document protection is a bit arbitrary, (needed by existing server configuration), add configuration overide...
+            if @md.cmd =~/H/ \
+            and @md.fns =~/\~[a-z]{2,3}\.s?/
               SiSU_Screen::Ansi.new(@md.cmd,
                 'multilingual document, creating internal url links with filetype suffix',
                 "\n\t\t(overriding -H request, using -h mode instead)"
               ).warn unless @md.cmd =~/q/
             end
             @md.sfx='.html'
-            @md.pdf='.pdf'
           end
         end
         @md.cmd=@md.cmd.gsub(/H/,'h')
@@ -169,12 +171,8 @@ module SiSU_HTML
         my_make_source_file=SiSU_Env::Create_file.new(@md.cmd,@md.fns)
         @fnm=my_make_source_file.marshal_meta
         @tune_verse_marshal=my_make_source_file.marshal_tune
-        if @md.markup !~/url_png/ and @md.cmd =~/[hozn]/
-          dal_array=SiSU_DAL::Source.new(@md).get # dal file drawn here
-          @tuned_file_array=SiSU_Tune::Tune.new(dal_array,@md).songsheet
-        else
-          SiSU_HTML_nav_tune::Tune.new(@file_array,@md).songsheet #no doc passed originally... 2004w35, revist changes in conditional 2006
-        end
+        dal_array=SiSU_DAL::Source.new(@md).get # dal file drawn here
+        @tuned_file_array=SiSU_Tune::Tune.new(dal_array,@md).songsheet
         require "#{SiSU_lib}/param"
         @tuned_file_array
       end
@@ -236,7 +234,8 @@ module SiSU_HTML
         format_head_toc=SiSU_HTML_Format_type::Head_toc.new(@md)
         guide_type='horzontal' #values: horizontal or vertical
         @links_guide_toc << format_head_toc.links_guide_open(guide_type)
-        if defined? @md.lnk and @md.lnk
+        if defined? @md.lnk \
+        and @md.lnk
           @md.lnk.each do |l|
             if defined? l[:say]
               target=if l[:url] !~/^\.(\.)?\//; 'external'
@@ -244,7 +243,6 @@ module SiSU_HTML
               end
               s_lnk_url,s_lnk_lnk=l[:url],l[:say]
               lev_para_ocn=SiSU_HTML_Format_type::Format_toc.new(@md,s_lnk_url,s_lnk_lnk,target)
-#p lev_para_ocn.links_guide if s_lnk_lnk
               @links_guide_toc << lev_para_ocn.links_guide if s_lnk_lnk
             end
           end
@@ -266,20 +264,23 @@ module SiSU_HTML
         @scr_endnotes << format_head_scroll.title_endnote
         @data.each do |para|
           pg=para.dup
-          if pg =~/~[{\[][\d*+]+ <a name="_[\d*+]+"/
-            endnote_array=[]
-            if pg=~/~\{[\d*+].+?\}\~/m
-              endnote_array << pg.scan(/~\{[\d*+]+(.+?)\}\~/m)
-            end
-            if pg=~/~\[[\d*]+\s.+?\]\~/m
-              endnote_array << pg.scan(/~\[[\d*]+(.+?)\]\~/m)
-            end
-            if pg=~/~\[[\d+]+\s.+?\]\~/m
-              endnote_array << pg.scan(/~\[[\d+]+(.+?)\]\~/m)
-            end
-            endnote_array.flatten.each do |note|
-              format_scroll=SiSU_HTML_Format_type::Format_scroll.new(@md,note)
-              @scr_endnotes << format_scroll.endnote_body
+          unless pg =~/^<:code>/
+            if pg =~/~[{\[][\d*+]+ <a name="_[\d*+]+"/ \
+            and not pg =~/^<:code>/
+              endnote_array=[]
+              if pg=~/~\{[\d*+].+?\}\~/m
+                endnote_array << pg.scan(/~\{[\d*+]+(.+?)\}\~/m)
+              end
+              if pg=~/~\[[\d*]+\s.+?\]\~/m
+                endnote_array << pg.scan(/~\[[\d*]+(.+?)\]\~/m)
+              end
+              if pg=~/~\[[\d+]+\s.+?\]\~/m
+                endnote_array << pg.scan(/~\[[\d+]+(.+?)\]\~/m)
+              end
+              endnote_array.flatten.each do |note|
+                format_scroll=SiSU_HTML_Format_type::Format_scroll.new(@md,note)
+                @scr_endnotes << format_scroll.endnote_body
+              end
             end
           end
         end
@@ -316,7 +317,8 @@ module SiSU_HTML
             when /^\s*4~!/;      Toc.new(para_toc).level_crosslink
             else
             end
-            if @@firstseg.nil? and para=~/^4~\S+?/
+            if @@firstseg.nil? \
+            and para=~/^4~\S+?/
               @@firstseg=/^4~(\S+)?/.match(para)[1]
             end
             if toc
@@ -375,26 +377,40 @@ WOK
         end
         para[@pat_heading]
         linkname,link=$1,$2 if $&
-        p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link) if link and link !~/#/ #% keep eye on link
-        title=unless para =~/Document Information/; linkname
+          if link \
+          and link !~/#/ #% keep eye on link
+            p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+          end
+          title=unless para =~/Document Information/; linkname
         else
           link='metadata'
           %{<b><a href="#{@md.fnl[:pre]}#{link}#{@md.fnl[:mid]}#{@md.sfx}#{@md.fnl[:post]}">#{linkname}</a></b>}
         end
         toc={}
         format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,title)
-        toc[:seg]=format_toc.lev1
+        toc[:seg]=if para =~/^\d~meta\s+Document Information/
+          format_toc.lev0
+        else format_toc.lev1
+        end
         title=if para =~/(<~0;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>)$/
           m=/#{$1}/
           para.gsub!(m,'')
-          linkname
-        else #if para =~/Document Information/
+          if para=~/^\d~meta\s+Document Information/
+            %{<a href="#docinfo">#{linkname}</a>}
+          else linkname
+          end
+        else
           @@toc[:scr] <<  '<br />'
-          link='docinfo'
+          link=if para =~/<~[1-9];([0-6]):\d+;\w\d+><#@dp:#@dp>$/; $1
+          else ''
+          end
           %{<b><a href="##{link}">#{linkname}</a></b>}
         end
         format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,title)
-        toc[:scr]=format_toc.lev1
+        toc[:scr]=if para =~/^\d~meta\s+Document Information/
+          format_toc.lev0
+        else format_toc.lev1
+        end
         toc
       end
       def level_2
@@ -404,7 +420,10 @@ WOK
         end
         para[@pat_heading]
         linkname,link=$1,$2 if $&
-        p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link) if link and link !~/#/
+        if link \
+        and link !~/#/
+          p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+        end
         format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,linkname)
         toc={}
         toc[:seg]=format_toc.lev2
@@ -424,7 +443,10 @@ WOK
         para.gsub(/(.*?)<a name="(\d+)"><\/a>(.*)/,'\1') #2002w42 altered gsub! - problematic? - suspect
         para[@pat_heading]
         linkname,link=$1,$2 if $&
-        p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link) if link and link !~/#/
+        if link \
+        and link !~/#/
+          p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+        end
         format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,linkname)
         toc={}
         toc[:seg]=format_toc.lev3
@@ -481,7 +503,10 @@ WOK
         end
         para[@pat_heading]
         linkname,link=$1,$2 if $&
-        p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link) if link and link !~/#/
+        if link \
+        and link !~/#/
+          p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+        end
         toc={}
         if para =~/<~0;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
           m=/#{$1}/
@@ -506,7 +531,10 @@ WOK
         end
         para[@pat_heading]
         linkname,link=$1,$2 if $&
-        p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link) if link and link !~/#/
+        if link \
+        and link !~/#/
+          p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+        end
         toc={}
         if para =~/<~0;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
           m=/#{$1}/
@@ -560,7 +588,7 @@ WOK
         SiSU_Screen::Ansi.new(@md.cmd,'Scroll & Segtoc').txt_grey unless @md.cmd =~/q/
         format_head_toc=SiSU_HTML_Format_type::Head_toc.new(@md)
         dochead=format_head_toc.head
-        dochead.gsub!(/toc\.(html|php)/,'doc.\1') #kludge
+        dochead.gsub!(/toc\.(html)/,'doc.\1') #kludge
         ads=SiSU_HTML_promo::Ad.new(@md)
         toc_shared << dochead << ads.div.major
         @segtoc << format_head_toc.head << ads.div.major
@@ -585,7 +613,8 @@ WOK
         format_txt_obj=SiSU_HTML_Format_type::Format_text_object.new(@md,tmp_head)
         toc_shared << format_txt_obj.center_bold
         @segtoc << format_txt_obj.center_bold
-        if not @md.subtitle.nil? and not @md.subtitle.empty?
+        if not @md.subtitle.nil? \
+        and not @md.subtitle.empty?
           tmp_head=@md.subtitle + "\n"
           format_txt_obj=SiSU_HTML_Format_type::Format_text_object.new(@md,tmp_head)
           toc_shared << format_txt_obj.center_bold
@@ -593,7 +622,6 @@ WOK
         end
         if @md.dc_creator
           creator_endnote=@md.dc_creator.gsub(/(\*+)/,%{&nbsp;<sup><a href="#notes">\\1</a></sup>})
-          creator_endnote=%{<sup>&copy;</sup> #{creator_endnote}} if creator_endnote =~/\S/
           tmp_head=creator_endnote + "\n"
           format_txt_obj=SiSU_HTML_Format_type::Format_text_object.new(@md,tmp_head)
           toc_shared << format_txt_obj.center_bold
@@ -641,7 +669,8 @@ WOK
       end
       def publish
         scroll=[]
-        scroll << @scr_toc << @scr_body << @scr_endnotes << @scr_metadata << @scr_owner_details << @scr_tails
+        hr='<center><hr width=90% /></center>'
+        scroll << @scr_toc << hr << @scr_body << hr << @scr_endnotes << hr << @scr_metadata << @scr_owner_details << @scr_tails
         scroll.flatten!.compact!
       end
     end
@@ -683,17 +712,6 @@ WOK
         rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         end
       end
-      def seg
-        begin
-          @data.each do |para|
-            para.strip!
-            unless para =~/\A\s*\Z/
-              @newfile.puts para,"\n"
-            end
-          end
-        rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
-        end
-      end
     end
   end
 end
