@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: base formatting template for html generation
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: base formatting template for html generation
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_HTML_Format
   require "#{SiSU_lib}/param"
@@ -55,16 +63,29 @@ module SiSU_HTML_Format
       @md=md
       @paranum=paranum[/(\d+)/m,1]
       @paranum ||=''
-      @paranum='' if @md.mod.inspect =~/--no-ocn/
+      vz=SiSU_Env::Get_init.instance.skin
+      @skin_no_ocn=if defined? vz.ocn_display_off \
+      and vz.ocn_display_off == true
+        true
+      else false
+      end
     end
     def ocn_display
-      ocn_class=if @md.mod.inspect =~/--no-ocn/; 'ocn_off'
-      else                                 'ocn'
-      end
-      @paranum.gsub(/^(\d+|)$/,
+      if @md.markup.inspect =~/no_ocn/ \
+      or @md.mod.inspect =~/--no-ocn/ \
+      or @skin_no_ocn
+        ocn_class='ocn_off'
+        @paranum.gsub(/^(\d+|)$/,
+        %{  <p class="#{ocn_class}">
+    &nbsp;
+  </p>})
+      else
+        ocn_class='ocn'
+        @paranum.gsub(/^(\d+|)$/,
         %{  <p class="#{ocn_class}">
     &nbsp;&nbsp;\\1
   </p>})
+      end
     end
     def name
       %{<a name="#@paranum" />}
@@ -161,7 +182,7 @@ module SiSU_HTML_Format
 <!- home and index buttons -!>}
     end
     def copyat
-      %{#{@vz.paragraph_heading_1_center}copy @
+      %{#{@vz.paragraph_font_tiny}copy @
   <a href="#{@vz.url_home}" #{@vz.js_home}>
     #{@vz.txt_home}
   </a></h1>}
@@ -181,7 +202,7 @@ module SiSU_HTML_Format
 }
     end
     def scroll(text)
-      if @md.fns =~ /\.[_-]?sst$/
+      if @md.fns =~ /\.(?:-|ssm\.)?sst$/
         scroll=%{<td align="center" bgcolor=#{@vz.color_band2}>
   <a href="#{@md.fn[:doc]}" target="_top" #{@vz.js_doc}>
     #{text}
@@ -200,7 +221,7 @@ module SiSU_HTML_Format
     end
     def search
       env=SiSU_Env::Info_env.new(@md.fns,@md)
-      env.widget.search_form
+      env.widget.search_form('sisusearch',nil,nil,true)
     end
     def manifest
       %{<td align="center" bgcolor=#{@vz.color_band2}>
@@ -210,14 +231,15 @@ module SiSU_HTML_Format
 </td>}
     end
     def pdf
-      pdf=if @md.programs[:pdf] and @cf_defaults.cf_0 =~/p/
+      pdf=if @md.programs[:pdf] \
+      and @cf_defaults.cf_0 =~/p/
         %{
-<td align="center" bgcolor=#{@vz.color_band2} border="0">
+<td align="center" bgcolor=#{@vz.color_band2}>
   <a href="#{@md.fn[:pdf_p]}" target="_top" #{@vz.js_portrait}>
     #{@vz.nav_txt_pdf_portrait}
   </a>
 </td>
-<td align="center" bgcolor=#{@vz.color_band2} border="0">
+<td align="center" bgcolor=#{@vz.color_band2}>
   <a href="#{@md.fn[:pdf_l]}" target="_top" #{@vz.js_landscape}>
     #{@vz.nav_txt_pdf_landscape}
   </a>
@@ -238,8 +260,9 @@ module SiSU_HTML_Format
       end
     end
     def concordance(text)
-      if @md.concord_make or @cf_defaults.cf_0 =~/w/
-  %{<td align="center" bgcolor=#{@vz.color_band2} border="0">
+      if @md.concord_make \
+      and @md.wc_words < 300000 #max word count for display of concordance here as would now be a large file
+  %{<td align="center" bgcolor=#{@vz.color_band2}>
     <a href="#{@md.fn[:concordance]}" target="_top" #{@vz.js_concordance}>
       #{text}
     </a>
@@ -270,6 +293,24 @@ WOK
 <td width="20%">
   &nbsp;
 #{@vz.table_close}
+<p />}
+    end
+    def concordance_navigation_band(type='')
+      if type=~/pdf/
+        @tocband_concordance=make_concordance
+      end
+      %{<table summary="concordance navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
+<tr><td width="20%">
+ #{@vz.banner_band}
+</td>
+<td width="60%" align="center">
+  #@tocband_concordance
+</td>
+<td width="20%" align="right">
+  &nbsp;<a href="index.html" target="_top" alt="-&gt;">
+      #{@vz.png_nav_toc}
+    </a>&nbsp;
+#{@vz.table_close}
 <p />}
     end
     def seg_head_navigation_band(type='')
@@ -308,7 +349,7 @@ WOK
     end
     def make_seg_scroll_pdf
       wgt=Widget.new(@md)
-      scroll=%{<td align="center" bgcolor=#{@vz.color_band2} border="0">
+      scroll=%{<td align="center" bgcolor=#{@vz.color_band2}>
   #{@vz.nav_txt_doc_link}
 </td>
 }
@@ -338,6 +379,19 @@ WOK
   #{wgt.manifest}
   #{wgt.search}
   #{wgt.home}
+</tr></table>}
+    end
+    def make_concordance
+      manifest=scroll=seg=''
+      wgt=Widget.new(@md)
+      %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
+<tr>
+  #{wgt.seg(@vz.nav_txt_toc_link)}#{wgt.scroll(@vz.nav_txt_doc_link)}#{wgt.pdf}#{wgt.odf}
+<td align="center" bgcolor=#{@vz.color_band2}>
+  #{wgt.concordance(@vz.nav_txt_concordance)}
+  #{wgt.manifest}
+  #{wgt.search}
+  #{wgt.home}
 </tr></table>}
     end
     def head
@@ -428,18 +482,12 @@ WOK
     def prefix_a
     end
     def rights
-      rights=@md.dc_rights.gsub(/^\s*Copyright\s+/,'<sup>&copy;</sup>&nbsp;')
-      %{<p class="left">#{rights}</p>
+      rights=@md.dc_rights.gsub(/^\s*Copyright\s+\(C\)/,'Copyright <sup>&copy;</sup>&nbsp;')
+      %{<p class="small_left">Rights: #{rights}</p>
 <p />}
     end
     def prefix_b
-      %{<table summary="prefix">
-<tr>
-<td width=10%>&nbsp;</td>
-<td width=80%>
-  #{@md.prefix_b}
-#{@vz.table_close}
-<p />}
+      %{<p class="small_left">Prefix: #{@md.prefix_b}<p />}
     end
     def scroll_head_title_banner_open
       %{<center>
@@ -520,6 +568,7 @@ WOK
 </table>
 <p>&nbsp;</p>
 #{@vz.credits_splash}
+#{@vz.credits_sisu}
 <a name="bottom" id="bottom"></a>
 <a name="down" id="down"></a>
 <a name="end" id="end"></a>
@@ -531,6 +580,7 @@ WOK
       nav=scroll_head_navigation_band
       %{#{nav}
 #{@vz.credits_splash}
+#{@vz.credits_sisu}
 <a name="bottom" id="bottom"></a>
 <a name="down" id="down"></a>
 <a name="end" id="end"></a>
@@ -542,6 +592,7 @@ WOK
       #nav=scroll_head_navigation_band
       %{<p>&nbsp;</p>
 #{@vz.credits_splash}
+#{@vz.credits_sisu}
 <a name="bottom" id="bottom"></a>
 <a name="down" id="down"></a>
 <a name="end" id="end"></a>
@@ -598,9 +649,7 @@ WOK
     def title_endnote
       %{#{@vz.margin_txt_0}
   #{@vz.paragraph_txt}
-  <br />
   <a name="endnotes" id="endnotes"></a>
-  <b>Endnotes</b>
 #{@vz.margin_num}
   &nbsp;
 #{@vz.table_close}}
@@ -620,6 +669,7 @@ WOK
 #{@vz.paragraph_txt}
   <center>
     #{@vz.credits_splash}
+    #{@vz.credits_sisu}
   </center>
 #{@vz.margin_num}
 #{@vz.table_close}
@@ -827,7 +877,6 @@ WOK
     Endnotes
   </h4>
 #{@vz.table_close}
-#{table_top_control}
 <h1>Endnotes</h1>}
     end
     def navigation_table
@@ -886,6 +935,7 @@ WOK
     def credit
       %{<br/>
 #{@vz.credits_splash}
+#{@vz.credits_sisu}
 <a name="bottom" id="bottom"></a>
 <a name="down" id="down"></a>
 <a name="end" id="end"></a>
@@ -909,7 +959,7 @@ WOK
     end
     def endnote_mark
 %{<p class="center" id="endnotes">
-<a href="#top">^</a></p>}
+<a href="#top"><hr></a></p>} #revisit
     end
   end
   class Format_text_object
@@ -946,41 +996,35 @@ WOK
       end
       @vz=SiSU_Env::Get_init.instance.skin
     end
-    def para_form                                                                # regular paragraphs shaped here
+    def para_form(tag,attrib)                                                        # regular paragraphs shaped here
       ul=ulc=''
       ul,ulc="<ul>\n  ","\n  </ul>" if @tag =~/li/
       %{#{@vz.margin_css}
-  #{ul}<#@tag class="#@class" #{@p_num.id}>#{@p_num.name}
+  #{ul}<#{tag} class="#{attrib}" #{@p_num.id}>#{@p_num.name}
     #@parablock
-  </#@tag>#{ulc}
+  </#{tag}>#{ulc}
 #{@vz.margin_num_css}
   #{@p_num.ocn_display}
 #{@vz.table_close}
 }
     end
     def para
-      @tag,@class='p','norm'
-      para_form
+      para_form('p','norm')
     end
     def code
-      @tag,@class='p','code'
-      para_form
+      para_form('p','code')
     end
     def center
-      @tag,@class='p','center'
-      para_form
+      para_form('p','center')
     end
     def bold
-      @tag,@class='p','bold'
-      para_form
+      para_form('p','bold')
     end
     def bullet
-      @tag,@class='li','bullet'
-      para_form
+      para_form('li','bullet')
     end
     def format(tag,atrib)
-      @tag,@class=tag,atrib
-      para_form
+      para_form(tag,atrib)
     end
     def dl
       "<dl><b>#@one</b> #@two</dl>"
