@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: html segment generation, processing
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: html segment generation, processing
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_HTML_seg
   require "#{SiSU_lib}/shared_html"
@@ -57,11 +65,12 @@ module SiSU_HTML_seg
     @@loop_count=@@seg_total=@@tracker=0
     @@is4=@@is3=@@is2=@@is1=0
     @@header1=@@header2=@@header3=@@header4=0
-    @@seg[:tocband],@@seg[:title],@@seg[:headers],@@seg[:main],@@seg[:tail],@@seg[:credits],@@seg_subtoc_array,@@seg_endnotes_array,@@heading_endnotes_array,@@seg[:endnote_all]=Array.new(10){[]}
+    @@seg[:tocband],@@seg[:title],@@seg[:headers],@@seg[:main],@@seg[:tail],@@seg[:credits],@@seg_subtoc_array,@@seg_endnotes_array,@@seg[:endnote_all]=Array.new(9){[]}
     @@seg[:header_endnotes]=''
     @@tablehead,@@number_of_cols=0,0
-    @@flag_group=false
+    @@flag_alt=false
     @@dp,@@segtocband=nil,nil
+    @@fns_previous=''
     attr_reader :seg_name_html,:seg_name_html_tracker
     def initialize(data='',md='')
       @data,@md=data,md
@@ -126,10 +135,13 @@ module SiSU_HTML_seg
           unless para =~/^1~/; head1=$_ #;
           end
         end
-        if @@is4 == 1 or para =~/^<ENDNOTES>|^<EOF>/
-          if newfile == 1 or para =~/^<ENDNOTES>|^<EOF>/
+        if @@is4 == 1 \
+        or para =~/^<ENDNOTES>|^<EOF>/
+          if newfile == 1 \
+          or para =~/^<ENDNOTES>|^<EOF>/
             newfile=0
-            if para =~/^4~\S+/ or para =~/^<ENDNOTES>|^<EOF>/ # @@level4
+            if para =~/^4~\S+/ \
+            or para =~/^<ENDNOTES>|^<EOF>/ # @@level4
               if tracking != 0
                 File.mkpath(@md.dir_out) unless FileTest.directory?(@md.dir_out) #bug - added specifically for nav! not needed by regular seg, check !!!
                 Seg.new('',@md).tail
@@ -159,7 +171,7 @@ module SiSU_HTML_seg
           end
           m=para[/.+?<a name="(\d+)">.*/]; @@get_hash_to=$1 if m              # changed 2002w42, again w44 ! & again 2003w16
           m=para[/^4~(\S+)/]; @@get_hash_fn=$1 if m
-          para=if para =~/<!Th?¡\s+c|<:(?:code|alt|verse|group)>/; para.split(/\n/)
+          para=if para =~/<!Th?¡\s+c|<:(?:code|alt|verse|group)>/m; para.split(/\n/)
           else para
           end
           if para.class == String
@@ -169,10 +181,8 @@ module SiSU_HTML_seg
               markup(pg)
             end
           end
-          Seg.new(para,@md).txt
           if testforartnum[tracking-1] =~/endnote/
             if printed_endnote_seg == 'n'
-              Seg.new(para,@md).endnote
               printed_endnote_seg='y'
             end
           end
@@ -182,8 +192,8 @@ module SiSU_HTML_seg
     def header_art(para)
       format_head_seg=SiSU_HTML_Format_type::Head_seg.new(@md)
       if para =~/^[0-6]~/ #2004w27/5
-        if @@tracker < @@seg_total-1; @@seg[:dot_nav]=format_head_seg.dot_control_pre_next #if format_head_seg.dot_control_pre_next
-        else                          @@seg[:dot_nav]=format_head_seg.dot_control_pre #if format_head_seg.dot_control_pre
+        if @@tracker < @@seg_total-1; @@seg[:dot_nav]=format_head_seg.dot_control_pre_next
+        else                          @@seg[:dot_nav]=format_head_seg.dot_control_pre
         end
       end
       ads=SiSU_HTML_promo::Ad.new(@md)
@@ -200,7 +210,7 @@ module SiSU_HTML_seg
       end
       @p_num ||= ''
       if @@is1 == 1
-        @dc_creator=%{<b><sup>&copy;</sup>&nbsp;#{@md.dc_creator}</b>\n} if @md.dc_creator.to_s =~/\S/
+        @dc_creator=%{<b>#{@md.dc_creator}</b>\n} if @md.dc_creator.to_s =~/\S/
         @@seg[:tocband] << format_head_seg.navigation_band(@@segtocband,@@seg[:dot_nav])
         @@seg[:headers] << format_head_seg.seg_head_escript if SiSU_HTML_Format_type::Head_seg.method_defined? :seg_head_escript #debug PHP move up in text #bug
         @@seg[:headers] << format_head_seg.title_banner(@md.title,@md.subtitle,@dc_creator).gsub(clean,'')
@@ -253,20 +263,22 @@ module SiSU_HTML_seg
           paranum=m[1].to_s
           @p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,paranum)
         end
-        if para =~/<:(?:code|alt|verse|group)>/ or @@flag_group==true
-          if para =~/<:(?:code|alt|verse|group)>/
+        if para =~/<:(?:code|alt|verse|group)>/m \
+        or @@flag_alt==true
+          if para =~/<:(?:code|alt|verse|group)>/m
             @group_collect=[] #unless @group_collect.class == Array
-            @group_collect << @vz.margin_txt_0 + para
-            @@flag_group=true
-          elsif @@flag_group==true
-            unless para =~/<:(?:code|alt|verse|group)-end>/                  # neither ideal nor necessary sort later
-              @group_collect << para
-            else @group_collect << para.gsub(/<:(?:code|alt|verse|group)-end>/,'')
+            @group_collect << @vz.margin_txt_0 + para.gsub(/<:(?:code|alt|verse|group)-end>/m,'') #watch !
+            @@flag_alt=true
+          elsif @@flag_alt==true
+            @group_collect << if para !~/<:(?:code|alt|verse|group)-end>/m                  # neither ideal nor necessary sort later
+              para
+            else
+              para.gsub(/<:(?:code|alt|verse|group)-end>/m,'')
             end
           end
-          if para =~/<:(?:code|alt|verse|group)-end>/
+          if para =~/<:(?:code|alt|verse|group)-end>/m
             para=@group_collect.flatten.join
-            @@flag_group=false
+            @@flag_alt=false
             @group_collect=[]
           end
         end
@@ -291,15 +303,17 @@ module SiSU_HTML_seg
           when /^i([1-9])$/    #indent levels 1-9
             format_txt_obj.gsub_body
             para=@sto.seg_lev_para_ocn.format('p',"i#{$1}")
-          when /^(?:verse|group|alt)$/
+          when /^(?:verse|group|alt)$/m
             @sto.seg_lev_para_ocn.para
           when /^code$/
             @sto.seg_lev_para_ocn.code
           when /null/
-            if para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/ and para !~/^<!TZ!>/
+            if para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/ \
+            and para !~/^<!TZ!>/
               format_txt_obj.gsub_body
               @sto.seg_lev_para_ocn.para
-            elsif para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/ and para =~/^<!TZ!>/
+            elsif para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/ \
+            and para =~/^<!TZ!>/
               format_txt_obj.gsub_body
               @sto.seg_lev_para_ocn.table_end
             else para
@@ -331,19 +345,15 @@ module SiSU_HTML_seg
           @@seg[:main] << @@seg_subtoc[@@get_hash_fn]                       #% insertion of sub-toc
         else
           para.gsub!(/<:[-_\w\d]?(-.+?-)?>|4~!.+/,'')
-          @@seg[:main] << para unless @@flag_group==true
+          @@seg[:main] << para unless @@flag_alt==true
         end
       end
     end
-    def txt
-    end
-    def endnote
-    end
     def tail
       format_head_seg=SiSU_HTML_Format_type::Head_seg.new(@md)
       if @md.flag_auto_endnotes
         @@seg[:tail] << format_head_seg.endnote_mark
-        @@seg[:tail] << @@seg_endnotes[@@get_hash_fn] #endnotes deposited at end of individual segments||@|EXTRACTION OF ENDNOTES|
+        @@seg[:tail] << @@seg_endnotes[@@get_hash_fn] #endnotes deposited at end of individual segments ||@|EXTRACTION OF ENDNOTES|
       end
       @@seg[:tail] << '<table summary="whitespace"><tr><td>&nbsp;</td></tr></table>'
       ads=SiSU_HTML_promo::Ad.new(@md)
@@ -377,29 +387,36 @@ module SiSU_HTML_seg
       reinitialise
       @@seg_total,@@tracker=0,0
       @@seg_endnotes,@@seg_subtoc={},{}
-      @@seg_endnotes_array,@@seg_subtoc_array,@@heading_endnotes_array=[],[],[]
+      @@seg_endnotes_array,@@seg_subtoc_array=[],[]
       @@seg[:endnote_all]=[]
     end
     def get_subtoc_endnotes(data) #get endnotes & sub-table of contents subtoc
       data.each do |para|
         para.gsub!(/<a name=\"h\d.*?\">(.+?)<\/a>/mi,'\1')
         if @md.flag_auto_endnotes
-          if para =~/^[1234]~/ and not @@fn.empty?
+          if para =~/^[1234]~/ \
+          and not @@fn.empty?
             @@seg_endnotes[@@fn]=[]
             @@seg_endnotes[@@fn] << @@seg_endnotes_array
             @@seg_endnotes_array=[] if para=~/^4~/
+            @@fns_previous=@md.fns if para=~/^1~meta/
           end
-        end
-        if para =~/^4~/                                              #% EXTRACTION OF SUB-TOCs
-          @@seg_subtoc[@@fn]=@@seg_subtoc_array
-          @@seg_subtoc_array=[]
-        end
-        if para =~/^4~/                                              #% SEGMENT NAME, after EXTRACTION OF ENDNOTES & SUB-TOCs
-          m=para[/^4~(\S+).+?<~(\d+);(?:[oh]|4:)\d+;\w\d+><#@dp:#@dp>$/]
-          if m;  @@fn,@@to_lev4=$1,$2 if m # changed 2004w07          #endnotes and sub-tocs
-          else
-            m=para[/^4~(\S+)/]
-            @@fn,@@to_lev4=$1,'nonum' if m # changed 2005w13
+          if para =~/^4~/                                              #% EXTRACTION OF SUB-TOCs
+            @@seg_subtoc[@@fn]=@@seg_subtoc_array
+            @@seg_subtoc_array=[]
+          end
+          if para =~/^4~/                                              #% SEGMENT NAME, after EXTRACTION OF ENDNOTES & SUB-TOCs
+            if para !~/^4~metadata/
+              m=para[/^4~(\S+).+?<~(\d+);(?:[oh]|4:)\d+;\w\d+><#@dp:#@dp>$/]
+            end
+            if m;  @@fn,@@to_lev4=$1,$2 if m # changed 2004w07          #endnotes and sub-tocs
+            else
+              if para !~/^4~metadata/
+                m=para[/^4~(\S+)/]
+                @@fn,@@to_lev4=$1,'nonum' if m # changed 2005w13
+              else @@fn=''
+              end
+            end
           end
         end
         if para =~/^[56]~\S*\s+(.+)?<~(\d+);(?:h|[56]:)\d+;\w\d+><#@dp:#@dp>$/
@@ -417,7 +434,8 @@ module SiSU_HTML_seg
           @@seg_subtoc_array << para
         end
         if @md.flag_auto_endnotes
-          if para =~/~[{\[][\d*+]+ <a name="_[\d*+]+"/ # endnote-
+          if para =~/~[{\[][\d*+]+ <a name="_[\d*+]+"/ \
+          and not para =~/^<:code>/ # endnote-
             endnote_array=[]
             if para=~/~\{.+?\}\~/m
               endnote_array << para.scan(/~\{.+?\}\~/m)
