@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: shared html parts
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: shared html parts
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_HTML_table
   require "#{SiSU_lib}/defaults"
