@@ -1,52 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: document summary processing, available outputs and metadata
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
 
- * Notes: tidy -ascii index.xml >> index.tidy
+ ** Description: summary of generated outputs and metadata
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_Manifest
   require "#{SiSU_lib}/sysenv"
@@ -85,14 +91,14 @@ module SiSU_Manifest
         @md,@fns=md
         @env=SiSU_Env::Info_env.new(@md.fns)
         @fnb=@md.fnb
-        out=@env.path.output
-        @base_url="#{@env.url.root}/#@fnb"
-        @base_path="#{out}/#@fnb"
+        @base_url,@base_url_src,@base_url_pod="#{@env.url.root}/#@fnb","#{@env.url.src_txt}","#{@env.url.src_pod}"
+        @base_path,@base_path_src,@base_path_pod="#{@env.path.output}/#@fnb","#{@env.path.output_src}","#{@env.path.output_pod}"
         @@dg ||=SiSU_Env::Info_env.new.digest.type
         @dg=@@dg
         l=SiSU_Env::Standardise_language.new.file_to_language(@md.fns)
         @language=l[:l]
         @translate=SiSU_Translate::Source.new(@md,@language)
+        @url_brace=SiSU_Viz::Skin.new.url_decoration
       end
       def output
         SiSU_Env::SiSU_file.new(@md).mkdir
@@ -101,23 +107,37 @@ module SiSU_Manifest
           manifest << x
         end
       end
-      def summarize(id,file)
+      def summarize(id,file,img='')
         size=(File.size("#{@base_path}/#{file}")/1024.00).to_s
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
         @manifest[:txt] << "#{file} #{id} #{kb}\n"
-        @manifest[:html] << %{<tr><th class="left"><p class="bold"><a href="#{file}">#{file}</a></p></th><td><p class="norm">#{id}</p><p class="tiny"><a href="#@base_url/#{file}">#@base_url/#{file}</a></p></td><td class="right"><p class="right">#{kb}</p></td></tr>\n}
+        @manifest[:html] << %{<tr><th class="left"><p class="norm"><a href="#{file}">#{img}#{id}</a></p></th><td><p class="small"><a href="#{file}">#{file}</a></p><p class="tiny">#{@url_brace.xml_open}<a href="#@base_url/#{file}">#@base_url/#{file}</a>#{@url_brace.xml_close}</p></td><td class="right"><p class="right">#{kb}</p></td></tr>\n}
       end
       def summarize_source(id,file)
         sys=SiSU_Env::System_call.new
-        dgst =if @dg =~/^sha(?:2|256)$/; sys.sha256("#{@base_path}/#{file}")
-        else                             sys.md5("#{@base_path}/#{file}")
+        dgst =if @dg =~/^sha(?:2|256)$/; sys.sha256("#{@base_path_src}/#{file}")
+        else                             sys.md5("#{@base_path_src}/#{file}")
         end
         tell=SiSU_Screen::Ansi.new(@md.cmd,"#{dgst[1]} #{file}")
         tell.warn if @md.cmd =~/[vVM]/
-        size=(File.size("#{@base_path}/#{file}")/1024.00).to_s
+        size=(File.size("#{@base_path_src}/#{file}")/1024.00).to_s
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
         @manifest[:txt] << "#{file} #{id} #{kb}\n"
-        @manifest[:html] << %{<tr><th class="left"><p class="tiny">#{id}:</p> <p class="norm"><a href="#{file}">#{file}</a></p><p class="tiny"><a href="#@base_url/#{file}">#@base_url/#{file}</a></p></th><td class="right"><p class="tiny">#{dgst[1]}</p></td><td class="right"><p class="right">#{kb}</p></td></tr>\n}
+        @manifest[:html] << %{<tr><th class="left"><p class="norm"><a href="../src/#{file}">#{id}</a></p></th><td class="right"><p class="tiny"><a href="../src/#{file}">#{file}</a> &nbsp;&nbsp;#{dgst[1]}<br />#{@url_brace.xml_open}<a href="#@base_url_src/#{file}">#@base_url_src/#{file}</a>#{@url_brace.xml_close}</p></td><td class="right"><p class="right">#{kb}</p>
+        </td></tr>\n} if kb and kb =~/\d+/
+      end
+      def summarize_pod(id,file)
+        sys=SiSU_Env::System_call.new
+        dgst =if @dg =~/^sha(?:2|256)$/; sys.sha256("#{@base_path_pod}/#{file}")
+        else                             sys.md5("#{@base_path_pod}/#{file}")
+        end
+        tell=SiSU_Screen::Ansi.new(@md.cmd,"#{dgst[1]} #{file}")
+        tell.warn if @md.cmd =~/[vVM]/
+        size=(File.size("#{@base_path_pod}/#{file}")/1024.00).to_s
+        kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
+        @manifest[:txt] << "#{file} #{id} #{kb}\n"
+        @manifest[:html] << %{<tr><th class="left"><p class="norm"><a href="../pod/#{file}">#{id}</a></p></th><td class="right"><p class="tiny"><a href="../pod/#{file}">#{file}</a> &nbsp;&nbsp;#{dgst[1]}<br />#{@url_brace.xml_open}<a href="#@base_url_pod/#{file}">#@base_url_pod/#{file}</a>#{@url_brace.xml_close}</p></td><td class="right"><p class="right">#{kb}</p>
+        </td></tr>\n} if kb and kb =~/\d+/
       end
       def languages(id,file)
         flv=@env.published_manifests?(@base_path)
@@ -134,7 +154,7 @@ module SiSU_Manifest
         flv.each do |l|
           lang=SiSU_Translate::Source.new(@md,@language,l[:l]).language_list
           @manifest[:txt] << "#{l[:m]} #{lang}\n"
-          @manifest[:html] << %{<tr><th class="left"><p class="bold"><a href="#{l[:m]}">#{lang}</a></p></th><td><p class="norm">#{lang}</p><p class="tiny"><a href="#@base_url/#{l[:m]}">#@base_url/#{l[:m]}</a></p></td><td class="right"><p class="right">&nbsp;</p></td></tr>\n}
+          @manifest[:html] << %{<tr><th class="left"><p class="bold"><a href="#{l[:m]}">#{lang}</a></p></th><td><p class="norm">#{lang}</p><p class="tiny">#{@url_brace.xml_open}<a href="#@base_url/#{l[:m]}">#@base_url/#{l[:m]}</a>#{@url_brace.xml_close}</p></td><td class="right"><p class="right">&nbsp;</p></td></tr>\n}
         end
       end
       def metadata(id,info)
@@ -145,52 +165,57 @@ module SiSU_Manifest
         elsif url =~/^\.\.\//;   url.gsub(/^\.(\.)?/,@env.url.root)
         else                     url
         end
-        @manifest[:html] << %{<tr><th class="left"><p class="norm"><a href="#{url}">#{lnk}</a></p><p class="tiny"><a href="#{static}">#{static}</a></p></th></tr>\n}
+        @manifest[:html] << %{<tr><th class="left"><p class="norm"><a href="#{url}">#{lnk}</a></p><p class="tiny">&nbsp;&nbsp;#{@url_brace.xml_open}<a href="#{static}">#{static}</a>#{@url_brace.xml_close}</p></th></tr>\n}
       end
       def output_tests
         if FileTest.file?("#@base_path/#{@md.fn[:toc]}")==true
-          id,file='HTML table of contents (linked to segmented text)',@md.fn[:toc]
-          summarize(id,file)
+          img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_toc.png" alt="TOC linked" /> '
+          id,file='table of contents (for segmented HTML text)',@md.fn[:toc]
+          summarize(id,file,img)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:doc]}")==true
-          id,file='HTML document (scroll)',@md.fn[:doc]
-          summarize(id,file)
+          img='<img border="0" height="15" width="15" src="../_sisu/image_sys/b_doc.png" alt="Full Text" /> '
+          id,file='full length document (HTML)',@md.fn[:doc]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_p]}")==true
+          img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_pdf.png" alt="PDF portrait" /> '
+          id,file='full length document (PDF portrait&nbsp;/ vertical - recommended for printing)',@md.fn[:pdf_p]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_l]}")==true
+          img='<img border="0" height="15" width="18" src="../_sisu/image_sys/b_pdf.png" alt="PDF landscape" /> '
+          id,file='full length document (PDF landscape&nbsp;/ horizontal - recommended for screen viewing)',@md.fn[:pdf_l]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:odf]}")==true
+          img='<img border="0" height="18" width="18" src="../_sisu/image_sys/b_odf.png" alt="ODF/ODT" /> '
+          id,file='full length document (ODF:ODT - Open Document Format)',@md.fn[:odf]
+          summarize(id,file,img)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:xhtml]}")==true
-          id,file='XHTML',@md.fn[:xhtml]
+          id,file='full length document (XHTML)',@md.fn[:xhtml]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:sax]}")==true
-          id,file='XML (SAX)',@md.fn[:sax]
+          id,file='full length document (XML SAX)',@md.fn[:sax]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:dom]}")==true
-          id,file='XML (DOM)',@md.fn[:dom]
-          summarize(id,file)
-        end
-        if FileTest.file?("#@base_path/#{@md.fn[:odf]}")==true
-          id,file='ODF:ODT (Open Document Format)',@md.fn[:odf]
-          summarize(id,file)
-        end
-        if FileTest.file?("#@base_path/#{@md.fn[:pdf_p]}")==true
-          id,file='PDF (portrait) - print bias',@md.fn[:pdf_p]
-          summarize(id,file)
-        end
-        if FileTest.file?("#@base_path/#{@md.fn[:pdf_l]}")==true
-          id,file='PDF (landscape) - screen view bias (colored links)',@md.fn[:pdf_l]
+          id,file='full length document (XML DOM)',@md.fn[:dom]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:plain]}")==true
-        if    @md.cmd =~/a/; id,file='plaintext Unix (UTF-8) (footnotes)',@md.fn[:plain]
-        elsif @md.cmd =~/e/; id,file='plaintext Unix (UTF-8) (endnotes)',@md.fn[:plain]
-        elsif @md.cmd =~/A/; id,file='plaintext dos (UTF-8) (footnotes)',@md.fn[:plain]
-        elsif @md.cmd =~/E/; id,file='plaintext dos (UTF-8) (endnotes)',@md.fn[:plain]
-        else                id,file='plaintext (UTF-8)',@md.fn[:plain]
+        if    @md.cmd =~/a/; id,file='full length document (plaintext Unix (UTF-8) with footnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/e/; id,file='full length document (plaintext Unix (UTF-8) with endnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/A/; id,file='full length document (plaintext dos (UTF-8) with footnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/E/; id,file='full length document (plaintext dos (UTF-8) with endnotes)',@md.fn[:plain]
+        else                id,file='full length document (plaintext (UTF-8))',@md.fn[:plain]
         end
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:concordance]}")==true
-          id,file='Concordance (wordmap)',@md.fn[:concordance]
+          id,file='Concordance file (HTML - wordmap, alphabetical wordlist)',@md.fn[:concordance]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fns}.tex")==true
@@ -219,24 +244,26 @@ module SiSU_Manifest
         end
       end
       def source_tests
-        if @md.fns =~/\._sst$/                                                  #% decide whether to extract and include requested/required documents
-          req=@md.fns.gsub(/(.+)?\._sst$/,'\1.composite.sst') #watch strange
-          if FileTest.file?("#@base_path/#{req}")==true
+        if @md.fns =~/\.ssm\.sst$/                                                  #% decide whether to extract and include requested/required documents
+          req=@md.fns
+          if FileTest.file?("#@base_path_src/#{req}")==true
             id,file='Markup Composite File (SiSU source)',req
             summarize_source(id,file)
           end
+        else
+          if FileTest.file?("#@base_path_src/#{@md.fns}")==true
+            id,file='Markup (SiSU source)',@md.fns
+            summarize_source(id,file)
+          end
         end
-        if FileTest.file?("#@base_path/#{@md.fns}")==true
-          id,file='Markup (SiSU source)',@md.fns
-          summarize_source(id,file)
+        if FileTest.file?("#@base_path_pod/#{@md.fn[:sisupod]}")==true
+          id,file='SiSU doc (zip)',@md.fn[:sisupod]
+          summarize_pod(id,file)
         end
-        if FileTest.file?("#@base_path/sisupod.zip")==true
-          id,file='SiSU doc (zip)','sisupod.zip'
-          summarize_source(id,file)
-        end
-        if FileTest.file?("#@base_path/#{@md.fnb}")==true and @md.fnb =~/\.kdi$/
+        if FileTest.file?("#@base_path/#{@md.fnb}")==true \
+        and @md.fnb =~/\.kdi$/
           id,file='Kdissert (.kdi source)',@md.fnb
-          summarize_source(id,file)
+          summarize_pod(id,file)
         end
       end
       def metadata_tests
@@ -324,11 +351,13 @@ module SiSU_Manifest
           id,info=@translate.date_valid,@md.dc_date_valid
           metadata(id,info)
         end
-        if @md.dc_language and @md.dc_language[:name]
+        if @md.dc_language \
+        and @md.dc_language[:name]
           id,info=@translate.language,@md.dc_language[:name]
           metadata(id,info)
         end
-        if @md.language_original and @md.language_original[:name]
+        if @md.language_original \
+        and @md.language_original[:name]
           id,info=@translate.language_original,@md.language_original[:name]
           metadata(id,info)
         end
@@ -422,14 +451,17 @@ module SiSU_Manifest
         end
       end
       def links_tests
-        if defined? @md.lnk and @md.lnk
+        if defined? @md.lnk \
+        and @md.lnk
           @md.lnk.each do |l|
             if defined? l[:say]
               target=if l[:url] !~/^\.(\.)?\//; 'external'
               else                              '_top'
               end
               url,lnk=l[:url],l[:say]
-              unless url.nil? or url.empty?; links(url,lnk,target)
+              unless url.nil? \
+              or url.empty?
+                links(url,lnk,target)
               end
             end
           end
@@ -439,17 +471,17 @@ module SiSU_Manifest
         begin
           id,file='',''
           vz=SiSU_Env::Get_init.instance.skin
-          #vz=SiSU_Viz::Skin.new
-          banner_table=if vz.banner_home_button_only !~ /http:\/\/www\.jus\.uio\.no\/sisu/ and vz.banner_home_button_only !~  /sisu\.home\.png/
+          banner_table=if vz.banner_home_button_only !~ /http:\/\/www\.jus\.uio\.no\/sisu/ \
+          and vz.banner_home_button_only !~  /sisu\.home\.png/
 <<WOK
 <table summary="band" width="100%" border="0" cellpadding="3" cellspacing="0">
-<tr><td align="left" bgcolor="#ffffff">#{vz.banner_home_button}</td><td width="60%"><p class="tiny"><a href="#@base_url/#{file}"><img border="0" height="12" width="12" src="#{vz.url_path_image}/bullet_red.png"  alt="TOC linked" />&nbsp;#@base_url/#{file}</a></p></td><td width="20%">#{@env.widget_static.search_form}</td><td><a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" src="#{vz.url_path_image}/sisu.png" alt="SiSU --&gt;" /></a></td></tr>
+<tr><td align="left" bgcolor="#ffffff">#{vz.banner_band}</td><td width="60%"><p class="tiny">#{@url_brace.xml_open}<a href="#@base_url/#{file}">#@base_url/#{file}</a>#{@url_brace.xml_close}</p></td><td width="20%">#{@env.widget_static.search_form}</td><td><a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" src="#{vz.url_path_image_sys}/sisu.png" alt="SiSU --&gt;" /></a></td></tr>
 </table>
 WOK
           else
 <<WOK
 <table summary="band" border="0" cellpadding="3" cellspacing="0">
-<tr><td align="left" bgcolor="#ffffff"><a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" src="#{vz.url_path_image}/sisu.png" alt="SiSU --&gt;" /></a></td><td><p class="tiny"><a href="#@base_url/#{file}"><img border="0" height="12" width="12" src="#{vz.url_path_image}/bullet_red.png"  alt="TOC linked" />&nbsp;#@base_url/#{file}</a></p></td><td>#{@env.widget_static.search_form}</td></tr>
+<tr><td align="left" bgcolor="#ffffff"><a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" src="#{vz.url_path_image_sys}/sisu.png" alt="SiSU --&gt;" /></a></td><td><p class="tiny">#{@url_brace.xml_open}<a href="#@base_url/#{file}">#@base_url/#{file}</a>#{@url_brace.xml_close}</p></td><td>#{@env.widget_static.search_form}</td></tr>
 </table>
 WOK
           end
@@ -464,12 +496,13 @@ SiSU manifest: #{@md.title}
 <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 <meta name="sourcefile" content="#{@md.fns}" />
 <link rel="generator" href="http://www.jus.uio.no/sisu" />
-<link rel="shortcut icon" href="../_sisu/image/rb7.ico" />
+<link rel="shortcut icon" href="../_sisu/image_sys/rb7.ico" />
 <link rel="stylesheet" href="../#{@env.path.style}/html.css" type="text/css" />
 </head>
 <body bgcolor="#ffffff" text="#000000" link="#003090" lang="en" xml:lang="en">
 #{banner_table}
 <h1 class="small">#{@md.dc_title}</h1>
+<p class="bold">#{@md.dc_creator}</p>
 <table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
 WOK
           published_versions
@@ -477,7 +510,7 @@ WOK
           @manifest[:html] <<<<WOK
 <h2 class="small"><a name="output">#{@translate.manifest_description_output}</a></h2>
 <table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
-<tr> <th class="left"><p class="bold">#{@translate.filename}</p></th><th class="left"><p class="bold">#{@translate.description}</p></th><th class="right"><p class="right"><b>#{@translate.file_size}</b></p><p class="tiny_right">(kB)</p></th></tr>
+<tr> <th class="left"><p class="bold">#{@translate.description}</p></th><th class="left"><p class="bold">#{@translate.filename}</p></th><th class="right"><p class="right"><b>#{@translate.file_size}</b></p><p class="tiny_right">(kB)</p></th></tr>
 
 WOK
           output_tests
@@ -514,6 +547,7 @@ WOK
           @manifest[:html] <<<<WOK
 </table>
 #{vz.credits_splash}
+#{vz.credits_sisu}
 </body>
 </html>
 WOK
