@@ -1,52 +1,59 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: plaintext text generation, stripped plaintext output (unix, linefeed)
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
 
- * Notes: tidy -ascii index.xml >> index.tidy
+ ** Description: plaintext text generation, stripped plaintext output (unix,
+     linefeed)
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_Plaintext
   require "#{SiSU_lib}/dal"
@@ -63,12 +70,18 @@ module SiSU_Plaintext
   class Source
     def initialize(opt)
       @opt=opt
-      if @opt.fns =~/(.+?)\.[_-]?sst$/
-        case @opt.cmd
-        when /[af]/; @@dostype='unix footnotes'
-        when /e/;    @@dostype='unix endnotes'
-        when /[AF]/; @@dostype='msdos footnotes'
-        when /E/;    @@dostype='msdos endnotes'
+       @@dostype=if @opt.fns =~/(.+?)\.(?:-|ssm\.)?sst$/
+        if @opt.mod.inspect =~ /--footnote/ \
+        and @opt.mod.inspect =~ /--dos/
+          'msdos footnotes'
+        elsif @opt.mod.inspect =~ /--endnote/ \
+        and @opt.mod.inspect =~ /--dos/
+          'msdos endnotes'
+        elsif @opt.mod.inspect =~ /--footnote/
+          'unix footnotes'
+        elsif @opt.mod.inspect =~ /--endnote/
+          'unix endnotes'
+        else 'unix footnotes'
         end
       else puts "#{sf} not a processed file type"
       end
@@ -146,36 +159,38 @@ module SiSU_Plaintext
       require "#{SiSU_lib}/defaults"
       require "#{SiSU_lib}/shared_txt"
       include SiSU_text_utils
-      @@endnotes_para=[]
-      @@plaintext={ :body=>[],:open=>[],:close=>[],:head=>[],:metadata=>[],:tail=>[],:endnotes=>[] }
+      @@endnotes={ :para=>[],:end=>[] }
       @@dp=nil
       def initialize(data,md)
         @data,@md=data,md
         @url_brace=SiSU_Viz::Skin.new.url_decoration
         @vz=SiSU_Env::Get_init.instance.skin
         @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
-        @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/ #m # 2004w18 pb pn removal added
+        @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/m # 2004w18 pb pn removal added
         @tab="\t"
-        @br=case md.cmd
-        when /[af]/
-          @@dostype='unix footnotes'
-          "\n"
-        when /e/
-          @@dostype='unix endnotes'
-          "\n"
-        when /[AF]/
+        @br=if md.mod.inspect =~ /--footnote/ \
+        and md.mod.inspect =~ /--dos/
           @@dostype='msdos footnotes'
           "\r\n"
-        when /E/
+        elsif md.mod.inspect =~ /--endnote/ \
+        and md.mod.inspect =~ /--dos/
           @@dostype='msdos endnotes'
           "\r\n"
-        else "\n"
+        elsif md.mod.inspect =~ /--footnote/
+          @@dostype='unix footnotes'
+          "\n"
+        elsif md.mod.inspect =~ /--endnote/
+          @@dostype='unix endnotes'
+          "\n"
+        else
+          @@dostype='unix footnotes'
+          "\n"
         end
+        @plaintext={ :body=>[],:open=>[],:close=>[],:head=>[],:metadata=>[],:tail=>[] }
       end
       def songsheet
-        @data=markup(@data)
-        publish
-        #@data.each { |x|  puts x.inspect if x =~/\[table/ }
+        plaintext=markup(@data)
+        publish(plaintext)
       end
       # Used for extraction of endnotes from paragraphs
       def extract_endnotes(para='')
@@ -194,13 +209,12 @@ module SiSU_Plaintext
         end
         notes=@n.flatten
         notes.each do |e|
-          util=if e.to_s =~/^\[[\d*+]+\]:/; SiSU_text_utils::Wrap.new(e.to_s,70,4,1)
-          else                              SiSU_text_utils::Wrap.new(e.to_s,70,1,1)
+          util=if e.to_s =~/^\[[\d*+]+\]:/; SiSU_text_utils::Wrap.new(e.to_s,78,4,1)
+          else                              SiSU_text_utils::Wrap.new(e.to_s,78,1,1)
           end
           wrap=util.line_wrap
           if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
             wrap.gsub!(/^(\s*)([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
-
 \\1[\\2]: \\3
 GSUB
                       )
@@ -210,14 +224,15 @@ GSUB
 GSUB
                       )
           end
-          @@plaintext[:endnotes] << wrap
-          @@endnotes_para << wrap
+          @@endnotes[:para] << "-#{wrap}"
+          @@endnotes[:end] << '' << wrap
         end
+        @@endnotes
       end
       def plaintext_metadata(meta)
-        util=SiSU_text_utils::Wrap.new(meta.text,70,15,1)
+        util=SiSU_text_utils::Wrap.new(meta.text,78,15,1)
         txt=util.line_wrap
-        @@plaintext[:metadata] <<= if meta.type == 'meta'
+        @plaintext[:metadata] <<= if meta.type == 'meta'
           <<WOK
 
 #{@tab}#{meta.el}: #{txt}
@@ -235,7 +250,7 @@ WOK
           "Source file:    #{@md.sc_filename}#{@br}Version number: #{@md.sc_number}#{@br}Version date:   #{@md.sc_date}#{@br}"
         else ''
         end
-        @@plaintext[:tail] <<<<WOK
+        @plaintext[:tail] <<<<WOK
 #@br
 Other versions of this document: #@br
 manifest:
@@ -262,37 +277,37 @@ WOK
         n=lv - 1
         n3=lv + 2
         lv=nil if lv == 0
-        extract_endnotes(para)
-        para.gsub!(/~[{\[]([\d*+]+)\s+(?:.+?)[}\]]~/,'[^\1]') # endnote marker marked up
         wrapped=if para[@regx]
           paragraph=para[@regx,2]
           if paragraph =~/<:i([1-9])>/
             m=$1.to_i
             paragraph.gsub!(/<:i#{m}>/,'')
-            util=SiSU_text_utils::Wrap.new(paragraph,70,m*2)
-          else util=SiSU_text_utils::Wrap.new(paragraph,70,0)
+            util=SiSU_text_utils::Wrap.new(paragraph,78,m*2)
+          else util=SiSU_text_utils::Wrap.new(paragraph,78,0)
           end
           util.line_wrap
         end
         if lv
           times=wrapped.length
-          times=70 if times > 70
-          @@plaintext[:body] << case lv
+          times=78 if times > 78
+          @plaintext[:body] << case lv
           when 1;      wrapped.upcase << @br << '*'*times << @br
           when 2..3;   wrapped.upcase << @br << '='*times << @br
           when 4;      wrapped.upcase << @br << '-'*times << @br
           when 5..6;   wrapped.upcase << @br << '.'*times << @br
           end
         else
-          @@plaintext[:body] << wrapped << @br # main text, contents, body KEEP
+          @plaintext[:body] << wrapped << @br # main text, contents, body KEEP
         end
-        if @@endnotes_para and @@dostype =~/footnote/ #edit out to switch off endnotes following paragraph to which they belong
-          @@plaintext[:body] << @br
-          @@endnotes_para.each {|e| @@plaintext[:body] << e << @br}
-        elsif @@endnotes_para and @@dostype =~/endnote/
-          @@plaintext[:body] << @br*2
+        if @@endnotes[:para] \
+        and @@dostype =~/footnote/ #edit out to switch off endnotes following paragraph to which they belong
+          @plaintext[:body] << @br
+          @@endnotes[:para].each {|e| @plaintext[:body] << e << @br}
+        elsif @@endnotes[:para] \
+        and @@dostype =~/endnote/
+          @plaintext[:body] << @br*2
         end
-        @@endnotes_para=[]
+        @@endnotes[:para]=[]
       end
       def markup(data)                                                       # Used for major markup instructions
         dir=SiSU_Env::Info_env.new(@md.fns)
@@ -306,31 +321,52 @@ WOK
           para.gsub!(/<!Th?¡.+/m,"#@br#{table_message}")
           para.gsub!(/.+?<-#>/,'')                                           # remove dummy headings (used by html) #check
           para.gsub!(/_\*\s+/,'* ')                                          # bullet markup, marked down
-          #para.gsub!(/<br(?: \/)?>/,"\n")                                   # introduces a bug
-          para.gsub!(/&#169;/,'©')                                           # bullet markup, marked down
-          para.gsub!(/&amp;/,'&')                                            # bullet markup, marked down
           para.gsub!(/<sup>(.+?)<\/sup>/,'^\1^')
           para.gsub!(/<sub>(.+?)<\/sub>/,'[\1]')
           para.gsub!(/<i>(.+?)<\/i>/,'/\1/')
           para.gsub!(/<b>(.+?)<\/b>/,'*\1*')
           para.gsub!(/<u>(.+?)<\/u>/,'_\1_')
+          unless para =~/<:code>/
+            para.gsub!(/\{(.+?)\}((?:https?|file|ftp):\/\/\S+|image)/,'\1 [link:] \2')
+            para.gsub!(/(^|\s)((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([.,]?(?:\s|$))/,"\\1#{@url_brace.txt_open}\\2#{@url_brace.txt_close}\\3")
+            para.gsub!(/_((?:https?|file|ftp):\/\/\S+)/,'\1')
+            extract_endnotes(para)
+            para.gsub!(/~[{\[]([\d*+]+)\s+(?:.+?)[}\]]~/,'[^\1]') # endnote marker marked up
+            para.gsub!(/&amp;/,'&')
+            para.gsub!(/&#033;/,'!')
+            para.gsub!(/&#035;/,'#')
+            para.gsub!(/&#042;/,'*')
+            para.gsub!(/&#045;/,'-')
+            para.gsub!(/&#047;/,'/')
+            para.gsub!(/&#095;/,'_')
+            para.gsub!(/&#123;/,'{')
+            para.gsub!(/&#125;/,'}')
+            para.gsub!(/&#126;/,'~')
+            para.gsub!(/&#169;/,'©')
+          end
           if para =~/<:(?:group|verse|alt|code)(?:-end)?>(?:\s+<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>)?/
+            if para =~/<:code>/ #code-block: angle brackets special characters
+              para.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _> _<
+              para.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _<_<
+            end
             para.gsub!(/<br(?: \/)?>/,"\n")                                   # watch
             para.gsub!(/<:(?:group|verse|alt|code)(?:-end)?>(?:\s+<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>)?/,'')
+          else para.gsub!(/<br(?: \/)?>/,"\n\n")                                   # watch introduces a bug
           end
           para.gsub!(/<:p[bn]>/,'')                                         # remove page breaks
           para.gsub!(/^\s*<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/,'') # remove empty lines - check
-          para.gsub!(/(^|\s)(https?:\/\/[^"><]+?)([,.:;"><]?(?:\s|$))/,"\\1#{@url_brace.txt_open}\\2#{@url_brace.txt_close}\\3")
+          para.gsub!(/(^|\s)[_\\]((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([.,]?(?:\s|$))/,'\1\2\3')
           para.gsub!(/<a href=".+?">(.+?)<\/a>/m,'\1')
           para.gsub!(/<:name#\S+?>/,'')                                       # remove name links
           para.gsub!(/&nbsp;/,' ')                                            # decide on
-          para.gsub!(/\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
-          para.gsub!(/^\{\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*\}\S+/,'[image: "\1"]')
+          para.gsub!(/(?:^|[^_\\])\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|file|ftp):\/\/\S+|image)/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
+          para.gsub!(/(?:^|[^_\\])\{\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*\}\S+/,'[image: "\1"]')
+          #para.gsub!(/^\{\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*\}\S+/,'[image: "\1"]')
           wordlist=para.scan(/\S+/)
           if para =~/^0~(\S+)\s+(.+?)\Z/m # for headers
             d_meta=SiSU_text_utils::Header_scan.new(@md,para).meta
             if d_meta; plaintext_metadata(d_meta)
-	          end
+           end
           end
           if para !~/(^0~|<ENDNOTES>|<EOF>)/
             if para =~@regx #/.+?<~\d+;\w\d+;\w\d+>.*/ #watch change
@@ -340,7 +376,8 @@ WOK
             @sto=Split_text_object.new(para).lev_segname_para_ocn
             ### problem in scroll, it appears tables are getting paragraph numbers
             m=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
-            if para =~m and para=~/\S+/
+            if para =~m \
+            and para=~/\S+/
               para=case @sto.format
               when /^(1)~(?:(\S+))?/
                 plaintext_structure(para,$1,@sto.ocn,$2)
@@ -384,14 +421,17 @@ WOK
                 para
               end
             elsif para =~/#{table_message}/
-              @@plaintext[:body] << para << @br
-            elsif para =~/(Note|Endnotes?)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
-            elsif para =~/(MetaData)/ and para =~/<~(\d+);[um]\d+;\w\d+><#@dp:#@dp>$/ #debug 2003w46 add rc info ####suspect visit
+              @plaintext[:body] << para << @br
+            elsif para =~/(Note|Endnotes?)/ \
+            and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
+            elsif para =~/(MetaData)/ \
+            and para =~/<~(\d+);[um]\d+;\w\d+><#@dp:#@dp>$/ #debug 2003w46 add rc info ####suspect visit
               #formatMono=MonoSiSU.new('<br /><a name="metadata">MetaData</a>')
               #para=formatMono.bold_para
-            elsif para.include? 'Owner Details' and para !~/<~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
+            elsif para.include? 'Owner Details' \
+            and para !~/<~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
               #formatMono=MonoSiSU.new('<br /><a name="owner.details">Owner Details</a>')
-              #@@plaintext[:owner_details]=formatMono.bold_para
+              #@plaintext[:owner_details]=formatMono.bold_para
               #para=''
             elsif para =~/(¡|<!Th?)/ #tables !
             elsif para =~/(.*)<!#!>(.*)/
@@ -399,7 +439,8 @@ WOK
               format_text=Format_text_object.new(one,two)
               para=format_text.seg_no_paranum
             end
-            para='' if (para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
+            para='' if (para =~/<a name="n\d+">/ \
+            and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
             case para
             when /<:i[1-9]>/
               if para =~/.*<:#>.*$/m
@@ -419,21 +460,22 @@ WOK
             para.gsub!(/<:\S+>/,' ') if para ## Clean Prepared Text
           end
         end
+        @plaintext
       end
-      def publish
-        divider="="
+      def publish(plaintext)
+        divider='='
         content=[]
-        content << @@plaintext[:open]
-        content << @@plaintext[:head]
-        content << @@plaintext[:body]
-        content << @@plaintext[:endnotes] if @@dostype =~/endnotes/
-        content << "#@br#{divider*70}#@br"
-        content << @@plaintext[:metadata]
-        content << "#@br#{divider*70}#@br" if @md.stmp =~/\w+/ #not used?
-        content << @@plaintext[:owner_details] if @md.stmp =~/\w+/ #not used?
-        content << @@plaintext[:tail]
+        content << plaintext[:open]
+        content << plaintext[:head]
+        content << plaintext[:body]
+        content << @@endnotes[:end] if @@dostype =~/endnotes/
+        content << "#@br#{divider*78}#@br"
+        content << plaintext[:metadata]
+        content << "#@br#{divider*78}#@br" if @md.stmp =~/\w+/ #not used?
+        content << plaintext[:owner_details] if @md.stmp =~/\w+/ #not used?
+        content << plaintext[:tail]
         Output.new(content,@md).plaintext
-        @@plaintext[:head],@@plaintext[:body],@@plaintext[:tail],@@plaintext[:metadata]=[],[],[],[]
+        @@endnotes={ :para=>[],:end=>[] }
       end
     end
     class Output <Source
@@ -444,19 +486,22 @@ WOK
       end
       def plaintext                                                            #%plaintext output
         SiSU_Env::SiSU_file.new(@md).mkdir
-        filename_plaintext=SiSU_Env::SiSU_file.new(@md,@md.fn[:plain]).mkfile
+        file_plaintext=SiSU_Env::SiSU_file.new(@md,@md.fn[:plain]).mkfile
         @sisu=[]
         @content.each do |para|                                                # this is a hack
-          if para.class == Array and para.length > 0
+          if para.class == Array \
+          and para.length > 0
             para.each do |line|
               line.gsub!(/\s+$/m,'')
-              filename_plaintext.puts line           #unix plaintext
+              file_plaintext.puts line           #unix plaintext
             end
-          else filename_plaintext.puts para           #unix plaintext # /^([*=-]|\.){5}/
+          else file_plaintext.puts para           #unix plaintext # /^([*=-]|\.){5}/
           end
         end
+        file_plaintext.close
       end
     end
   end
 end
 __END__
+&#033;\|&#035;\|&&#042;\|&#045;\|&#047;\|&#095;\|&#123;\|&#125;\|&#126;\|&#
