@@ -1,79 +1,100 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: modules shared by db and flatfile output generators, mostly xml/xhtml/html formatting
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: modules shared by db and flatfile output generators, mostly
+    xml/xhtml/html formatting
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_Format_Shared
   require "#{SiSU_lib}/defaults"
   include SiSU_Viz
   class CSS_Format
     require "#{SiSU_lib}/defaults"
-    def initialize(content=nil,id=nil,ocnd='',ocns='',lv='',hname=nil)
+    @@fns=nil
+    def initialize(md,content=nil,col=nil,en=nil)
       content.gsub!(/<:i[12]>/,'')
-      @content=content
-      @id=@ocn=id
-      @ocnd,@ocns=ocnd,ocns
-      @lv=@notenumber=lv.to_s
-      @hname=hname.to_s
+      @md,@content=md,content
+      @id=@ocn=col[:id]
+      @ocnd,@ocns=col[:ocnd],col[:ocns]
+      @notenumber=en
+      @lv=col[:lev].to_s
+      @@hname=if @md.fns != @@fns
+        @@fns=@md.fns
+        ''
+      end
+      @hname=if col[:seg] \
+      and not col[:seg].to_s.empty?
+        @@hname=col[:seg].to_s
+      else @@hname
+      end
       @tab="\t"
       @url_brace=SiSU_Viz::Skin.new.url_decoration
       # lots introduced to do html tables in db
       @@tablehead,@@tablefoot=[],[]
       @vz=SiSU_Env::Get_init.instance.skin
+      @env=SiSU_Env::Info_env.new(@md.fns)
+      @base_url="#{@env.url.root}/#{@md.fnb}/#@hname.html"
     end
     def urls(data)
       @words=[]
       data.each do |word|
-        @words << if word=~/\{(.+?)\}((?:https?|ftp)\S+|image)/
-          if word =~/\{(.+?)\}((?:https?|ftp)\S+|image)([.,](?:\s|$))/
-            m,u,d=/\{(.+?)\}((?:https?|ftp)\S+|image)([.,](?:\s|$))/.match(word).captures
-          else m,u=/\{(.+?)\}((?:https?|ftp)\S+|image)/.match(word).captures
+        @words << if word=~/\{(.+?)\}((?:https?|file|ftp)\S+|image)/
+          if word =~/\{(.+?)\}((?:https?|file|ftp)\S+|image)([;.,](?:\s|$))/
+            m,u,d=/\{(.+?)\}((?:https?|file|ftp)\S+|image)([;.,](?:\s|$))/.match(word).captures
+          else m,u=/\{(.+?)\}((?:https?|file|ftp)\S+|image)/.match(word).captures
             d=''
           end
-          case m
+          word=case m
           when /\.png|\.jpg|\.gif|c=|\d+x\d+/
             w,h=/(\d+)x(\d+)/.match(m).captures if m =~/\d+x\d+/
             w=%{width="#{w}"} if w
@@ -84,57 +105,50 @@ module SiSU_Format_Shared
             #image_path=if @md.fns =~/\.-ss[tm]$/; @env.url.images_external
             #else                                  @env.url.images_local
             #end
-            ins=if u and u.strip !~/^image$/
+            ins=if u \
+            and u.strip !~/^image$/
               %{<a href="#{u}">[#{png}]</a>#{caption}}
             else %{[#{png}] #{caption}}
             end
-            word.gsub!(/\{.+?\}((?:https?|ftp)\S+|image)/,ins)
+            word.gsub!(/\{.+?\}((?:https?|file|ftp)\S+|image)/,ins)
           else
             link=m[/(.+)/m]
             png=m.scan(/\S+/)[0].strip
             link=link.strip
             ins=%{<a href="#{u}">#{link}</a>#{d}}
             #ins=%{#{link} <a href="#{u}">[link]</a>#{d}}
-            word.gsub!(/\{.+?\}(?:https?|ftp)\S+/,ins)
+            word.gsub!(/\{.+?\}(?:https?|file|ftp)\S+/,ins)
           end
-          word
         else word
         end
         word
       end
-      @words
+      @words=@words.join(' ')
     end
     def markup(para)
-      if para =~/\{.+?\}((?:http|ftp)\S+|image)/
-        @word_mode=para.scan(/\{.+?\}(?:(?:https?|ftp)\S+|image)|\S+/)
-        word_mode=urls(para)
-        words=word_mode.join(' ')
-        para.gsub!(/.+/,words)
-      end
-      if (para !~/(\"\w+:\/\/\S+?\"|>\s*\w+:\/\/\w+?\S*<)/) #url markup http etc.
-        if para=~/\w+:\/\/\S+?\.\S+?[.,] /
-          para.gsub!(/(\w+:\/\/\S+?\.\S+?)([.,] )/,%{#{@url_brace.xml_open}<a href="\\1" target="_top">\\1</a>#{@url_brace.xml_close}\\2}) #full stops ! have been a bother
-        else
-          para.gsub!(/(\w+:\/\/\S+?\.\S+)/,%{#{@url_brace.xml_open}<a href="\\1" target="_top">\\1</a>#{@url_brace.xml_close}})
-        end
-      end
-      if (para =~/[ ^](?:https?|ftp):\/\/\S+/) #url markup http leftovers watch carefully may accept too much 2004w46
-        if para=~/([ ^])((?:https?|ftp):\/\/\S+?)([\.,] )/
-        para.gsub!(/([ ^])((?:https?|ftp):\/\/\S+?)([\.,] )/,%{\\1#{@url_brace.xml_open}<a href="\\2" target="_top">\\2</a>#{@url_brace.xml_close}\\3}) #full stops ! have been a bother
-        else
-          para.gsub!(/([ ^])((?:https?|ftp):\/\/\S+)/,%{\\1#{@url_brace.xml_open}<a href="\\2" target="_top">\\2</a>#{@url_brace.xml_close}})
+      if para !~/^<:code>/
+        if para =~/\{.+?\}((?:https?|file|ftp)\S+|image)/
+          wm=para.scan(/\{.+?\}(?:(?:https?|file|ftp)\S+|image)|\S+/)
+          words=urls(wm)
+          para.gsub!(/.+/m,words)
         end
+        para.gsub!(/\b[_\\]((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/,'<a href="\1" target="_top">\1</a>\2') #http ftp matches escaped, no decoration
+        para.gsub!(/((?:^|\s)[}])((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/,'\1<a href="\2" target="_top">\2</a>\3') #special case \{ e.g. \}http://url
+        para.gsub!(/(^|\s)((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?=\s|$))/,%{\\1#{@url_brace.xml_open}<a href="\\2" target="_top">\\2</a>#{@url_brace.xml_close}\\3}) #http ftp matches with decoration
+      else
+        para.gsub!(/(^|[^}])_</m,'\1&lt;'); para.gsub!(/(^|[^}])_>/m,'\1&gt;') #code-block: angle brackets special characters
+        para.gsub!(/(^|[^}])_</m,'\1&lt;'); para.gsub!(/(^|[^}])_>/m,'\1&gt;')
       end
       para
     end
     def paragraph
       %{#{@tab*1}<p class="h#@lv" id="#@ocn" type="substantive" header="#@hname">\n#{@tab*2}#@content\n#{@tab*1}</p>\n}  << "\n"
     end
-    def endnote
+    def endnote #used only by db
       @content=markup(@content)
       <<GSUB
 #{@tab*1}<p class="endnote" name="note_#@notenumber" from="#@ocn">
-#{@tab*2}<a name="_#@notenumber" href="#-#@notenumber">#@notenumber.</a> <note>#@content</note>
+#{@tab*2}<a href="#@base_url#-#@notenumber" name="_#@notenumber">#@notenumber.</a> <note>#@content</note>
 #{@tab*1}</p>
 GSUB
     end
