@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: common file for xml generation
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: common file for xml generation
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_text_parts
   class Split_text_object
@@ -337,21 +345,33 @@ module SiSU_XML_munge
       end
     end
     def markup(para='')
-      wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
-      para=tidywords(wordlist).join(' ').strip
-      para.gsub!(/(^|\s+)<\s+/,'\1&lt; ')
-      para.gsub!(/\s+>(\s+|$)/,' &gt;\1')
+      #if para !~/^<:code>/
+        wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
+        para=tidywords(wordlist).join(' ').strip
+      #end
+      para.gsub!(/(^|\s+)<\s+/,'\1&lt; '); para.gsub!(/\s+>(\s+|$)/,' &gt;\1')
       para.gsub!(/<:pb>\s*/,'')
       para.gsub!(/<+[-~]#>+/,'')
       para.gsub!(/<0;\w\d+;[um]\d+><#@dp:#@dp>/,'')
-      #embeds a red-bullet image -->
-      #para.gsub!(/^(<:i[1-9]>\s*_\*)\s+/,'\1 <image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="/usr/share/sisu/image/bullet_red.png" width="12" height="12" alt="*" /> ')
-      #para.gsub!(/^_\*\s+/,'<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="/usr/share/sisu/image/bullet_red.png" width="12" height="12" alt="*" /> ')
-      para.gsub!(/(^|\s)\{\s*(\S+?\.(?:jpg|png|gif))\s+(\d+)x(\d+)(\s+[^}]+)?\}(https?:\/\/\S+)/,%{\\1<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\2" width="\\3" height="\\4" />[\\2] \\5})
-      para.gsub!(/(^|\s)\{\s*(\S+?\.(?:jpg|png|gif))(\s+[^}]+)?\}(https?:\/\/\S+)/,%{\\1<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\2"/>\\2})
-      para.gsub!(/(^|\s)\{([^}]+)\}(https?:\/\/[^"><]+?)([,.:;"><]?(?:\s|$))/,'\1<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:href="\3">\2</link>\4')
-      para.gsub!(/(^|\s)(https?:\/\/[^"><]+?)([,.:;"><]?(?:\s|$))/,%{\\1#{@url_brace.xml_open}<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:href="\\2">\\2</link>#{@url_brace.xml_close}\\3})
-      para.gsub!(/&nbsp;/,' ') #clean
+      if para !~/^<:code>/
+        #embeds a red-bullet image -->
+        para.gsub!(/(?:^|[^_\\])\{\s*(\S+?\.(?:jpg|png|gif))\s+(\d+)x(\d+)(\s+[^}]+)?\}(https?:\/\/\S+)/,
+	  %{<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\1" width="\\2" height="\\3" />[\\1] \\4})
+        para.gsub!(/(?:^|[^_\\])\{\s*(\S+?\.(?:jpg|png|gif))(\s+[^}]+)?\}(https?:\/\/\S+)/,
+	  %{<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\1"/>\\1})
+        para.gsub!(/(^|\s)\{([^}]+)\}(https?:\/\/[^"><]+?)([,.:;"><]?(?=\s|$))/,
+          '\1<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:href="\3">\2</link>\4') #watch, compare html_tune
+        para.gsub!(/(^|\s)((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?=\s|$))/,
+          %{\\1#{@url_brace.xml_open}<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:href="\\2">\\2</link>#{@url_brace.xml_close}\\3})
+        para.gsub!(/\b[_\\]((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/,
+	  '<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:href="\1">\1</link>\2') #escaped urls not linked, deal with later
+        para.gsub!(/&nbsp;/,'&#160;')
+        #para.gsub!(/&nbsp;/,' ') #clean
+      else
+        para.gsub!(/(^|[^}])_</m,'\1&lt;'); para.gsub!(/(^|[^}])_>/m,'\1&gt;') #code-block: angle brackets special characters
+        para.gsub!(/(^|[^}])_</m,'\1&lt;'); para.gsub!(/(^|[^}])_>/m,'\1&gt;')
+        para.gsub!(/&nbsp;/,'&#160;')
+      end
       para
     end
     def markup_light(para='')
@@ -364,9 +384,33 @@ module SiSU_XML_munge
       para.gsub!(/<[-~]#>/,'')
       para.gsub!(/(^|\s)&\s+/,'\1&amp; ') #sort
       para.gsub!(/&([^;]{1,5})/,'&amp;\1') #sort, rough estimate, revisit #WATCH found in node not sax
-      para.gsub!(/\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/,
+      para.gsub!(/(?:^|[^_\\])\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|file|ftp):\/\/\S+|image)/,
         "<image.path>#{@dir.url.images_local}\/\\1</image.path>")
-      para.gsub!(/&nbsp;/,' ')
+      para.gsub!(/&nbsp;/,'&#160;')
+      #para.gsub!(/&nbsp;/,' ') #clean
+      wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
+      para=tidywords(wordlist).join(' ').strip
+      para
+    end
+    def markup_fictionbook(para='')
+      para.gsub!(/~\{([\d*+]+).+?\}~/,'[\1]')
+      para.gsub!(/\/\{(.+?)\}\//,'<i>\1</i>')
+      para.gsub!(/[*!]\{(.+?)\}[*!]/,'<b>\1</b>')
+      para.gsub!(/_\{(.+?)\}_/,'<u>\1</u>')
+      para.gsub!(/-\{(.+?)\}-/,'<del>\1</del>')
+      para.gsub!(/<br(\s*\/)?>/,'<br />')
+      para.gsub!(/<:pb>\s*/,'')
+      para.gsub!(/<[-~]#>/,'')
+      #temporary -->
+      para.gsub!(/<:\S+?>/,'')
+      #<-- temporary
+      para.gsub!(/<[-~]#>/,'')
+      para.gsub!(/(^|\s)&\s+/,'\1&amp; ') #sort
+      para.gsub!(/&([^;]{1,5})/,'&amp;\1') #sort, rough estimate, revisit #WATCH found in node not sax
+      para.gsub!(/(?:^|[^_\\])\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|file|ftp):\/\/\S+|image)/,
+        "<image.path>#{@dir.url.images_local}\/\\1</image.path>")
+      para.gsub!(/&nbsp;/,'&#160;')
+      #para.gsub!(/&nbsp;/,' ') #clean
       wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
       para=tidywords(wordlist).join(' ').strip
       para
@@ -374,6 +418,9 @@ module SiSU_XML_munge
     def markup_group(para='')
       para.gsub!(/</,'&lt;'); para.gsub!(/>/,'&gt;')
       para.gsub!(/&lt;:?br(?:\s+\/)?&gt;/,'<br />')
+      para.gsub!(/&lt;(link xmlns:xlink=".+?")&gt;/,'<\1>')
+      para.gsub!(/&lt;(\/link)&gt;/,'<\1>')
+      para.gsub!(/&lt;(\/?en)&gt;/,'<\1>')
       para
     end
   end
@@ -392,15 +439,6 @@ module SiSU_XML_tags #Format
       if @md.dc_title                                                            # DublinCore 1 - title
         @rdf_title=%{    dc.title="#{seg_name}#{@md.dc_title}"\n}
         @dc_title=%{  <meta name="dc.title" content="#{seg_name}#{@md.dc_title}" />\n}
-        #if @md.subtitle
-        #  @rdf_title=%{    dc.title="#{seg_name}#{@md.title} - #{@md.subtitle}"\n}
-        #  @title=%{<meta name="dc.title" } +
-        #    %{content="#{seg_name}#{@md.title} - #{@md.subtitle}" />\n}
-        #else
-        #  @rdf_title=%{    dc.title="#{seg_name}#{@md.title}"\n}
-        #  @title=%{<meta name="dc.title" } +
-        #    %{content="#{seg_name}#{@md.title}" />\n}
-        #end
       end
       if @md.dc_creator                                                          # DublinCore 2 - creator/author (author)
         @rdf_creator=%{    dc.creator="#{@md.dc_creator}"\n}
@@ -471,11 +509,13 @@ module SiSU_XML_tags #Format
         content=meta_content_clean(@md.dc_source)
         @dc_source=%{  <meta name="dc.source" content="#{content}" />\n}
       end
-      if @md.dc_language[:name]                                                  # DublinCore 12 - language (English)
+      if @md.dc_language \
+      and @md.dc_language[:name]                                                  # DublinCore 12 - language (English)
         @rdf_language=%{    dc.language="#{@md.dc_language[:name]}"\n}
         @dc_language=%{  <meta name="dc.language" content="#{@md.dc_language[:name]}" />\n}
       end
-      if @md.language_original[:name]
+      if @md.language_original \
+      and @md.language_original[:name]
         @rdf_language_original=%{    dc.language="#{@md.language_original[:name]}"\n}
         @language_original=%{  <meta name="dc.language" content="#{@md.language_original[:name]}" />\n}
       end
