@@ -1,52 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: simple xml representation (dom style)
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
+ ** Description: simple xml representation (dom style)
 
- * Notes: tidy -xml sax.xml >> index.tidy
 =end
 module SiSU_simple_xml_model_dom
   require "#{SiSU_lib}/defaults"
@@ -230,7 +236,11 @@ WOK
           xml_element="<heading#{lv}>"
           3.downto(lv) do |x|
             y=x - 1
-            @@xml[:body] << "#{@tab*5}</content>\n" if @cont[1] or @cont[2] or @cont[3]
+            if @cont[1] \
+            or @cont[2] \
+            or @cont[3]
+              @@xml[:body] << "#{@tab*5}</content>\n"
+            end
             @cont[1]=false if @cont[1]
             @cont[2]=false if @cont[2]
             @cont[3]=false if @cont[3]
@@ -271,7 +281,10 @@ WOK
             end
             @cont[1]=true
           when 5
-            @@xml[:body] << "#{@tab*5}</content>\n" if @cont[2] or @cont[1]
+            if @cont[2] \
+            or @cont[1]
+              @@xml[:body] << "#{@tab*5}</content>\n"
+            end
             if @copen[3] == true  #6{
               [3,2].each { |v| @@xml[:body] << "#{@tab*n}</contents#{v}>\n" }
             elsif @copen[2] == true #5{
@@ -279,7 +292,11 @@ WOK
             end
             @cont[2]=true
           when 6
-            @@xml[:body] << "#{@tab*5}</content>\n" if @cont[3] or @cont[2] or @cont[1]
+            if @cont[3] \
+            or @cont[2] \
+            or @cont[1]
+              @@xml[:body] << "#{@tab*5}</content>\n"
+            end
             [3].each { |v| @@xml[:body] << "#{@tab*n}</contents#{v}>\n" } if @copen[3]
             @cont[3]=true
           end
@@ -340,7 +357,7 @@ WOK
           para.gsub!(/<[-~]#>/,'')
           para.gsub!(/<br\/?>/,'<br />')
           para.gsub!(/<:pb>\s*/,'')
-          para.gsub!(/\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/,
+          para.gsub!(/\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|file|ftp):\/\/\S+|image)/,
             "<image.path>#{dir.url.images_local}/\\1</image.path>")
           para.gsub!(/&nbsp;/,' ')
           para=SiSU_document_structure::Structure.new(@md,para).structure
@@ -348,9 +365,12 @@ WOK
           if para =~/\A(?:@|0~)(\S+?):?\s+(.+?)\Z/m
             d_meta=SiSU_text_utils::Header_scan.new(@md,para).meta
             if d_meta; xml_head(d_meta)
-	          end
+            end
+          end
+          if @rcdc==false \
+          and (para =~/~metadata/ or para =~/^1~meta\s+Document Information/)
+            @rcdc=true
           end
-          @rcdc=true if @rcdc==false and (para =~/~metadata/ or para =~/^1~\s+Document Information/)
           if para !~/(^0~|^@\S+?:|<ENDNOTES>|<EOF>)/
             @sto=SiSU_text_parts::Split_text_object.new(@md,para).lev_segname_para
             unless @rcdc
@@ -415,16 +435,21 @@ WOK
                     @@xml[:body] << table_structure(para)
                   else #xml_structure
                     xml_markup(para)
-                    @@xml[:body] << %{#{@tab*6}<object>} << "\n" if para[@regx] and para[@regx,2]
+                    if para[@regx] \
+                    and para[@regx,2]
+                      @@xml[:body] << %{#{@tab*6}<object>} << "\n"
+                    end
                     @@xml[:body] << "#{@tab*7}<text>#{para[@regx,2]}</text>\n" if para[@regx,2] # main text, contents, body KEEP
                     @@xml[:body] << "#{@tab*6}</object>" << "\n" if para[@regx]
                   end
                 end
               elsif para =~/(Note|Endnotes?)/
-              elsif para =~/(MetaData)/ and para =~/<~\d+;[m]\d+;\w\d+><#{@@dp}:#{@@dp}>$/ #debug 2003w46 add rc info
+              elsif para =~/(MetaData)/ \
+              and para =~/<~\d+;[m]\d+;\w\d+><#{@@dp}:#{@@dp}>$/ #debug 2003w46 add rc info
                 format_scroll=Format_scroll.new(@md,'<br /><a name="metadata">MetaData</a>')
                 para=format_scroll.bold_para
-              elsif para =~/(Owner Details)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/
+              elsif para =~/(Owner Details)/ \
+              and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/
                 format_scroll=Format_scroll.new(@md,'<br /><a name="owner.details">Owner Details</a>')
                 @@xml[:owner_details]=format_scroll.bold_para
                 para=''
@@ -433,7 +458,10 @@ WOK
                 format_text=Format_text_object.new(one,two)
                 para=format_text.seg_no_paranum
               end
-              para='' if para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
+              if para =~/<a name="n\d+">/ \
+              and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
+                para=''
+              end
               if para =~/.*<:#>.*$/
                 para=case para
                 when /<:i1>/
