@@ -1,52 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: simple xml representation (node style)
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
+ ** Description: simple xml representation (node style)
 
- * Notes: tidy -xml sax.xml >> index.tidy
 =end
 module SiSU_simple_xml_model_node
   require "#{SiSU_lib}/defaults"
@@ -222,9 +228,11 @@ WOK
         end
         if lv.to_s =~/^[1-6]/; @@current=lv
         end
-        if o.node == 1 or lv == 1
+        if o.node == 1 \
+        or lv == 1
           @@parent[:node][o.node]=0
-        elsif @@current == lv and @@current !=nil
+        elsif @@current == lv \
+        and @@current !=nil
           if @node[:no][lv-1] != nil
             @@parent[:node][o.node]=@node[:no][lv-1]
           elsif @node[:no][lv-2] != nil
@@ -234,12 +242,14 @@ WOK
           else puts 'error'
           end
         elsif lv == nil
-          if o.ocn.class == Fixnum and @@current
+          if o.ocn.class == Fixnum \
+          and @@current
             @@parent[:node][o.node]=@node[:no][@@current]
           end
         else puts 'error'
         end
-        if @@current == lv and @@current !=nil
+        if @@current == lv \
+        and @@current !=nil
           if @node[:ocn][lv-1] != nil
             @@parent[:ocn][o.ocn]=@node[:ocn][lv-1]
           elsif @node[:ocn][lv-2] != nil
@@ -249,7 +259,8 @@ WOK
           else puts 'error'
           end
         elsif lv == nil
-          if o.ocn.class == Fixnum and @@current
+          if o.ocn.class == Fixnum \
+          and @@current
             @@parent[:ocn][o.ocn]=@node[:ocn][@@current]
           end
         else puts 'error'
@@ -405,15 +416,18 @@ WOK
             if para =~/\A(?:@|0~)(\S+?):?\s+(.+?)\Z/m # for headers
               d_meta=SiSU_text_utils::Header_scan.new(@md,para).meta
               if d_meta; xml_head(d_meta)
-	            end
+              end
             end
           end
         end
         obj.each do |o|
           para=o.txt unless o.txt =~/^%% / #comments are lost, consider
           if para
-            @rcdc=true if @rcdc==false and (para =~/~metadata/ or para =~/^1~\s+Document Information/)
+            if @rcdc==false \
+            and (para =~/~metadata/ or para =~/^1~meta\s+Document Information/)
             if para !~/(^0~|^@\S+?:|^\s*$|<ENDNOTES>|<EOF>)/
+              @rcdc=true
+            end
               @sto=SiSU_text_parts::Split_text_object.new(@md,para).lev_segname_para
               unless @rcdc
                 format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[12]|null/
@@ -451,7 +465,11 @@ WOK
         obj.each do |o|
           para=o.txt unless o.txt =~/^%% / #comments are lost, consider
           if para
-            @rcdc=true if @rcdc==false and (para =~/~metadata/ or para =~/^1~\s+Document Information/)
+            if @rcdc==false \
+            and (para =~/~metadata/ \
+            or para =~/^1~meta\s+Document Information/)
+              @rcdc=true
+            end
             if para !~/(^0~|^@\S+?:|^\s*$|<ENDNOTES>|<EOF>)/
               @sto=SiSU_text_parts::Split_text_object.new(@md,para).lev_segname_para
               unless @rcdc
@@ -491,7 +509,10 @@ WOK
                   else xml_structure(o,para,nil,nil)
                   end
                 end
-                para='' if para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
+                if para =~/<a name="n\d+">/ \
+                and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
+                  para=''
+                end
                 if para =~/.*<:#>.*$/
                   para=case para
                   when /<:i1>/
