@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: texinfo formatting template
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: texinfo formatting template
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module TexInfoFormat
   @@table_pg_break_counter=1
@@ -82,6 +90,8 @@ module TexInfoFormat
       author=@md.dc_creator if @md.dc_creator
       author ||=''
       author.gsub!(/[\*]/,'') #if author
+      v=SiSU_Env::Info_version.new.get_version
+      #(version @value{VERSION} #{v[:version]}, @value{UPDATED} #{v[:date]})
       head =<<WOK
 \\input texinfo   @c -*-texinfo-*-
 @comment $Id$
@@ -90,10 +100,9 @@ module TexInfoFormat
 @settitle #{title} @value{VERSION}
 @syncodeindex pg cp
 @comment %**end of header
-@c {{{ 2
+@c %% 2
 @copying
-SiSU in texinfo version of #{title}
-(version @value{VERSION}, @value{UPDATED})
+SiSU texinfo of #{title}
 
 Copyright @copyright{} #{year} #{author}.
 
@@ -109,7 +118,7 @@ Copyright #{author}, generated by ``SiSU''
 WOK
       if @md.subtitle
         titlepage=<<WOK
-@c {{{ 3
+@c %% 3
 @titlepage
 @title #{title} #{subtitle}
 @author #{author}
@@ -121,7 +130,7 @@ WOK
 WOK
       else
         titlepage=<<WOK
-@c {{{ 3
+@c %% 3
 @titlepage
 @title #{title}
 @value{VERSION}, @value{UPDATED}
@@ -141,7 +150,7 @@ WOK
       @one=@one.gsub(/<(br|p|i)>|<\/\s*(br|p|i)>|<(br|p)\s*\/>/," #{@@tex_backslash*2} ")
       @one.gsub!(/\$/,"\\$")
       @one.gsub!(/[,]\s*/,' - ')
-      "@c {{{ 4\n" +
+      "@c %% 4\n" +
         "@ifnottex\n" +
         "@node Top\n" +
         "@top #@one\n\n" +
@@ -193,7 +202,7 @@ WOK
       dc_coverage="Coverage: #{dc_coverage}\n\n" if dc_coverage
       dc_rights="Rights: #{dc_rights}\n\n" if dc_rights
       "@node Dublin Core\n" +
-        "@chapter Dublin Core\n" +
+        "@unnumbered Dublin Core\n" +
         "@cindex chapter, Dublin Core\n\n" +
         "#{dc_title}" +
         "#{dc_creator}" +
@@ -217,91 +226,80 @@ WOK
         "\n\n"
     end
     def tail
-     "@c {{{ 6\n" +
+     "@c %% 6\n" +
       "@node Index\n" +
       "@unnumbered Index\n" +
       "@printindex cp\n\n" +
       "@bye"
     end
+    def clean(para)
+      para.gsub!(/<\\~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/,'<\1>')
+      para.gsub!(/\s*[,:]\s*/,' - ')
+      para.gsub!(/<:#>/,'')
+      para.strip!
+      para
+    end
     def menu
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#@dp:#@dp>$/,'~[\1]')
-      @para.gsub!(/\s*[,:]\s*/,' - ')
-      @para.gsub!(/<:#>/,'')
-      @para.strip!
-      "* #@para::"
+      para=clean(@para)
+      para=para.gsub(/@footnote\{.+?\}\s+/,'')
+      "* #{para}::"
     end
     def level1
       @para.gsub!(/[1]\\+~/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#@dp:#@dp>$/,'~[\1]')
-      @para.gsub!(/\s*[,:]\s*/,' - ')
-      @para.gsub!(/<:#>/,'')
-      @para.strip!
-      para="@node #@para\n@chapter #@para\n@cindex chapter, #@para\n"
+      para=clean(@para)
+      nd=para.gsub(/@footnote\{.+?\}\s+/,'')
+      para="@node #{nd}\n@unnumbered #{para}\n@cindex chapter, #{nd}\n"
       @para.gsub!(/.+/,"#{para}")
     end
     def level2
       @para.gsub!(/[2]\\+~/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#@dp:#@dp>$/,'~[\1]')
-      @para.gsub!(/\s*[,:]\s*/,' - ')
-      @para.gsub!(/<:#>/,'')
-      @para.strip!
-      para="@node #@para\n@chapter #@para\n@cindex chapter, #@para\n"
+      para=clean(@para)
+      nd=para.gsub(/@footnote\{.+?\}\s+/,'')
+      para="@node #{nd}\n@unnumbered #{para}\n@cindex chapter, #{nd}\n"
       @para.gsub!(/.+/,"#{para}")
     end
     def level3
       @para.gsub!(/[3]\\+\~/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#@dp:#@dp>$/,'~[\1]')
-      @para.gsub!(/\s*[,:]\s*/,' - ')
-      @para.gsub!(/<:#>/,'')
-      @para.strip!
-      para="@node #@para\n@chapter #@para\n@cindex chapter, #@para\n"
+      para=clean(@para)
+      nd=para.gsub(/@footnote\{.+?\}\s+/,'')
+      #para=para.gsub(/(.+?)\s*(@footnote\{.+?\})\s*(.+)$/,"\\1 \\3\n\\2")
+      #para=para.gsub(/(.+?)\s*(@footnote\{.+?\})\s*(.+)$/,'\1 \3 \2')
+      para="@node #{nd}\n@unnumbered #{para}\n@cindex chapter, #{nd}\n"
       @para.gsub!(/.+/,"#{para}")
     end
     def level4
       @para.gsub!(/[4]\\+~\S+/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#@dp:#@dp>$/,'~[\1]')
-      @para.gsub!(/\s*[,:]\s*/,' - ')
-      @para.gsub!(/<:#>/,'')
-      @para.strip!
-      para="@node #@para\n@chapter #@para\n@cindex chapter, #@para\n"
+      para=clean(@para)
+      nd=para.gsub(/@footnote\{.+?\}\s+/,'')
+      para="@node #{nd}\n@unnumbered #{para}\n@cindex chapter, #{nd}\n"
       @para.gsub!(/.+/,"#{para}")
     end
     def level5
       @para.gsub!(/[5]\\+~\S+/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#@dp:#@dp>$/,'~[\1]')
-      @para.gsub!(/\s*[,:]\s*/,' - ')
-      @para.gsub!(/<:#>/,'')
-      @para.strip!
-      para="@node #@para\n@chapter #@para\n@cindex chapter, #@para\n"
+      para=clean(@para)
+      nd=para.gsub(/@footnote\{.+?\}\s+/,'')
+      para="@node #{nd}\n@unnumbered #{para}\n@cindex chapter, #{nd}\n"
       @para.gsub!(/.+/,"#{para}")
     end
     def level6
       @para.gsub!(/[6]\\+~\S+/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#@dp:#@dp>$/,'~[\1]')
-      @para.gsub!(/\s*[,:]\s*/,' - ')
-      @para.gsub!(/<:#>/,'')
-      @para.strip!
-      para="@node #@para\n@chapter #@para\n@cindex chapter, #@para\n"
+      para=clean(@para)
+      nd=para.gsub(/@footnote\{.+?\}\s+/,'')
+      para="@node #{nd}\n@unnumbered #{para}\n@cindex chapter, #{nd}\n"
       @para.gsub!(/.+/,"#{para}")
     end
     def submenu
       @para=@para.join("\n")
       @para.gsub!(/[5]\\+~\S+/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#@dp:#@dp>$/,'~[\1]')
-      @para.gsub!(/\s*[,]\s*/,' - ')
-      @para.gsub!(/<:#>/,'')
-      @para.strip!
-      para="@menu\n#@para\n@end menu\n\n"
+      para=clean(@para)
+      para="@menu\n#{para}\n@end menu\n\n"
       @para.gsub!(/.+/m,"#{para}")
     end
     def subsubmenu
       @para=@para.join("\n")
       @para.gsub!(/[6]\\+~\S+/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#@dp:#@dp>$/,'~[\1]')
-      @para.gsub!(/\s*[,]\s*/,' - ')
-      @para.gsub!(/<:#>/,'')
-      @para.strip!
-      para="@menu\n#@para\n@menu\n\n"
+      para=clean(@para)
+      para="@menu\n#{para}\n@end menu\n\n"
       @para.gsub!(/.+/m,"#{para}")
     end
     def indent1
@@ -312,12 +310,15 @@ WOK
     end
     def spec_char # special characters
       @para.gsub!(/<EOF>/i,'')
-      @para.gsub!(/@/i,'@@')
-      @para.gsub!(/&(lt|#060);/,'\<&nbsp;')
-      @para.gsub!(/&(gt|#062);/,'&nbsp;\>')
-      @para.gsub!(/&#123;/,'\{&nbsp;')
-      @para.gsub!(/&#125;/,'\}&nbsp;')
-      @para.gsub!(/&#(126|152);/i,'~&nbsp;')
+      @para.gsub!(/&#169;/,'(c)')
+      @para.gsub!(/&(lt|#060);/,'<'); @para.gsub!(/&(gt|#062);/,'>')
+      @para.gsub!(/&#123;/,'{'); @para.gsub!(/&#125;/,'}')
+      @para.gsub!(/&#(126|152);/i,'~')
+      @para.gsub!(/&#033;/,'!')
+      @para.gsub!(/&#035;/,'#')
+      @para.gsub!(/&#042;/,'*')
+      @para.gsub!(/&#047;/,'/')
+      @para.gsub!(/&#095;/,'_')
       @para.gsub!(/<sup><font face=symbol>&atild;<\/font><\/sup>/,' ')
       @para.gsub!(/\\/,'\\backslash ')
       @para.gsub!(/<:pb>/,'\\newpage')
@@ -326,16 +327,10 @@ WOK
       @para.gsub!(/(\$)/,"\\$")
       @para.gsub!(/\~/,'\\~')
       @para.gsub!(/%/,"\\%")
-      if @para !~ /^\s*<:image|\}:image\s/
-        @para.gsub!(/_/,'\_')
-      end
-      @para.gsub!(/\{/,"\\{")
-      @para.gsub!(/\}/,"\\}")
-        @para.gsub!(/&nbsp;&nbsp;/,' ')  # ~ character for hardspace
-        @para.gsub!(/&nbsp;/,' ')        # ~ character for hardspace
-      @para.gsub!(/&(\S+?);/,'')
-      @para.gsub!(/(\s+&\s+)/,' and ')
-      @para.gsub!(/(\&)/,"\\&")
+      #if @para !~ /^\s*<:image|\}:image\s/
+      #  @para.gsub!(/_/,'\_')
+      #end
+      @para.gsub!(/_(https?:\/\/)/,'\1')
       @para.gsub!(/§/i,'\S')
       @para.gsub!(/£/i,'\pounds')
       @para.gsub!(/å/i,'\aa')
@@ -344,7 +339,6 @@ WOK
       @para.gsub!(/Å/i,'\AA')
       @para.gsub!(/Æ/i,'\AE')
       @para.gsub!(/Ø/i,'\O')
-      @para.gsub!(/&(.+?);/i,' ')
       @para.gsub!(/<a href=".+?">/i,' ')
       @para.gsub!(/<\/a>/i,' ')
       @para.gsub!(/<:ee>/i,'')
@@ -352,6 +346,15 @@ WOK
       @para.gsub!(/<b>(.+?)<\/b>/,'\*\1\*')
       @para.gsub!(/<i>(.+?)<\/i>/,'\/\1\/')
       @para.gsub!(/<u>(.+?)<\/u>/,'\_\1\_')
+      @para.gsub!(/@/i,'@@')
+      @para.gsub!(/\{/,'@{'); @para.gsub!(/\}/,'@}')
+      #@para.gsub!(/(^|[\s*!\/#_-])\{/,'\1@{'); @para.gsub!(/\}([\s*!\/#_-]|$)/,'@}\1')
+      @para.gsub!(/&nbsp;&nbsp;/,' ')  # ~ character for hardspace
+      @para.gsub!(/&nbsp;/,' ')        # ~ character for hardspace
+      @para.gsub!(/&(\S+?);/,' ')
+      @para.gsub!(/&/,'<=and>')
+      @para.gsub!(/(\s+&\s+)/,' and ')
+      @para.gsub!(/(\&)/,"\\&")
       @para.gsub!(/"(.+?)"/,"`\\1'")                                        # open & close "
       @para.gsub!(/\s+"/," `")                                              # open "
       @para.gsub!(/^([1-6-]\\+(?:~\S+)?|<.+?>)?\s*"/,'\1`')       # open "
@@ -360,11 +363,6 @@ WOK
       @para.gsub!(/"(\.|,)/,"'")                                            # close "
       @para.gsub!(/\s+'/," `")                                              # open '
       @para.gsub!(/^([1-6-]\\+(?:~\S+)?|<.+?>)?\s*'/,'\1`')       # open '
-      #if @para=~/#{@@tex_1}/
-      #end
-      #@para.gsub!(/^([1-6-](?:#{@@tex_2}|#{@@tex_1})(?:\\~\S+)?|<.+?>)?\s*"/i,"\\1`")       # open "
-      #@para.gsub!(/"([1-6-](?:#{@@tex_2}|#{@@tex_1})(?:\\~\S+)?|<.+?>)?\s*$/i,"'\\1")       # close "
-      #@para.gsub!(/^([1-6-](?:#{@@tex_2}|#{@@tex_1})(?:\\~\S+)?|<.+?>)?\s*'/i,"\\1`")       # open '
       @para.gsub!(/(<font.*?>|<\/font>)/,'')
       @para.gsub!(/\s*<sup>(\S+?)<\/sup>/,'^\1')
       @para.gsub!(/(<sup>|<\/sup>)/,'')
@@ -466,7 +464,7 @@ WOK
       width="100"
       width=@para[/<:image.+?width=``(\d+)''.+?>/im,1]
       width=width.to_i*0.4
-      @para.gsub!(/<:image\s+((?:https?|ftp)\S+)\s+(\S+)\s+.+\s+?>/i,
+      @para.gsub!(/<:image\s+((?:https?|file|ftp)\S+)\s+(\S+)\s+.+\s+?>/i,
         "\\href{\\1}{\\includegraphics*[width=#{width}pt]{#{dir.path.image_source_tex}/\\2}}")
       @para.gsub!(/<:image\s+(\S+)\s+.+\s+?>/i,
         "\\includegraphics*[width=#{width}pt]{#{dir.path.image_source_tex}/\\1}")
@@ -480,8 +478,8 @@ WOK
     end
     def http
       # very messy clean up ! - work area, testing
-      z=@para[/\\\{(.+?)\}(?:https?|ftp):\/\//,1] # match operator for z \\ fragile !
-      url=@para[/((?:https?|ftp):\S+)/im,1]
+      z=@para[/\\\{(.+?)\}(?:https?|file|ftp):\/\//,1] # match operator for z \\ fragile !
+      url=@para[/((?:https?|file|ftp):\S+)/im,1]
       if @para =~/\.(png|jpg|gif)/
         image,w,x,y=z.scan(/\S+/)
         image.gsub!(/\\/,'')
@@ -494,11 +492,11 @@ WOK
       end
       if image
         dir=SiSU_Env::Info_env.new(@md.fns)
-        @para.gsub!(/\{\S+\.(png|jpg|gif).+?\}(?:https?|ftp):\/\/\S+/, # fragile match operator\\ fragile !
+        @para.gsub!(/\{\S+\.(png|jpg|gif).+?\}(?:https?|file|ftp):\/\/\S+/, # fragile match operator\\ fragile !
           "\n\\href{#{url}}{\\includegraphics*[width=#{width}pt]{#{dir.path.image_source_tex}/#{image}}}#{caption}")
       else
         link=z[/(.+?)\\/im,1]
-        @para.gsub!(/\{.+?\}(?:https?|ftp):\/\/\S+/,"\n\\noindent\\href{#{url}}{#{link}}")  # fragile match operator\\ fragile !
+        @para.gsub!(/\{.+?\}(?:https?|file|ftp):\/\/\S+/,"\n\\noindent\\href{#{url}}{#{link}}")  # fragile match operator\\ fragile !
       end
     end
   end
