@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: LaTeX generation
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: LaTeX generation
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_TeX
   require 'pstore'
@@ -83,7 +91,7 @@ module SiSU_TeX
       begin
         @dir_out_root=@env.path.output
         case @opt.fns
-        when /\.[_-]?sst$/
+        when /\.(?:-|ssm\.)?sst$/
           SiSU_Env::SiSU_file.new(@md).mkdir
           Dir.mkdir(@env.path.tex) unless FileTest.directory?(@env.path.tex)
         end
@@ -106,25 +114,20 @@ module SiSU_TeX
         tell.flow if @opt.cmd =~/[MVv]/
         @md=SiSU_Param::Parameters.new(@opt).get
         my_make=SiSU_Env::Create_file.new(@opt.cmd,@opt.fns)
-        if @md.flag_pdf
-          $flag=@md.cmd                                                         #introduced to pass 0 for no object citation numbers... to texpdf_format
-          @dir_o="#{@env.path.output}/#{@opt.fnb}"
-          directories
-          filename_index="#{@md.txt_path}/pdf"
-          newfilename=filename_index
-                                                                               #% needed needs to be reprogrammed !!!
-          SiSU_Env::Info_skin.new(@md).select
-          dal_array=SiSU_DAL::Source.new(@opt).get             # dal file drawn here
-          SiSU_TeX::Source::LaTeX_create.new(dal_array,@md,'landscape').songsheet
-          SiSU_TeX::Source::LaTeX_create.new(dal_array,@md,'portrait').songsheet
-          dal_array=''
-          pwd=Dir.pwd
-          SiSU_TeX::Source::LaTeX_to_pdf.new(@md).latexrun_selective
-          Dir.chdir(pwd)
-        else
-          tell=SiSU_Screen::Ansi.new(@opt.cmd,'instructed NOT to produce LaTeX/PDF')
-          tell.warn unless @opt.cmd =~/q/
-        end
+        $flag=@md.cmd                                                         #introduced to pass 0 for no object citation numbers... to texpdf_format
+        @dir_o="#{@env.path.output}/#{@opt.fnb}"
+        directories
+        filename_index="#{@md.txt_path}/pdf"
+        newfilename=filename_index
+                                                                             #% needed needs to be reprogrammed !!!
+        SiSU_Env::Info_skin.new(@md).select
+        dal_array=SiSU_DAL::Source.new(@opt).get             # dal file drawn here
+        SiSU_TeX::Source::LaTeX_create.new(dal_array,@md,'landscape').songsheet
+        SiSU_TeX::Source::LaTeX_create.new(dal_array,@md,'portrait').songsheet
+        dal_array=''
+        pwd=Dir.pwd
+        SiSU_TeX::Source::LaTeX_to_pdf.new(@md).latexrun_selective
+        Dir.chdir(pwd)
       rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
         unless @opt.cmd =~/[MV]/ #check maintenance flag
@@ -189,21 +192,22 @@ module SiSU_TeX
       end
       def latexrun_selective
         begin
-          ep_dir=Dir.pwd
-          Dir.chdir(ep_dir)
+          pwd=Dir.pwd
+          Dir.chdir(pwd) #watch
           @tex_f_no=0
           info={}
-          if FileTest.file?("#{ep_dir}/#{@md.fns}")
-            if @md.fns =~/\.[_-]?sst$/
+          if FileTest.file?(@env.source_file_with_path)
+            if @md.fns =~/\.(?:-|ssm\.)?sst$/
               @dirout=SiSU_Env::Info_env.new(@md.fns)
               case @md.fns
-              when /\.[_-]?sst$/
+              when /\.(?:-|ssm\.)?sst$/
                 if FileTest.directory?(@env.path.tex)==true
                   Dir.chdir(@env.path.tex)
                   @dir_sisu=@dirout.path.output
                   texfile=@md.fns.gsub(/$/,'.tex')
                   texfile=texfile.gsub(/~/,'-')
-                  if File.exist?(texfile) and File.size(texfile) > 0
+                  if File.exist?(texfile) \
+                  and File.size(texfile) > 0
                     @tex_f_no+=1
                     latex_do(texfile)
                   else
@@ -213,12 +217,13 @@ module SiSU_TeX
               end
             end
           else
-            puts "\n#{@cX.fuschia}FILE NOT FOUND:#{@cX.off} << #{file} >> - requested latex system processing skipped\n"
+            tell=SiSU_Screen::Ansi.new(@md.cmd,"FILE NOT FOUND: << #{@md.fns} >> - requested latex system processing skipped")
+            tell.warn
           end
           lst=Dir["*.{aux,log,out}"]
           lst.each {|file| File.unlink(file)} if lst
           #touch("#{@dir_pdf}index.html") #correct @dir_pdf appears to contain slash / and should not
-        rescue; SiSU_Errors::Info_error.new($!,$@,@md.fns,@md.cmd).error
+        rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         end
       end
     end
@@ -227,7 +232,7 @@ module SiSU_TeX
       @@tex_backslash ||="\\\\"
       @@tilde='\\\\\\~' #?? debug crazy
       @@tex_head_portrait,@@tex_head_landscape=nil,nil
-      @@flag_group,@@flag_code=false,false
+      @@flag_alt,@@flag_group,@@flag_code=false,false,false
       @@dp,@@prefix_b=nil,nil
       def initialize(data,md,orientation)
         @data,@md,@orientation=data,md,orientation
@@ -236,6 +241,12 @@ module SiSU_TeX
         @tex=SiSU_TeX_Pdf::Use_TeX.new(@md,@orientation)
         @vz=SiSU_Env::Get_init.instance.skin
         @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
+        vz=SiSU_Env::Get_init.instance.skin
+        @skin_no_ocn=if defined? vz.ocn_display_off \
+        and vz.ocn_display_off == true
+          true
+        else false
+        end
       end
       def songsheet
         begin
@@ -250,7 +261,8 @@ module SiSU_TeX
             copymark=if @md.creator_copymark; '{\\begin{small}\\raisebox{1ex}{\\copyright}\\end{small}} '
             else ''
             end
-            copyright=do_mono.special_characters_safe.gsub(/^\s*Copyright/, copymark)
+            copymark='Copyright {\\begin{small}\\raisebox{1ex}{\\copyright}\\end{small}} '
+            copyright=do_mono.special_characters_safe.gsub(/^\s*Copyright \(C\)/, copymark)
             @@rights||="\n #{@@tex_backslash*2}[3]\\ \\linebreak #{copyright}"
           end
           if @md.prefix_b
@@ -258,17 +270,22 @@ module SiSU_TeX
             prefix_b=do_mono.special_characters_safe
             @@prefix_b="\n #{@@tex_backslash*2}[3]\\ \\linebreak \\ #{prefix_b}\n" unless @@prefix_b
           end
-          if @md.markup.to_s !~/url_png/
-            data=pre(data)
-            data=footnote(data)
-            if @md.flag_tables
-             data=tables(data)
-            end
-            data=number_paras(data) if @md.markup !~/not_to/ #check
-            data=markup(data)
-            output(data)
+          data=pre(data)
+          data=footnote(data)
+          if @md.flag_tables
+           data=tables(data)
           end
-        rescue; SiSU_Errors::Info_error.new($!,$@,@md.fns,@md.cmd).error
+          ocn=if @md.markup.inspect =~/no_ocn/ \
+          or @md.mod.inspect =~/--no-ocn/ \
+          or @skin_no_ocn
+            false
+           else true
+           end
+          data=number_paras(data,ocn)
+          data=markup(data)
+          #data=markup(data).flatten #watch
+          output(data)
+        rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         ensure
         end
       end
@@ -300,7 +317,6 @@ module SiSU_TeX
       def footnote(data)
         @tex_file=[]
         data.each do |para|
-          para2=para.dup
           # EMBEDDED FOOTNOTES / ENDNOTES should be straightforward but not quite a synch.
           footnote=[]
           if para =~/~\\\{[\d*+]+\s|\\\~\[([*+]\d+)\s/                                                # note escape not necessary in front of ~ has implications for many other matches #debug note
@@ -328,8 +344,7 @@ module SiSU_TeX
       end
       def enclose(para,type='')
         para.strip!
-        if type =~/code/; para
-          #para = '\begin{footnotesize} \begin{ttfamily} ' + para + ' \end{ttfamily} \end{footnotesize}'
+        para=if type =~/code/; para
         elsif para !~/(\\begin\{tabular\}.*|\\end\{tabular\}|&|#{@@tex_backslash*2})\s*$/ #check
           para.gsub!(/(.+)/m,"\n#{@tex.skip_small} \\1 #{@tex.skip_small}\n")
         else para
@@ -350,6 +365,7 @@ module SiSU_TeX
         end
         @tex_file <<<<WOK
 #{@tex.header}#{@tex.footer}
+\\tolerance=500
 \\makeatother
 \\makeatother
 \\begin{document}
@@ -357,9 +373,10 @@ WOK
         sisu_rc_footnote=if @md.sc_info; @tex.doc_sc_info_footnote_full
         else                             @tex.doc_sc_info_footnote_brief
         end
-        @copymark=if @md.creator_copymark; '^\copyright'
-        else                               ''
-        end
+        #@copymark=if @md.creator_copymark; '^\copyright'
+        #else                               ''
+        #end
+        @copymark='' #check and remove as now is superflous
         if @orientation =~/landscape/ # using longtable latex package
           @tex_file << SiSU_TeX_Pdf::Format_text_object.new(@md,@md.title,@md.subtitle).title_landscape
           if @md.dc_creator
@@ -374,7 +391,7 @@ WOK
             end
           end
           @tex_file << unless @md.fnb =~/^mail\s*$/
-            "\n\\date{copy @ #{@tex.site} #{sisu_rc_footnote}}"
+            "\n\\date{\\begin{footnotesize} copy @ #{@tex.site} \\end{footnotesize} #{sisu_rc_footnote}}"
           else "\\date"
           end
         else #portrait
@@ -389,7 +406,7 @@ WOK
             else "\n\\author{#@copymark \\textnormal{#{creator}}}"
             end
            end
-          @tex_file << unless @md.fnb =~/^mail\s*$/; "\n\\date{copy @ #{@tex.site} #{sisu_rc_footnote}}"
+          @tex_file << unless @md.fnb =~/^mail\s*$/; "\n\\date{\\begin{footnotesize} copy @ #{@tex.site} \\end{footnotesize} #{sisu_rc_footnote}}"
           else                                       "\\date"
           end
         end
@@ -418,11 +435,12 @@ WOK
         @group_collect=[]
         data.each do |para|                                                      #% case follows with levels 1-6 indents & graphics
           mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
-          if para =~/<:(code|alt|verse|group)>/ or @@flag_group==true
-            if para =~/<:(code|alt|verse|group)>/
+          if para =~/<:(?:code|alt|verse|group)>/ \
+          or @@flag_alt
+            if para =~/<:(?:code|alt|verse|group)>/
               @lineone=case para
-              when /<:(alt|verse|group)>/; para
-              when /<:code>/; "#{@tex.paraskip_small} \\begin{footnotesize} \\begin{ttfamily} " + para
+              when /<:(?:alt|verse|group)>/; para
+              when /<:code>/; "#{@tex.paraskip_small} \\begin{scriptsize} " + para
               else 'error' #should never occur
               end
             end
@@ -430,39 +448,54 @@ WOK
               do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
               para=do_mono.special_characters_curly(para)
             end
-            regx=/<:((?:code|alt|verse|group)(?:-end)?)>/
+            regx=/<:((?:code|alt|verse|group)(?:-end)?)>/m
             x=regx.match(para)[1] if para =~regx
             x=$1
             para.gsub!(/\n<:(?:code|alt|verse|group)>\n/m,'')
             para=enclose(para,'code') unless para =~/^$/
-            if x =~/(?:alt|verse|group)/; @@flag_group=true
-            elsif x =~/code/; @@flag_group,@@flag_code=true,true
-            elsif @@flag_group==true;    @group_collect << para #<< "\n\n"
+            if x =~/(?:alt|verse|group)/; @@flag_alt=true
+              if x =~/group/; @@flag_group=true
+              end
+            elsif x =~/code/; @@flag_alt,@@flag_code=true,true
+            elsif @@flag_alt;
+              if para =~ /\}(?:https?|file|ftp)/m
+                para=mono.http(@orientation)
+              end
+              @group_collect << para #<< "\n\n"
             end
-            if x =~/(?:code|alt|verse|group)-end/
+            if x =~/(?:code|alt|verse|group)-end/m
               regx=/(\\+marginpar\{\\+begin\{tiny\}\d+\\+end\{tiny\}\})/
               y=if para =~regx
                 regx.match(para)[1]
               else ''
               end
               para.gsub!(regx,'')
-              @group_collect.each{ |x| x.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ') }
+              #@group_collect.each{ |x| x.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ') }
+              group_collect=[]
+              group_collect << '\begin{footnotesize} ' unless @@flag_code
+              @group_collect.each do |x|
+                x.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ')
+                x=x.split(/ \\\\ /)
+                group_collect << x
+              end
+              group_collect << ' \end{footnotesize} ' unless @@flag_code
+              @group_collect=group_collect.flatten
               @lineone.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ')
               #@group_collect.each{ |x| x.gsub!(/(.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ') }
               #@lineone.gsub!(/(.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ')
               insert=[]
-              if para =~/<:code-end>/
-                insert << y + @lineone << @group_collect << ' \end{ttfamily} \end{footnotesize}' << " #{@tex.paraskip_normal}"
+              if para =~/<:code-end>/m
+                insert << y + @lineone << @group_collect << ' \end{scriptsize}' << " #{@tex.paraskip_normal}"
               else insert << y + @lineone << @group_collect
               end
-              @@flag_group,@@flag_code=false,false
+              @@flag_alt,@@flag_group,@@flag_code=false,false,false
               @group_collect=[]
               para.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ')
               #para.gsub!(/(.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ')
               @tex_file << insert.flatten
             end
           else
-            if para =~ /\}(?:https?|ftp)/
+            if para =~ /\}(?:https?|file|ftp)/
               para=mono.http(@orientation)
             end
             case para
@@ -495,7 +528,8 @@ WOK
         @tex_file << if @md.doc_skin !~/skin_mail/; @tex.doc_tail
         else                                        @tex.mail_tail
         end
-        if defined? @md.lnk and @md.lnk
+        if defined? @md.lnk \
+        and @md.lnk
           @md.lnk.each do |l|
             if l[:say]
               url=%<#{l[:url]}>
@@ -536,13 +570,16 @@ WOK
         end
         @tex_file << "\n\\end{document}"
       end
-      def number_paras(data)
+      def number_paras(data,ocn)
         @tex_file=[]
         data.each do |para|
-          if para =~/<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/ and para !~/\\end\{longtable\}|<EOF>/ #catch <!TZ!>
+          if para =~/<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/ \
+          and para !~/\\end\{longtable\}|<EOF>/ #catch <!TZ!>
             m=/(.+?)<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/m
             parablock=para[m,1]
-            paranum=para[m,2]
+            paranum=if ocn; para[m,2]
+            else ''
+            end
             do_duo=SiSU_TeX_Pdf::Format_text_object.new(@md,parablock,paranum)
             para=do_duo.para_num if parablock
           elsif para =~/^<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/ #2005 this is added for tables, rationalise
