@@ -1,50 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: LaTeX formatting template, unicode utf-8 version, used for pdf
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
+
+ ** Description: LaTeX formatting template, unicode utf-8 version, used for pdf
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
 =end
 module SiSU_TeX_Pdf
   @@table_pg_break_counter=1
@@ -56,8 +64,9 @@ module SiSU_TeX_Pdf
     def initialize(md,orientation='')
       @md,@orientation=md,orientation
       @vz=SiSU_Env::Get_init.instance.skin
-      @date=SiSU_Env::Info_date.new
+      @date=SiSU_Env::Info_date.new # #{@date.year}
       @copymark='{\\begin{footnotesize}\\raisebox{1ex}{\\copyright}\\end{footnotesize}}'
+      @url_brace=SiSU_Viz::Skin.new.url_decoration
     end
     def skip
       "\n\\vspace*{\\smallskipamount} \n"
@@ -134,10 +143,10 @@ WOK
 <<WOK
 \\\\ ~
 {\\begin{footnotesize}#{base_prog_txt}
-\\\\ Generated by \\href{http://www.jus.uio.no/sisu}{SiSU \\ www.jus.uio.no/sisu } \\begin{tiny}[ #{v[:project]} #{v[:version]} of #{v[:date_stamp]} ]\\end{tiny}
-\\\\ using SiSU: object citation numbering, markup, meta-markup, and system
-\\\\ #@copymark Ralph Amissah 1997, current #{@date.year}, All Rights Reserved.
-\\\\ SiSU is released under \\href{http://www.fsf.org/licenses/gpl.html}{GPL 2 } or later, \\href{http://www.fsf.org/licenses/gpl.html}{http://www.fsf.org/licenses/gpl.html}.
+\\\\ Generated by \\href{http://www.jus.uio.no/sisu}{SiSU} \\begin{tiny}[ #{v[:project]} #{v[:version]} of #{v[:date_stamp]} ]\\end{tiny} \\href{http://www.jus.uio.no/sisu}{www.jus.uio.no/sisu}
+\\\\ Copyright #@copymark 1997, current #{@date.year_static} Ralph Amissah, All Rights Reserved.
+\\\\ SiSU is software for document structuring, publishing and search (with object citation numbering), \\href{http://www.sisudoc.org}{www.sisudoc.org}
+\\\\ SiSU is released under \\href{http://www.fsf.org/licenses/gpl.html}{GPL 3 } or later, #{@url_brace.tex_open}\\href{http://www.fsf.org/licenses/gpl.html}{http://www.fsf.org/licenses/gpl.html}#{@url_brace.tex_close}.
 {\\end{footnotesize}
 \\\\
 WOK
@@ -148,7 +157,7 @@ WOK
 WOK
     end
     def doc_sc_info_footnote_brief
-      " \\footnote{%\nGenerated by \\href{http://www.jus.uio.no/sisu}{SiSU \\ www.jus.uio.no/sisu }\\\n}"
+      " \\footnote{%\nGenerated by \\href{http://www.jus.uio.no/sisu}{SiSU} \\ \\href{http://www.jus.uio.no/sisu}{www.jus.uio.no/sisu} \\newline \\href{http://www.sisudoc.org}{www.sisudoc.org} \\\n}"
     end
     def doc_sc_info
       v=SiSU_Env::Info_version.new.get_version
@@ -169,7 +178,7 @@ WOK
 {\\begin{small}
 Document information: \\\\
 \\emph{sourcefile} \\uline{#{@md.fnstex}} \\\\
-Generated by \\href{http://www.jus.uio.no/sisu}{SiSU www.jus.uio.no/sisu }\\- version information: \\\\
+Generated by \\href{http://www.jus.uio.no/sisu}{SiSU www.jus.uio.no/sisu } \\\\ version information: \\
 \\uline{ #{v[:project]} #{v[:version]} of #{v[:date_stamp]}}
 
 \\end{small}}&
@@ -181,7 +190,7 @@ WOK
 <<WOK
 {\\begin{footnotesize}
 \\\\ For alternative output formats of this document check:
-\\\\ \\begin{scriptsize}\\href{#{@vz.url_root_http}/#{url}/#{fn}}{#{@vz.url_root_http}/#{url}/#{fn}}\\end{scriptsize}
+\\\\ #{@url_brace.tex_open}\\begin{scriptsize}\\href{#{@vz.url_root_http}/#{url}/#{fn}}{#{@vz.url_root_http}/#{url}/#{fn}}\\end{scriptsize}#{@url_brace.tex_close}
 \\end{footnotesize}}&
 WOK
     end
@@ -209,13 +218,13 @@ WOK
 \\subsection*{Information on this document copy and an unofficial List of Some web related information and sources}
 \\addcontentsline{toc}{section}{Information on this document copy and an unofficial List of Some web related information and sources}
 \\\\
-\"Support Open Standards and Open Sources for the Information Technology Infrastructure\" RA\\subsubsection*{Information on this document copy #{site}}
+\"Support Open Standards and Software Libre for the Information Technology Infrastructure\" RA\\subsubsection*{Information on this document copy #{site}}
 \\addcontentsline{toc}{subsection}{Information on this document copy}
 {\\begin{footnotesize}
-\\\\ Generated by \\href{http://www.jus.uio.no/sisu/}{SiSU} found at \\href{http://www.jus.uio.no/sisu/}{www.jus.uio.no/sisu} \\begin{tiny}[ #{v[:project]} #{v[:version]} #{v[:date_stamp]} ]\\end{tiny} (using SiSU: object citation numbering, markup, meta-markup, and system) #@copymark Ralph Amissah 1997, current #{@date.year}, All Rights Reserved.
-\\\\ SiSU is released under \\href{http://www.fsf.org/licenses/gpl.html}{GPL 2 } or later (\\href{http://www.fsf.org/licenses/gpl.html}{www.fsf.org/licenses/gpl.html}). {\\end{footnotesize}
+\\\\ Generated by \\href{http://www.jus.uio.no/sisu/}{SiSU} found at \\href{http://www.jus.uio.no/sisu/}{www.jus.uio.no/sisu} \\begin{tiny}[ #{v[:project]} #{v[:version]} #{v[:date_stamp]} ]\\end{tiny}  \\href{http://www.sisudoc.org}{www.sisudoc.org}. SiSU is software for document structuring, publishing and search (using SiSU: object citation numbering, markup, meta-markup, and system) Copyright #@copymark 1997, current #{@date.year_static} Ralph Amissah, All Rights Reserved.
+\\\\ SiSU is released under \\href{http://www.fsf.org/licenses/gpl.html}{GPL 3 } or later (\\href{http://www.fsf.org/licenses/gpl.html}{www.fsf.org/licenses/gpl.html}). {\\end{footnotesize}
 {\\begin{small}
-\\\\ W3 since October 3 1993 \\href{http://www.jus.uio.no/sisu/}{#{sisu_ico}}SiSU 1997, current #{@date.year}. \\\\ #{sitename} presentations at \\begin{bfseries}#{site}\\end{bfseries} \\\\ \\\\ #{@md.title} \\textbf{pdf} versions can be found at:  \\\\
+\\\\ W3 since October 3 1993 \\href{http://www.jus.uio.no/sisu/}{#{sisu_ico}}SiSU 1997, current #{@date.year_static}. \\\\ #{sitename} presentations at \\begin{bfseries}#{site}\\end{bfseries} \\\\ \\\\ #{@md.title} \\textbf{pdf} versions can be found at:  \\\\
 {\\end{small}
 \\begin{scriptsize}\\href{#{@vz.url_root_http}/#{url}/#{@md.fn[:pdf_p]}}{#{@vz.url_root_http}/#{url}/#{@md.fn[:pdf_p]}}\\end{scriptsize}  \\\\
 \\begin{scriptsize}\\href{#{@vz.url_root_http}/#{url}/#{@md.fn[:pdf_l]}}{#{@vz.url_root_http}/#{url}/#{@md.fn[:pdf_l]}}\\end{scriptsize}  \\\\
@@ -244,7 +253,7 @@ Mail from: ralph@amissah.com\\\\
 \\\\
  \"Support Open Standards and Open Sources for the Information Technology Infrastructure\" RA
 \\subsubsection*{Information on this document copy #{site}\\copyright}
-Presentations' look and feel generated by \\href{http://www.jus.uio.no/sisu/}{SiSU Scribe} \\href{http://www.jus.uio.no/sisu/}{http://www.jus.uio.no/sisu/} programmed in Ruby on Debian/Gnu/Linux by \\copyright Ralph Amissah, W3 since October 3 1993 \\href{http://www.jus.uio.no/sisu/}{\\includegraphics*[width=35pt]{#{dir.path.image_source_tex}/sisu.png}}for #{sitename}. SiSU Scribe (sisu information structuring unit) produces Electronic Documents, i.e. it generates structured output for use in a number of file formats, including the pdf file produced here.
+Presentations' look and feel generated by \\href{http://www.jus.uio.no/sisu/}{SiSU Scribe} \\href{http://www.jus.uio.no/sisu/}{http://www.jus.uio.no/sisu/} programmed in Ruby on Debian/Gnu/Linux by Copyright \\copyright Ralph Amissah, W3 since October 3 1993 \\href{http://www.jus.uio.no/sisu/}{\\includegraphics*[width=35pt]{#{dir.path.image_source_tex}/sisu.png}}for #{sitename}. SiSU Scribe (sisu information structuring unit) produces Electronic Documents, i.e. it generates structured output for use in a number of file formats, including the pdf file produced here.
 WOK
     end
   end
@@ -262,7 +271,8 @@ WOK
     @@dp=nil
     def initialize(md,string,string1=nil)
       @md,@string,@string1=md,string,string1
-      if defined? @md.image and @md.image =~/center/
+      if defined? @md.image \
+      and @md.image =~/center/
         @center_begin,@center_end='\begin{center}','\end{center}'
       else @center_begin,@center_end='',''
       end
@@ -414,8 +424,7 @@ WOK
       end
       @string
     end
-    def special_characters_1(para)
-      # ~ ^ $ & % _ { }                                                          #LaTeX special characters - KEEP list
+    def special_characters_1(para)             # ~ ^ $ & % _ { }  #LaTeX special characters - KEEP list
       #p @@utf_8.list
       #@string=Iconv.conv('ISO-8859-1', 'UTF-8', @string)
       word=@string.scan(/\S+|\n/) #unless line =~/^(?:0~\S|%+\s)/
@@ -456,7 +465,7 @@ WOK
       @string.gsub!(/&#095;/,'<=underscore>')                                    # _ SiSU special character also LaTeX
       @string.gsub!(/&#124;/,'|')                                                # | SiSU not really special sisu character but done, also LaTeX
       @string.gsub!(/&#058;/,':')                                                # : SiSU not really special sisu character but done, also LaTeX
-      @string.gsub!(/&#094;/,'<=caret>')                                         # ^ SiSU not really special sisu character but done, also LaTeX
+      @string.gsub!(/&#094;|\^/,'<=caret>')                                      # ^ SiSU not really special sisu character but done, also LaTeX
       @string.gsub!(/\#/,'<=hash>')
       ##watch placement, problem sequence ^
       @string.gsub!(/<sup><font face=symbol>&atild;<\/font><\/sup>/,' ')
@@ -490,17 +499,14 @@ WOK
       @string.gsub!(/&\S+?;/,' ')
       @string.gsub!(/<a href=".+?">/,' ')
       @string.gsub!(/<\/a>/,' ')
-      if @string !~/^\s*<:image|\}image/                                           #watch carefully could introduce breaks ! removed \}http changed 0.1.1-4 200501
-        if @string =~/(?:https?|ftp):\/\/\S+?<\/\S>/                               #problems where have font attribute eg </u> (change substitution sequence?) # [^\}>] added for escaped curly brace <=curlyclose> watch
-          @string.gsub!(/[^\}>]((?:https?|ftp):\/\/\S+?)(<\/\S>)/,' \begin{scriptsize}\href{\1}{ \1 } \end{scriptsize}\2')
-        else # regular urls !! http:// href
-          if @string=~/(?:https?|ftp):\/\/\S+?[,.]? /
-            @string.gsub!(/(?:^|[^\}>])((?:https?|ftp):\/\/\S+?)([,.])? /," #{@url_brace.tex_open}\\begin{scriptsize}\\href{\\1}{ \\1}\\end{scriptsize}#{@url_brace.tex_close}\\2 ") #tamper
-          else @string.gsub!(/(?:^|[^\}>])((?:https?|ftp):\/\/\S+)/,' \begin{scriptsize}\href{ \1 }{\1} \end{scriptsize}') #should not be necessary, not checked
-          end
-        end
-      else #@string =~/\\~\\\{.+?\\\}\\~/ # \\~\\{1
-        #@string.gsub!(/(?:\n)?(http:\/\/\S+)/," \\begin{scriptsize}\\href{\\1}{\\1} \\end{scriptsize}") #bug...
+      @string.gsub!(/[^\}>_]((?:https?|file|ftp):\/\/\S+?)(<\/\S>)/,' \begin{scriptsize}\href{\1}{\1} \end{scriptsize}\2') #special case
+      @string.gsub!(/((?:^|\s)[}])((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/,'\1\begin{scriptsize}\\href{\2}{\2}\end{scriptsize}\3') #special case \{ e.g. \}http://url
+      @string.gsub!(/\B(?:\\_|\\)((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/,'\begin{scriptsize}\\href{\1}{\1}\end{scriptsize}\2') #specially escaped url no decoration
+      unless @@flag_code
+        @string.gsub!(/(^|\s)((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?=\s|$))/,"\\1#{@url_brace.tex_open}\\begin{scriptsize}\\href{\\2}{\\2}\\end{scriptsize}#{@url_brace.tex_close}\\3") #url matching with decoration <url> positive lookahead, sequence issue with { linked }http://url cannot use \b at start
+      else #code-block: angle brackets special characters, note _ already escaped
+        @string.gsub!(/\\_</,'{\UseTextSymbol{OML}{<}}')
+        @string.gsub!(/\\_>/,'{\UseTextSymbol{OML}{>}}')
       end
       @string.gsub!(/<:ee>/,'')
       @string.gsub!(/<!>/,' ')
@@ -514,6 +520,7 @@ WOK
       @string.gsub!(/<i>(.+?)<\/i>/,'\emph{\1}')
       @string.gsub!(/<italic>(.+?)<\/italic>/,'\emph{\1}')
       @string.gsub!(/<u>(.+?)<\/u>/,'\uline{\1}') # ulem
+      @string.gsub!(/<cite>(.+?)<\/cite>/,"``\\1''") # quote
       @string.gsub!(/<ins>(.+?)<\/ins>/,'\uline{\1}') # ulem
       @string.gsub!(/<del>(.+?)<\/del>/,'\sout{\1}') # ulem
       @string.gsub!(/<sub>(.+?)<\/sub>/,"\$_{\\textrm{\\1}}\$")
@@ -595,7 +602,7 @@ WOK
       para.gsub!(/(?:\\begin\{bfseries\}|\\begin\{itshape\})(.+?)(?:\\end\{bfseries\}|\\end\{itshape\})/m,'\1')
       cont_ln=para.dup
       cont_ln.gsub!(/#{@@tex_pattern_margin_number}/,'')
-      cont_ln.gsub!(/#{lev}#{@@tilde}\s+/,'')
+      cont_ln.gsub!(/#{lev}#{@@tilde}(?:\S+)?\s+/,'')
       if para =~/\\[Ff]ootnote/ #and para =~/^[1-6]#{@@tilde}/ # removing footnotes from headings!
         cont_ln.gsub!(/\s*\\footnote\[\d+\]\{%\n .+? \}\s*/,' ')
         cont_ln.gsub!(/\s*\\Footnote[A]\{[*+]+\d*\}\{%\n .+? \}\s*/,' ')
@@ -695,10 +702,20 @@ WOK
       #end BUGWATCH
     end
     def indent(lev)
-      @string.gsub!(/<:i#{lev}>(.*)/m,
-        "\\begin{ParagraphIndent}{0.0#{lev}\\columnwidth} \\1
-\\end{ParagraphIndent}
-")
+      indent=case lev
+      when /1/; '0mm'
+      when /2/; '10mm'
+      when /3/; '20mm'
+      when /4/; '30mm'
+      when /5/; '40mm'
+      when /6/; '50mm'
+      when /7/; '60mm'
+      when /8/; '70mm'
+      when /9/; '80mm'
+      end
+      @string.gsub!(/<:i#{lev}>\s*(.*)/m,
+        "\\begin{ParagraphIndent}{#{indent}}\\1
+\\end{ParagraphIndent}}")
     end
     def symbol_graphic
       dir=SiSU_Env::Info_env.new(@md.fns)
@@ -709,7 +726,7 @@ WOK
       else
         tell=SiSU_Screen::Ansi.new(@md.cmd,"ERROR - image:",%{"#{image}" missing},"search path: #{dir.path.image_source_tex}")
         tell.error2 unless @md.cmd =~/q/
-        @string.gsub!(/\{\S+\.(png|jpg|gif).+?\}(?:https?|ftp):\/\/\S+/,'') # fragile match operator\\ fragile !
+        @string.gsub!(/\{\S+\.(png|jpg|gif).+?\}(?:https?|file|ftp):\/\/\S+/,'') # fragile match operator\\ fragile !
       end
     end
     def image
@@ -717,9 +734,11 @@ WOK
       image,m=/<:image\s+(\S+)\s+.+?width=``(\d+)''.+?>/m.match(@string).captures
       width=m[1] || '100'
       width=width.to_i*0.4
-      image_source=if @md.fns =~/\._?sst$/ and FileTest.file?("#{dir.path.image_source_local_tex}/#{image}")
+      image_source=if @md.fns =~/\.(?:ssm\.)?sst$/ \
+      and FileTest.file?("#{dir.path.image_source_local_tex}/#{image}")
         dir.path.image_source_local_tex
-      elsif @md.fns =~/\.-ss[tm]$/ and FileTest.file?("#{dir.path.image_source_remote_tex}/#{image}")
+      elsif @md.fns =~/\.-ss[tm]$/ \
+      and FileTest.file?("#{dir.path.image_source_remote_tex}/#{image}")
         dir.path.image_source_remote_tex
       elsif FileTest.file?("#{dir.path.image_source_tex}/#{image}")
         dir.path.image_source_tex
@@ -729,7 +748,7 @@ WOK
         nil
       end
       if image_source
-        @string.gsub!(/<:image\s+((?:https?|ftp)\S+)\s+(\S+)\s+.+\s+?>/,
+        @string.gsub!(/<:image\s+((?:https?|file|ftp)\S+)\s+(\S+)\s+.+\s+?>/,
           @center_begin + "\\href{\\1}{\\includegraphics*[width=#{width}pt]{#{image_source}/\\2}}" + @center_end )
         @string.gsub!(/<:image\s+(\S+)\s+.+\s+?>/,
           @center_begin + "\\includegraphics*[width=#{width}pt]{#{image_source}/\\1}" + @center_end )
@@ -754,14 +773,17 @@ WOK
       hsp="\n{\\color{mywhite} .}&~\n" # ~ character for hardspace
       caption="{\\\\\\\ \n\\begin{scriptsize}#{hsp*3}#{c}\\end{scriptsize}&}" if c
       #caption="{\\\\\\\ \n\\begin{scriptsize}#{hsp*3}#{c[1]}\\end{scriptsize}&}" if c
-      image_source=if @md.fns =~/\._?sst$/ and FileTest.file?("#{dir.path.image_source_local_tex}/#{image}")
+      image_source=if @md.fns =~/\.(?:ssm\.)?sst$/ \
+      and FileTest.file?("#{dir.path.image_source_local_tex}/#{image}")
         dir.path.image_source_local_tex
-      elsif @md.fns =~/\.-ss[tm]$/ and FileTest.file?("#{dir.path.image_source_remote_tex}/#{image}")
+      elsif @md.fns =~/\.-ss[tm]$/ \
+      and FileTest.file?("#{dir.path.image_source_remote_tex}/#{image}")
         dir.path.image_source_remote_tex
       elsif FileTest.file?("#{dir.path.image_source_tex}/#{image}")
         dir.path.image_source_tex
       else
-        unless image.nil? or image.length < 2
+        unless image.nil? \
+        or image.length < 2
           tell=SiSU_Screen::Ansi.new(@md.cmd,"ERROR - image:",%{"#{image}" missing},"search locations: #{dir.path.image_source_local_tex},#{dir.path.image_source_remote_tex} and #{dir.path.image_source_tex}")
           tell.error2 unless @md.cmd =~/q/
         end
@@ -779,17 +801,18 @@ WOK
       dir=SiSU_Env::Info_env.new(@md.fns)
       @words=[]
       @string.each do |word|
-        @words << if word=~/\{.+?\}(?:https?|ftp):\S+/
-          if word =~/\\\{(.+?)\\\}((?:https?|ftp)\S+?)([.,](?:\s|$))/
-            r=%r/\\\{(.+?)\\?\}((?:https?|ftp):\S+?)(?:[.,](?:\s|$)|(?:\s|$))/
-            d=/\\\{.+?\\?\}(?:https?|ftp):\S+([.,](?:\s|$))/.match(word).captures.to_s
+        @words << if word=~/\\\{.+?\\\}(?:https?|file|ftp):\S+/
+          if word =~/\\\{(.+?)\\\}((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/
+            r=%r/\\\{(.+?)\\?\}((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)(?:[;.,]?(?:\s|$)|(?:\s|$))/
+            d=/\\\{.+?\\?\}(?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?([;.,]?(?:\s|$))/.match(word).captures.to_s
           else
-            r=%r/\\\{(.+?)\\?\}((?:https?|ftp):\S+)/
+            r=%r/\\\{(.+?)\\?\}((?:https?|file|ftp):\S+)/
             d=''
           end
           z,url=r.match(word).captures if word =~r
           url=url.strip
-          if word =~/\{\s*\S+\.?(?:png|jpg|gif)/ and word=~/\s+\d+x\d+\s+/
+          if word =~/\{\s*\S+\.?(?:png|jpg|gif)/ \
+          and word=~/\s+\d+x\d+\s+/
             image,x,y=z.scan(/\S+/)
             image.gsub!(/\\/,'')
             width=200
@@ -802,8 +825,6 @@ WOK
             when /a5/;     @tx.a5
             else           @tx.a4
             end
-            ##dm=SiSU_Env::Get_init.instance.tex(@md.papersize).dimensions #test!
-            #dm=SiSU_Viz::TeX.new(@md.papersize).dimensions
             width=if orientation =~/portrait/ #value is not currently passed
               width=if width.to_i > dm.portrait.img_px; dm.portrait.img_px
               else                                      width
@@ -821,35 +842,37 @@ WOK
             tell.print_grey #unless @opt.cmd =~/q/
           end
           ins=if image #most images fc etc. #% clean up !
-            out=if @md.fns =~/\._?sst$/ and FileTest.file?("#{dir.path.image_source_local_tex}/#{image}")
+            out=if @md.fns =~/\.(?:ssm\.)?sst$/ \
+            and FileTest.file?("#{dir.path.image_source_local_tex}/#{image}")
               @center_begin +
               "\\\n\\href{#{url}}" + #not satisfactory: \\ added to ^line to mimic reference file output
               "{\\includegraphics*[width=#{width}pt]" +
               "{#{dir.path.image_source_local_tex}/#{image}}}" +
               "#{caption}" +
-              @center_end if word =~ /(\{[a-zA-Z0-9_\\]+\.(?:png|jpg|gif).+?\}(?:https?|ftp):\/\/\S+)/
-            elsif @md.fns =~/\.-ss[tm]$/ and FileTest.file?("#{dir.path.image_source_remote_tex}/#{image}")
+              @center_end if word =~ /(\{[a-zA-Z0-9_\\]+\.(?:png|jpg|gif).+?\}(?:https?|file|ftp):\/\/\S+)/
+            elsif @md.fns =~/\.-ss[tm]$/ \
+            and FileTest.file?("#{dir.path.image_source_remote_tex}/#{image}")
               @center_begin +
               "\\\n\\href{#{url}}" + #not satisfactory: \\ added to ^line to mimic reference file output
               "{\\includegraphics*[width=#{width}pt]" +
               "{#{dir.path.image_source_remote_tex}/#{image}}}"  +
               "#{caption}" +
-              @center_end if word =~ /(\{[a-zA-Z0-9_\\]+\.(?:png|jpg|gif).+?\}(?:https?|ftp):\/\/\S+)/
+              @center_end if word =~ /(\{[a-zA-Z0-9_\\]+\.(?:png|jpg|gif).+?\}(?:https?|file|ftp):\/\/\S+)/
             elsif FileTest.file?("#{dir.path.image_source_tex}/#{image}")
               @center_begin +
               "\\\n\\href{#{url}}\n" + #not satisfactory: \\ added to ^line to mimic reference file output, mirror above ... not tested
               "{\\includegraphics*[width=#{width}pt]" +
               "{#{dir.path.image_source_tex}/#{image}}}" +
               "#{caption}" +
-              @center_end if word =~/(\{[a-zA-Z0-9_\\]+\.(?:png|jpg|gif).+?\}(?:https?|ftp):\/\/\S+)/
+              @center_end if word =~/(\{[a-zA-Z0-9_\\]+\.(?:png|jpg|gif).+?\}(?:https?|file|ftp):\/\/\S+)/
             else
               tell=SiSU_Screen::Ansi.new(@md.cmd,"ERROR - image:",%{"#{image}" missing},"search locations: #{dir.path.image_source_local_tex},#{dir.path.image_source_remote_tex} and #{dir.path.image_source_tex}")
               tell.error2 unless @md.cmd =~/q/
-              '' if word =~ /\{\S+\.(png|jpg|gif).+?\}(?:https?|ftp):\/\/\S+/
+              '' if word =~ /\{\S+\.(png|jpg|gif).+?\}(?:https?|file|ftp):\/\/\S+/
             end
           else
             link=z.strip #[/(.+?)\\/m,1]
-            word="\\href{#{url}}{#{link}}#{d}" if word =~/\\\{.+?\\\}(?:https?|ftp):\/\/\S+/
+            word="\\href{#{url}}{#{link}}#{d}" if word =~/\\\{.+?\\\}(?:https?|file|ftp):\/\/\S+/
           end
         else word
         end
@@ -857,7 +880,7 @@ WOK
       @words.join
     end
     def http(orientation)
-      wm=@string.dup.scan(/\\\{.+?\\\}(?:(?:https?|ftp):\S+|image)|\w+\s*|./m) #first match of interest others passed through
+      wm=@string.dup.scan(/\\\{.+?\\\}(?:(?:https?|file|ftp):\S+|image)|\w+\s*|./m)
       @string=SiSU_TeX_Pdf::Format_text_object.new(@md,wm).http_word_mode(orientation)
     end
     def language
@@ -936,7 +959,7 @@ WOK
       lastdone="Last Generated on: #{Time.now}"
       rubyv="Ruby version: #{@md.ruby_version}"
       <<WOK
-%% Sisu Sabaki (Linux & Ruby - \"better ways\") LaTeX output
+%% SiSU (Linux & Ruby - \"better ways\") LaTeX output
 %% #{generator}
 %% #{rubyv}
 %% LaTeX output
@@ -1183,21 +1206,19 @@ WOK
     def a4generic
     end
     def para_num
-      paranumber_display=if @md.mod.inspect =~/--no-ocn/; ''                                        #!ocn no object citation numbering
+      paranumber_display=if @md.markup.inspect =~/no_ocn/ \
+      or @md.mod.inspect =~/--no-ocn/
+        ''
       else "\\begin{tiny}~\\end{tiny}{\\marginpar{\\begin{tiny}#@string1\\end{tiny}}}" #ocn object citation numbering
       end
       if @string !~/^([1-6a-z-]#{@@tilde}\S*|<:.+?>|#{@md.lv1}|#{@md.lv2}|#{@md.lv3}|#{@md.lv4}|#{@md.lv5}|#{@md.lv6})/
         @string.gsub!(/^\s*(.+)/m,"#{paranumber_display}\\1\n") #watch - in 1-6 is suspect
       else
         if (@string =~/^(?:[1-6a-z-]#{@@tilde}\S*|<:.+?>)/) #watch - in 1-6 is suspect
-          @string.gsub!(/^([1-6a-z-]#{@@tilde}\S*|<:.+?>)\s*(.+)/m,"\\1 #{paranumber_display} \\2\n") #watch - in 1-6 is suspect
+          @string.gsub!(/^([1-6a-z-]#{@@tilde}\S*)\s*(.+)/m,"\\1 #{paranumber_display} \\2\n") #watch - in 1-6 is suspect
+          @string.gsub!(/^(<:.+?>)\s*(.+)/m,"\\1 #{paranumber_display}\\2\n")
         else
-          @string.gsub!(/(#{@md.lv1}.+)$/,"#{@md.lv1} #{paranumber_display}\\1\n")
-          @string.gsub!(/(#{@md.lv2}.+)$/,"#{@md.lv2} #{paranumber_display}\\1\n")
-          @string.gsub!(/(#{@md.lv3}.+)$/,"#{@md.lv3} #{paranumber_display}\\1\n")
-          @string.gsub!(/(#{@md.lv4}.+)$/,"#{@md.lv4} #{paranumber_display}\\1\n")
-          @string.gsub!(/(#{@md.lv5}.+)$/,"#{@md.lv5} #{paranumber_display}\\1\n")
-          @string.gsub!(/(#{@md.lv6}.+)$/,"#{@md.lv6} #{paranumber_display}\\1\n")
+          @string.gsub!(/((#{@md.lv1}|#{@md.lv2}|#{@md.lv3}|#{@md.lv4}|#{@md.lv5}|#{@md.lv6}).+)$/,"\\2 #{paranumber_display}\\1\n")
         end
       end
       @string
