@@ -1,52 +1,58 @@
 =begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download.html
 
- * Description: xml output (sax style) processing
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah All Rights Reserved.
 
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
 
- * License: GPL 2 or later
+   SiSU, a framework for document structuring, publishing and search
 
-  Summary of GPL 2
+   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007 Ralph Amissah
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the Free
-  Software Foundation; either version 2 of the License, or (at your option)
-  any later version.
+   This program is free software: you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by the Free
+   Software Foundation, either version 3 of the License, or (at your option)
+   any later version.
 
-  This program is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
-  more details.
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+   more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+   You should have received a copy of the GNU General Public License along with
+   this program. If not, see <http://www.gnu.org/licenses/>.
 
-  If you have Internet connection, the latest version of the GPL should be
-  available at these locations:
-    http://www.fsf.org/licenses/gpl.html
-    http://www.gnu.org/copyleft/gpl.html
-    http://www.jus.uio.no/sisu/gpl2.fsf
+   If you have Internet connection, the latest version of the GPL should be
+   available at these locations:
+   <http://www.fsf.org/licenses/gpl.html>
+   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf>
 
-  SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+   * Standard SiSU markup syntax,
+   * Standard SiSU meta-markup syntax, and the
+   * Standard SiSU object citation numbering and system
 
-  SiSU uses:
+ * Hompages:
+   <http://www.jus.uio.no/sisu>
+   <http://www.sisudoc.org>
 
-  *  Standard SiSU markup syntax,
-  *  Standard SiSU meta-markup syntax, and the
-  *  Standard SiSU object citation numbering and system
+ * Download:
+   <http://www.jus.uio.no/sisu/SiSU/download.html>
 
-  © Ralph Amissah 1997, current 2007.
-  All Rights Reserved.
+ * Ralph Amissah
+   <ralph@amissah.com>
+   <ralph.amissah@gmail.com>
 
- * Ralph Amissah: ralph@amissah.com
-                  ralph.amissah@gmail.com
+ ** Description: xml output (sax style) processing
 
- * Notes: tidy -xml sax.xml >> index.tidy
 =end
 module SiSU_XML_SAX
   require "#{SiSU_lib}/defaults"
@@ -208,26 +214,6 @@ WOK
         end
         @@xml[:sc]=sc
       end
-      def xml_structure_ee(para='',lv='',ocn='',hname='') #embedded endnotes
-        lv=lv.to_i
-        n=lv - 1
-        n3=lv + 2
-        lv=nil if lv == 0
-        embedded_endnotes(para)
-        if para[@regx]
-          paragraph="#{para[@regx,2]}"
-          util=SiSU_text_utils::Wrap.new(paragraph,70)
-          wrapped=util.line_wrap
-        end
-        @@xml[:body] << "#{@tab*0}<object>" << "\n" if para[@regx]
-        @@xml[:body] << "#{@tab*1}<ocn>#{para[@regx,3]}</ocn>" << "\n" if para[@regx,3]
-        @@xml[:body] << if lv; %{#{@tab*1}<text class="h#{lv}">#{wrapped}</text>\n} << "\n"
-        else                   %{#{@tab*1}<text class="norm">#{wrapped}</text>\n} # main text, contents, body KEEP
-        end
-        #@@xml[:body] << "#{@tab*1}<text>#{wrapped}</text>\n" # main text, contents, body KEEP
-        ##@@xml[:body] << "#{@tab*1}<text>#{para[@regx,2]}</text>\n" if para[@regx,2] # old unwrapped main text, contents, body KEEP
-        @@xml[:body] << "#{@tab*0}</object>" << "\n" if para[@regx]
-      end
       def xml_structure(para='',lv='',ocn='',hname='',type='norm') #extracted endnotes
         lv=lv.to_i
         n=lv - 1
@@ -243,18 +229,19 @@ WOK
         @@xml[:body] << if para[@regx,3]; %{#{@tab*0}<object id="#{para[@regx,3]}">} << "\n"
         else                              "#{@tab*0}<object>" << "\n" if para[@regx]
         end
-        #@@xml[:body] << "#{@tab*1}<heading>#{lv}</heading>" << "\n" if lv
         @@xml[:body] << "#{@tab*1}<ocn>#{para[@regx,3]}</ocn>" << "\n" if para[@regx,3]
         @@xml[:body] << if lv; %{#{@tab*1}<text class="h#{lv}">\n#{@tab*2}#{wrapped}\n#{@tab*1}</text>\n} << "\n"
         else                   %{#{@tab*1}<text class="#{type}">\n#{@tab*2}#{wrapped}\n#{@tab*1}</text>\n} # main text, contents, body KEEP
         end
-        @@xml[:body] << @endnotes if @endnotes # main text, endnotes KEEP
+        @@xml[:body] << @endnotes if @endnotes
         ##@@xml[:body] << "#{@tab*1}<text>#{para[@regx,2]}</text>\n" if para[@regx,2] # old unwrapped main text, contents, body KEEP
         @@xml[:body] << "#{@tab*0}</object>" << "\n" if para[@regx]
         @endnotes=[]
       end
       def group_structure(para='',ocn='')
         para.gsub!(/<:group(?:-end)?>/,'')
+        extract_endnotes(para)
+        para.gsub!(/~[{\[]([\d*+]+)\s+(?:.+?)\s*<#@dp>[}\]]~/,'<en>\1</en>') #footnote/endnote clean
         para=@trans.markup_group(para)
         para.strip!
         @@xml[:body] << %{#{@tab*0}<object id="#{ocn}">} << "\n"
@@ -263,10 +250,13 @@ WOK
         @@xml[:body] << %{#{@tab*2}#{para}#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*1}</text>\n}
         @@xml[:body] << "#{@tab*0}</object>" << "\n"
+        @@xml[:body] << @endnotes if @endnotes
+        @endnotes=[]
       end
       def poem_structure(para='',ocn='')
         para.gsub!(/<:verse(?:-end)?>/,'')
         para=@trans.markup_group(para)
+        #para.gsub!(/\s\s/,'&#160;&#160;')
         para.strip!
         @@xml[:body] << %{#{@tab*0}<object id="#{ocn}">} << "\n"
         @@xml[:body] << %{#{@tab*1}<ocn>#{ocn}</ocn>} << "\n"
@@ -305,9 +295,12 @@ WOK
           if para =~/^0~(\S+)\s+(.+?)$/ # for headers
             d_meta=SiSU_text_utils::Header_scan.new(@md,para).meta
             if d_meta; xml_head(d_meta)
-	          end
+            end
+          end
+          if @rcdc==false \
+          and (para =~/~metadata/ or para =~/1~meta\s+Document Information/)
+            @rcdc=true
           end
-          @rcdc=true if @rcdc==false and (para =~/~metadata/ or para =~/1~\s+Document Information/)
           if para !~/(^0~|<ENDNOTES>|<EOF>)/
             if para =~/.+?<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
               paranum=para[@regx,3]
@@ -367,11 +360,14 @@ WOK
                   #@@xml[:body] << "#{@tab*7}<text>#{para[@regx,2]}</text>\n" if para[@regx,2] # main text, contents, body KEEP
                   #@@xml[:body] << "#{@tab*6}</object>" << "\n" if para[@regx]
                 end
-              elsif para =~/(Note|Endnotes?)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
-              elsif para =~/(MetaData)/ and para =~/<~(\d+);[m]\d+;\w\d+><#@dp:#@dp>$/ #debug 2003w46 add rc info
+              elsif para =~/(Note|Endnotes?)/ \
+              and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
+              elsif para =~/(MetaData)/ \
+              and para =~/<~(\d+);[m]\d+;\w\d+><#@dp:#@dp>$/ #debug 2003w46 add rc info
                 format_scroll=Format_scroll.new(@md,'<br /><a name="metadata">MetaData</a>')
                 para=format_scroll.bold_para
-              elsif para =~/(Owner Details)/ and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
+              elsif para =~/(Owner Details)/ \
+              and para !~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/
                 format_scroll=Format_scroll.new(@md,'<br /><a name="owner.details">Owner Details</a>')
                 @@xml[:owner_details]=format_scroll.bold_para
                 para=''
@@ -380,7 +376,10 @@ WOK
                 format_text=Format_text_object.new(one,two)
                 para=format_text.seg_no_paranum
               end
-              para='' if para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
+              if para =~/<a name="n\d+">/ \
+              and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
+                para=''
+              end
               if para =~/.*<:#>.*$/
                 para=if para =~ /<:i[1-9]>/
                   format_text=Format_text_object.new(para,'')
